/********************************************************
 Bitstream Library, a module for reading bits of data

 Copyright (C) 2007-2015  Brian Langenberger

 The Bitstream Library is free software; you can redistribute it and/or modify
 it under the terms of either:

   * the GNU Lesser General Public License as published by the Free
     Software Foundation; either version 3 of the License, or (at your
     option) any later version.

 or

   * the GNU General Public License as published by the Free Software
     Foundation; either version 2 of the License, or (at your option) any
     later version.

 or both in parallel, as here.

 The Bitstream Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.

 You should have received copies of the GNU General Public License and the
 GNU Lesser General Public License along with the GNU MP Library.  If not,
 see https://www.gnu.org/licenses/.
 *******************************************************/

{
/* state = 0x0 (0 bits, 0x0 buffer) */
{{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0}},
/* state = 0x1 (0 bits, 0x0 buffer) */
{{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0},{0, 0x0, 0x0}},
/* state = 0x2 (1 bits, 0x0 buffer) */
{{1, 0x0, 0x0},{1, 0x0, 0x0},{1, 0x0, 0x0},{1, 0x0, 0x0},{1, 0x0, 0x0},{1, 0x0, 0x0},{1, 0x0, 0x0},{1, 0x0, 0x0}},
/* state = 0x3 (1 bits, 0x1 buffer) */
{{1, 0x1, 0x0},{1, 0x1, 0x0},{1, 0x1, 0x0},{1, 0x1, 0x0},{1, 0x1, 0x0},{1, 0x1, 0x0},{1, 0x1, 0x0},{1, 0x1, 0x0}},
/* state = 0x4 (2 bits, 0x0 buffer) */
{{1, 0x0, 0x2},{2, 0x0, 0x0},{2, 0x0, 0x0},{2, 0x0, 0x0},{2, 0x0, 0x0},{2, 0x0, 0x0},{2, 0x0, 0x0},{2, 0x0, 0x0}},
/* state = 0x5 (2 bits, 0x1 buffer) */
{{1, 0x1, 0x2},{2, 0x1, 0x0},{2, 0x1, 0x0},{2, 0x1, 0x0},{2, 0x1, 0x0},{2, 0x1, 0x0},{2, 0x1, 0x0},{2, 0x1, 0x0}},
/* state = 0x6 (2 bits, 0x2 buffer) */
{{1, 0x0, 0x3},{2, 0x2, 0x0},{2, 0x2, 0x0},{2, 0x2, 0x0},{2, 0x2, 0x0},{2, 0x2, 0x0},{2, 0x2, 0x0},{2, 0x2, 0x0}},
/* state = 0x7 (2 bits, 0x3 buffer) */
{{1, 0x1, 0x3},{2, 0x3, 0x0},{2, 0x3, 0x0},{2, 0x3, 0x0},{2, 0x3, 0x0},{2, 0x3, 0x0},{2, 0x3, 0x0},{2, 0x3, 0x0}},
/* state = 0x8 (3 bits, 0x0 buffer) */
{{1, 0x0, 0x4},{2, 0x0, 0x2},{3, 0x0, 0x0},{3, 0x0, 0x0},{3, 0x0, 0x0},{3, 0x0, 0x0},{3, 0x0, 0x0},{3, 0x0, 0x0}},
/* state = 0x9 (3 bits, 0x1 buffer) */
{{1, 0x1, 0x4},{2, 0x1, 0x2},{3, 0x1, 0x0},{3, 0x1, 0x0},{3, 0x1, 0x0},{3, 0x1, 0x0},{3, 0x1, 0x0},{3, 0x1, 0x0}},
/* state = 0xA (3 bits, 0x2 buffer) */
{{1, 0x0, 0x5},{2, 0x2, 0x2},{3, 0x2, 0x0},{3, 0x2, 0x0},{3, 0x2, 0x0},{3, 0x2, 0x0},{3, 0x2, 0x0},{3, 0x2, 0x0}},
/* state = 0xB (3 bits, 0x3 buffer) */
{{1, 0x1, 0x5},{2, 0x3, 0x2},{3, 0x3, 0x0},{3, 0x3, 0x0},{3, 0x3, 0x0},{3, 0x3, 0x0},{3, 0x3, 0x0},{3, 0x3, 0x0}},
/* state = 0xC (3 bits, 0x4 buffer) */
{{1, 0x0, 0x6},{2, 0x0, 0x3},{3, 0x4, 0x0},{3, 0x4, 0x0},{3, 0x4, 0x0},{3, 0x4, 0x0},{3, 0x4, 0x0},{3, 0x4, 0x0}},
/* state = 0xD (3 bits, 0x5 buffer) */
{{1, 0x1, 0x6},{2, 0x1, 0x3},{3, 0x5, 0x0},{3, 0x5, 0x0},{3, 0x5, 0x0},{3, 0x5, 0x0},{3, 0x5, 0x0},{3, 0x5, 0x0}},
/* state = 0xE (3 bits, 0x6 buffer) */
{{1, 0x0, 0x7},{2, 0x2, 0x3},{3, 0x6, 0x0},{3, 0x6, 0x0},{3, 0x6, 0x0},{3, 0x6, 0x0},{3, 0x6, 0x0},{3, 0x6, 0x0}},
/* state = 0xF (3 bits, 0x7 buffer) */
{{1, 0x1, 0x7},{2, 0x3, 0x3},{3, 0x7, 0x0},{3, 0x7, 0x0},{3, 0x7, 0x0},{3, 0x7, 0x0},{3, 0x7, 0x0},{3, 0x7, 0x0}},
/* state = 0x10 (4 bits, 0x0 buffer) */
{{1, 0x0, 0x8},{2, 0x0, 0x4},{3, 0x0, 0x2},{4, 0x0, 0x0},{4, 0x0, 0x0},{4, 0x0, 0x0},{4, 0x0, 0x0},{4, 0x0, 0x0}},
/* state = 0x11 (4 bits, 0x1 buffer) */
{{1, 0x1, 0x8},{2, 0x1, 0x4},{3, 0x1, 0x2},{4, 0x1, 0x0},{4, 0x1, 0x0},{4, 0x1, 0x0},{4, 0x1, 0x0},{4, 0x1, 0x0}},
/* state = 0x12 (4 bits, 0x2 buffer) */
{{1, 0x0, 0x9},{2, 0x2, 0x4},{3, 0x2, 0x2},{4, 0x2, 0x0},{4, 0x2, 0x0},{4, 0x2, 0x0},{4, 0x2, 0x0},{4, 0x2, 0x0}},
/* state = 0x13 (4 bits, 0x3 buffer) */
{{1, 0x1, 0x9},{2, 0x3, 0x4},{3, 0x3, 0x2},{4, 0x3, 0x0},{4, 0x3, 0x0},{4, 0x3, 0x0},{4, 0x3, 0x0},{4, 0x3, 0x0}},
/* state = 0x14 (4 bits, 0x4 buffer) */
{{1, 0x0, 0xA},{2, 0x0, 0x5},{3, 0x4, 0x2},{4, 0x4, 0x0},{4, 0x4, 0x0},{4, 0x4, 0x0},{4, 0x4, 0x0},{4, 0x4, 0x0}},
/* state = 0x15 (4 bits, 0x5 buffer) */
{{1, 0x1, 0xA},{2, 0x1, 0x5},{3, 0x5, 0x2},{4, 0x5, 0x0},{4, 0x5, 0x0},{4, 0x5, 0x0},{4, 0x5, 0x0},{4, 0x5, 0x0}},
/* state = 0x16 (4 bits, 0x6 buffer) */
{{1, 0x0, 0xB},{2, 0x2, 0x5},{3, 0x6, 0x2},{4, 0x6, 0x0},{4, 0x6, 0x0},{4, 0x6, 0x0},{4, 0x6, 0x0},{4, 0x6, 0x0}},
/* state = 0x17 (4 bits, 0x7 buffer) */
{{1, 0x1, 0xB},{2, 0x3, 0x5},{3, 0x7, 0x2},{4, 0x7, 0x0},{4, 0x7, 0x0},{4, 0x7, 0x0},{4, 0x7, 0x0},{4, 0x7, 0x0}},
/* state = 0x18 (4 bits, 0x8 buffer) */
{{1, 0x0, 0xC},{2, 0x0, 0x6},{3, 0x0, 0x3},{4, 0x8, 0x0},{4, 0x8, 0x0},{4, 0x8, 0x0},{4, 0x8, 0x0},{4, 0x8, 0x0}},
/* state = 0x19 (4 bits, 0x9 buffer) */
{{1, 0x1, 0xC},{2, 0x1, 0x6},{3, 0x1, 0x3},{4, 0x9, 0x0},{4, 0x9, 0x0},{4, 0x9, 0x0},{4, 0x9, 0x0},{4, 0x9, 0x0}},
/* state = 0x1A (4 bits, 0xA buffer) */
{{1, 0x0, 0xD},{2, 0x2, 0x6},{3, 0x2, 0x3},{4, 0xA, 0x0},{4, 0xA, 0x0},{4, 0xA, 0x0},{4, 0xA, 0x0},{4, 0xA, 0x0}},
/* state = 0x1B (4 bits, 0xB buffer) */
{{1, 0x1, 0xD},{2, 0x3, 0x6},{3, 0x3, 0x3},{4, 0xB, 0x0},{4, 0xB, 0x0},{4, 0xB, 0x0},{4, 0xB, 0x0},{4, 0xB, 0x0}},
/* state = 0x1C (4 bits, 0xC buffer) */
{{1, 0x0, 0xE},{2, 0x0, 0x7},{3, 0x4, 0x3},{4, 0xC, 0x0},{4, 0xC, 0x0},{4, 0xC, 0x0},{4, 0xC, 0x0},{4, 0xC, 0x0}},
/* state = 0x1D (4 bits, 0xD buffer) */
{{1, 0x1, 0xE},{2, 0x1, 0x7},{3, 0x5, 0x3},{4, 0xD, 0x0},{4, 0xD, 0x0},{4, 0xD, 0x0},{4, 0xD, 0x0},{4, 0xD, 0x0}},
/* state = 0x1E (4 bits, 0xE buffer) */
{{1, 0x0, 0xF},{2, 0x2, 0x7},{3, 0x6, 0x3},{4, 0xE, 0x0},{4, 0xE, 0x0},{4, 0xE, 0x0},{4, 0xE, 0x0},{4, 0xE, 0x0}},
/* state = 0x1F (4 bits, 0xF buffer) */
{{1, 0x1, 0xF},{2, 0x3, 0x7},{3, 0x7, 0x3},{4, 0xF, 0x0},{4, 0xF, 0x0},{4, 0xF, 0x0},{4, 0xF, 0x0},{4, 0xF, 0x0}},
/* state = 0x20 (5 bits, 0x0 buffer) */
{{1, 0x0, 0x10},{2, 0x0, 0x8},{3, 0x0, 0x4},{4, 0x0, 0x2},{5, 0x0, 0x0},{5, 0x0, 0x0},{5, 0x0, 0x0},{5, 0x0, 0x0}},
/* state = 0x21 (5 bits, 0x1 buffer) */
{{1, 0x1, 0x10},{2, 0x1, 0x8},{3, 0x1, 0x4},{4, 0x1, 0x2},{5, 0x1, 0x0},{5, 0x1, 0x0},{5, 0x1, 0x0},{5, 0x1, 0x0}},
/* state = 0x22 (5 bits, 0x2 buffer) */
{{1, 0x0, 0x11},{2, 0x2, 0x8},{3, 0x2, 0x4},{4, 0x2, 0x2},{5, 0x2, 0x0},{5, 0x2, 0x0},{5, 0x2, 0x0},{5, 0x2, 0x0}},
/* state = 0x23 (5 bits, 0x3 buffer) */
{{1, 0x1, 0x11},{2, 0x3, 0x8},{3, 0x3, 0x4},{4, 0x3, 0x2},{5, 0x3, 0x0},{5, 0x3, 0x0},{5, 0x3, 0x0},{5, 0x3, 0x0}},
/* state = 0x24 (5 bits, 0x4 buffer) */
{{1, 0x0, 0x12},{2, 0x0, 0x9},{3, 0x4, 0x4},{4, 0x4, 0x2},{5, 0x4, 0x0},{5, 0x4, 0x0},{5, 0x4, 0x0},{5, 0x4, 0x0}},
/* state = 0x25 (5 bits, 0x5 buffer) */
{{1, 0x1, 0x12},{2, 0x1, 0x9},{3, 0x5, 0x4},{4, 0x5, 0x2},{5, 0x5, 0x0},{5, 0x5, 0x0},{5, 0x5, 0x0},{5, 0x5, 0x0}},
/* state = 0x26 (5 bits, 0x6 buffer) */
{{1, 0x0, 0x13},{2, 0x2, 0x9},{3, 0x6, 0x4},{4, 0x6, 0x2},{5, 0x6, 0x0},{5, 0x6, 0x0},{5, 0x6, 0x0},{5, 0x6, 0x0}},
/* state = 0x27 (5 bits, 0x7 buffer) */
{{1, 0x1, 0x13},{2, 0x3, 0x9},{3, 0x7, 0x4},{4, 0x7, 0x2},{5, 0x7, 0x0},{5, 0x7, 0x0},{5, 0x7, 0x0},{5, 0x7, 0x0}},
/* state = 0x28 (5 bits, 0x8 buffer) */
{{1, 0x0, 0x14},{2, 0x0, 0xA},{3, 0x0, 0x5},{4, 0x8, 0x2},{5, 0x8, 0x0},{5, 0x8, 0x0},{5, 0x8, 0x0},{5, 0x8, 0x0}},
/* state = 0x29 (5 bits, 0x9 buffer) */
{{1, 0x1, 0x14},{2, 0x1, 0xA},{3, 0x1, 0x5},{4, 0x9, 0x2},{5, 0x9, 0x0},{5, 0x9, 0x0},{5, 0x9, 0x0},{5, 0x9, 0x0}},
/* state = 0x2A (5 bits, 0xA buffer) */
{{1, 0x0, 0x15},{2, 0x2, 0xA},{3, 0x2, 0x5},{4, 0xA, 0x2},{5, 0xA, 0x0},{5, 0xA, 0x0},{5, 0xA, 0x0},{5, 0xA, 0x0}},
/* state = 0x2B (5 bits, 0xB buffer) */
{{1, 0x1, 0x15},{2, 0x3, 0xA},{3, 0x3, 0x5},{4, 0xB, 0x2},{5, 0xB, 0x0},{5, 0xB, 0x0},{5, 0xB, 0x0},{5, 0xB, 0x0}},
/* state = 0x2C (5 bits, 0xC buffer) */
{{1, 0x0, 0x16},{2, 0x0, 0xB},{3, 0x4, 0x5},{4, 0xC, 0x2},{5, 0xC, 0x0},{5, 0xC, 0x0},{5, 0xC, 0x0},{5, 0xC, 0x0}},
/* state = 0x2D (5 bits, 0xD buffer) */
{{1, 0x1, 0x16},{2, 0x1, 0xB},{3, 0x5, 0x5},{4, 0xD, 0x2},{5, 0xD, 0x0},{5, 0xD, 0x0},{5, 0xD, 0x0},{5, 0xD, 0x0}},
/* state = 0x2E (5 bits, 0xE buffer) */
{{1, 0x0, 0x17},{2, 0x2, 0xB},{3, 0x6, 0x5},{4, 0xE, 0x2},{5, 0xE, 0x0},{5, 0xE, 0x0},{5, 0xE, 0x0},{5, 0xE, 0x0}},
/* state = 0x2F (5 bits, 0xF buffer) */
{{1, 0x1, 0x17},{2, 0x3, 0xB},{3, 0x7, 0x5},{4, 0xF, 0x2},{5, 0xF, 0x0},{5, 0xF, 0x0},{5, 0xF, 0x0},{5, 0xF, 0x0}},
/* state = 0x30 (5 bits, 0x10 buffer) */
{{1, 0x0, 0x18},{2, 0x0, 0xC},{3, 0x0, 0x6},{4, 0x0, 0x3},{5, 0x10, 0x0},{5, 0x10, 0x0},{5, 0x10, 0x0},{5, 0x10, 0x0}},
/* state = 0x31 (5 bits, 0x11 buffer) */
{{1, 0x1, 0x18},{2, 0x1, 0xC},{3, 0x1, 0x6},{4, 0x1, 0x3},{5, 0x11, 0x0},{5, 0x11, 0x0},{5, 0x11, 0x0},{5, 0x11, 0x0}},
/* state = 0x32 (5 bits, 0x12 buffer) */
{{1, 0x0, 0x19},{2, 0x2, 0xC},{3, 0x2, 0x6},{4, 0x2, 0x3},{5, 0x12, 0x0},{5, 0x12, 0x0},{5, 0x12, 0x0},{5, 0x12, 0x0}},
/* state = 0x33 (5 bits, 0x13 buffer) */
{{1, 0x1, 0x19},{2, 0x3, 0xC},{3, 0x3, 0x6},{4, 0x3, 0x3},{5, 0x13, 0x0},{5, 0x13, 0x0},{5, 0x13, 0x0},{5, 0x13, 0x0}},
/* state = 0x34 (5 bits, 0x14 buffer) */
{{1, 0x0, 0x1A},{2, 0x0, 0xD},{3, 0x4, 0x6},{4, 0x4, 0x3},{5, 0x14, 0x0},{5, 0x14, 0x0},{5, 0x14, 0x0},{5, 0x14, 0x0}},
/* state = 0x35 (5 bits, 0x15 buffer) */
{{1, 0x1, 0x1A},{2, 0x1, 0xD},{3, 0x5, 0x6},{4, 0x5, 0x3},{5, 0x15, 0x0},{5, 0x15, 0x0},{5, 0x15, 0x0},{5, 0x15, 0x0}},
/* state = 0x36 (5 bits, 0x16 buffer) */
{{1, 0x0, 0x1B},{2, 0x2, 0xD},{3, 0x6, 0x6},{4, 0x6, 0x3},{5, 0x16, 0x0},{5, 0x16, 0x0},{5, 0x16, 0x0},{5, 0x16, 0x0}},
/* state = 0x37 (5 bits, 0x17 buffer) */
{{1, 0x1, 0x1B},{2, 0x3, 0xD},{3, 0x7, 0x6},{4, 0x7, 0x3},{5, 0x17, 0x0},{5, 0x17, 0x0},{5, 0x17, 0x0},{5, 0x17, 0x0}},
/* state = 0x38 (5 bits, 0x18 buffer) */
{{1, 0x0, 0x1C},{2, 0x0, 0xE},{3, 0x0, 0x7},{4, 0x8, 0x3},{5, 0x18, 0x0},{5, 0x18, 0x0},{5, 0x18, 0x0},{5, 0x18, 0x0}},
/* state = 0x39 (5 bits, 0x19 buffer) */
{{1, 0x1, 0x1C},{2, 0x1, 0xE},{3, 0x1, 0x7},{4, 0x9, 0x3},{5, 0x19, 0x0},{5, 0x19, 0x0},{5, 0x19, 0x0},{5, 0x19, 0x0}},
/* state = 0x3A (5 bits, 0x1A buffer) */
{{1, 0x0, 0x1D},{2, 0x2, 0xE},{3, 0x2, 0x7},{4, 0xA, 0x3},{5, 0x1A, 0x0},{5, 0x1A, 0x0},{5, 0x1A, 0x0},{5, 0x1A, 0x0}},
/* state = 0x3B (5 bits, 0x1B buffer) */
{{1, 0x1, 0x1D},{2, 0x3, 0xE},{3, 0x3, 0x7},{4, 0xB, 0x3},{5, 0x1B, 0x0},{5, 0x1B, 0x0},{5, 0x1B, 0x0},{5, 0x1B, 0x0}},
/* state = 0x3C (5 bits, 0x1C buffer) */
{{1, 0x0, 0x1E},{2, 0x0, 0xF},{3, 0x4, 0x7},{4, 0xC, 0x3},{5, 0x1C, 0x0},{5, 0x1C, 0x0},{5, 0x1C, 0x0},{5, 0x1C, 0x0}},
/* state = 0x3D (5 bits, 0x1D buffer) */
{{1, 0x1, 0x1E},{2, 0x1, 0xF},{3, 0x5, 0x7},{4, 0xD, 0x3},{5, 0x1D, 0x0},{5, 0x1D, 0x0},{5, 0x1D, 0x0},{5, 0x1D, 0x0}},
/* state = 0x3E (5 bits, 0x1E buffer) */
{{1, 0x0, 0x1F},{2, 0x2, 0xF},{3, 0x6, 0x7},{4, 0xE, 0x3},{5, 0x1E, 0x0},{5, 0x1E, 0x0},{5, 0x1E, 0x0},{5, 0x1E, 0x0}},
/* state = 0x3F (5 bits, 0x1F buffer) */
{{1, 0x1, 0x1F},{2, 0x3, 0xF},{3, 0x7, 0x7},{4, 0xF, 0x3},{5, 0x1F, 0x0},{5, 0x1F, 0x0},{5, 0x1F, 0x0},{5, 0x1F, 0x0}},
/* state = 0x40 (6 bits, 0x0 buffer) */
{{1, 0x0, 0x20},{2, 0x0, 0x10},{3, 0x0, 0x8},{4, 0x0, 0x4},{5, 0x0, 0x2},{6, 0x0, 0x0},{6, 0x0, 0x0},{6, 0x0, 0x0}},
/* state = 0x41 (6 bits, 0x1 buffer) */
{{1, 0x1, 0x20},{2, 0x1, 0x10},{3, 0x1, 0x8},{4, 0x1, 0x4},{5, 0x1, 0x2},{6, 0x1, 0x0},{6, 0x1, 0x0},{6, 0x1, 0x0}},
/* state = 0x42 (6 bits, 0x2 buffer) */
{{1, 0x0, 0x21},{2, 0x2, 0x10},{3, 0x2, 0x8},{4, 0x2, 0x4},{5, 0x2, 0x2},{6, 0x2, 0x0},{6, 0x2, 0x0},{6, 0x2, 0x0}},
/* state = 0x43 (6 bits, 0x3 buffer) */
{{1, 0x1, 0x21},{2, 0x3, 0x10},{3, 0x3, 0x8},{4, 0x3, 0x4},{5, 0x3, 0x2},{6, 0x3, 0x0},{6, 0x3, 0x0},{6, 0x3, 0x0}},
/* state = 0x44 (6 bits, 0x4 buffer) */
{{1, 0x0, 0x22},{2, 0x0, 0x11},{3, 0x4, 0x8},{4, 0x4, 0x4},{5, 0x4, 0x2},{6, 0x4, 0x0},{6, 0x4, 0x0},{6, 0x4, 0x0}},
/* state = 0x45 (6 bits, 0x5 buffer) */
{{1, 0x1, 0x22},{2, 0x1, 0x11},{3, 0x5, 0x8},{4, 0x5, 0x4},{5, 0x5, 0x2},{6, 0x5, 0x0},{6, 0x5, 0x0},{6, 0x5, 0x0}},
/* state = 0x46 (6 bits, 0x6 buffer) */
{{1, 0x0, 0x23},{2, 0x2, 0x11},{3, 0x6, 0x8},{4, 0x6, 0x4},{5, 0x6, 0x2},{6, 0x6, 0x0},{6, 0x6, 0x0},{6, 0x6, 0x0}},
/* state = 0x47 (6 bits, 0x7 buffer) */
{{1, 0x1, 0x23},{2, 0x3, 0x11},{3, 0x7, 0x8},{4, 0x7, 0x4},{5, 0x7, 0x2},{6, 0x7, 0x0},{6, 0x7, 0x0},{6, 0x7, 0x0}},
/* state = 0x48 (6 bits, 0x8 buffer) */
{{1, 0x0, 0x24},{2, 0x0, 0x12},{3, 0x0, 0x9},{4, 0x8, 0x4},{5, 0x8, 0x2},{6, 0x8, 0x0},{6, 0x8, 0x0},{6, 0x8, 0x0}},
/* state = 0x49 (6 bits, 0x9 buffer) */
{{1, 0x1, 0x24},{2, 0x1, 0x12},{3, 0x1, 0x9},{4, 0x9, 0x4},{5, 0x9, 0x2},{6, 0x9, 0x0},{6, 0x9, 0x0},{6, 0x9, 0x0}},
/* state = 0x4A (6 bits, 0xA buffer) */
{{1, 0x0, 0x25},{2, 0x2, 0x12},{3, 0x2, 0x9},{4, 0xA, 0x4},{5, 0xA, 0x2},{6, 0xA, 0x0},{6, 0xA, 0x0},{6, 0xA, 0x0}},
/* state = 0x4B (6 bits, 0xB buffer) */
{{1, 0x1, 0x25},{2, 0x3, 0x12},{3, 0x3, 0x9},{4, 0xB, 0x4},{5, 0xB, 0x2},{6, 0xB, 0x0},{6, 0xB, 0x0},{6, 0xB, 0x0}},
/* state = 0x4C (6 bits, 0xC buffer) */
{{1, 0x0, 0x26},{2, 0x0, 0x13},{3, 0x4, 0x9},{4, 0xC, 0x4},{5, 0xC, 0x2},{6, 0xC, 0x0},{6, 0xC, 0x0},{6, 0xC, 0x0}},
/* state = 0x4D (6 bits, 0xD buffer) */
{{1, 0x1, 0x26},{2, 0x1, 0x13},{3, 0x5, 0x9},{4, 0xD, 0x4},{5, 0xD, 0x2},{6, 0xD, 0x0},{6, 0xD, 0x0},{6, 0xD, 0x0}},
/* state = 0x4E (6 bits, 0xE buffer) */
{{1, 0x0, 0x27},{2, 0x2, 0x13},{3, 0x6, 0x9},{4, 0xE, 0x4},{5, 0xE, 0x2},{6, 0xE, 0x0},{6, 0xE, 0x0},{6, 0xE, 0x0}},
/* state = 0x4F (6 bits, 0xF buffer) */
{{1, 0x1, 0x27},{2, 0x3, 0x13},{3, 0x7, 0x9},{4, 0xF, 0x4},{5, 0xF, 0x2},{6, 0xF, 0x0},{6, 0xF, 0x0},{6, 0xF, 0x0}},
/* state = 0x50 (6 bits, 0x10 buffer) */
{{1, 0x0, 0x28},{2, 0x0, 0x14},{3, 0x0, 0xA},{4, 0x0, 0x5},{5, 0x10, 0x2},{6, 0x10, 0x0},{6, 0x10, 0x0},{6, 0x10, 0x0}},
/* state = 0x51 (6 bits, 0x11 buffer) */
{{1, 0x1, 0x28},{2, 0x1, 0x14},{3, 0x1, 0xA},{4, 0x1, 0x5},{5, 0x11, 0x2},{6, 0x11, 0x0},{6, 0x11, 0x0},{6, 0x11, 0x0}},
/* state = 0x52 (6 bits, 0x12 buffer) */
{{1, 0x0, 0x29},{2, 0x2, 0x14},{3, 0x2, 0xA},{4, 0x2, 0x5},{5, 0x12, 0x2},{6, 0x12, 0x0},{6, 0x12, 0x0},{6, 0x12, 0x0}},
/* state = 0x53 (6 bits, 0x13 buffer) */
{{1, 0x1, 0x29},{2, 0x3, 0x14},{3, 0x3, 0xA},{4, 0x3, 0x5},{5, 0x13, 0x2},{6, 0x13, 0x0},{6, 0x13, 0x0},{6, 0x13, 0x0}},
/* state = 0x54 (6 bits, 0x14 buffer) */
{{1, 0x0, 0x2A},{2, 0x0, 0x15},{3, 0x4, 0xA},{4, 0x4, 0x5},{5, 0x14, 0x2},{6, 0x14, 0x0},{6, 0x14, 0x0},{6, 0x14, 0x0}},
/* state = 0x55 (6 bits, 0x15 buffer) */
{{1, 0x1, 0x2A},{2, 0x1, 0x15},{3, 0x5, 0xA},{4, 0x5, 0x5},{5, 0x15, 0x2},{6, 0x15, 0x0},{6, 0x15, 0x0},{6, 0x15, 0x0}},
/* state = 0x56 (6 bits, 0x16 buffer) */
{{1, 0x0, 0x2B},{2, 0x2, 0x15},{3, 0x6, 0xA},{4, 0x6, 0x5},{5, 0x16, 0x2},{6, 0x16, 0x0},{6, 0x16, 0x0},{6, 0x16, 0x0}},
/* state = 0x57 (6 bits, 0x17 buffer) */
{{1, 0x1, 0x2B},{2, 0x3, 0x15},{3, 0x7, 0xA},{4, 0x7, 0x5},{5, 0x17, 0x2},{6, 0x17, 0x0},{6, 0x17, 0x0},{6, 0x17, 0x0}},
/* state = 0x58 (6 bits, 0x18 buffer) */
{{1, 0x0, 0x2C},{2, 0x0, 0x16},{3, 0x0, 0xB},{4, 0x8, 0x5},{5, 0x18, 0x2},{6, 0x18, 0x0},{6, 0x18, 0x0},{6, 0x18, 0x0}},
/* state = 0x59 (6 bits, 0x19 buffer) */
{{1, 0x1, 0x2C},{2, 0x1, 0x16},{3, 0x1, 0xB},{4, 0x9, 0x5},{5, 0x19, 0x2},{6, 0x19, 0x0},{6, 0x19, 0x0},{6, 0x19, 0x0}},
/* state = 0x5A (6 bits, 0x1A buffer) */
{{1, 0x0, 0x2D},{2, 0x2, 0x16},{3, 0x2, 0xB},{4, 0xA, 0x5},{5, 0x1A, 0x2},{6, 0x1A, 0x0},{6, 0x1A, 0x0},{6, 0x1A, 0x0}},
/* state = 0x5B (6 bits, 0x1B buffer) */
{{1, 0x1, 0x2D},{2, 0x3, 0x16},{3, 0x3, 0xB},{4, 0xB, 0x5},{5, 0x1B, 0x2},{6, 0x1B, 0x0},{6, 0x1B, 0x0},{6, 0x1B, 0x0}},
/* state = 0x5C (6 bits, 0x1C buffer) */
{{1, 0x0, 0x2E},{2, 0x0, 0x17},{3, 0x4, 0xB},{4, 0xC, 0x5},{5, 0x1C, 0x2},{6, 0x1C, 0x0},{6, 0x1C, 0x0},{6, 0x1C, 0x0}},
/* state = 0x5D (6 bits, 0x1D buffer) */
{{1, 0x1, 0x2E},{2, 0x1, 0x17},{3, 0x5, 0xB},{4, 0xD, 0x5},{5, 0x1D, 0x2},{6, 0x1D, 0x0},{6, 0x1D, 0x0},{6, 0x1D, 0x0}},
/* state = 0x5E (6 bits, 0x1E buffer) */
{{1, 0x0, 0x2F},{2, 0x2, 0x17},{3, 0x6, 0xB},{4, 0xE, 0x5},{5, 0x1E, 0x2},{6, 0x1E, 0x0},{6, 0x1E, 0x0},{6, 0x1E, 0x0}},
/* state = 0x5F (6 bits, 0x1F buffer) */
{{1, 0x1, 0x2F},{2, 0x3, 0x17},{3, 0x7, 0xB},{4, 0xF, 0x5},{5, 0x1F, 0x2},{6, 0x1F, 0x0},{6, 0x1F, 0x0},{6, 0x1F, 0x0}},
/* state = 0x60 (6 bits, 0x20 buffer) */
{{1, 0x0, 0x30},{2, 0x0, 0x18},{3, 0x0, 0xC},{4, 0x0, 0x6},{5, 0x0, 0x3},{6, 0x20, 0x0},{6, 0x20, 0x0},{6, 0x20, 0x0}},
/* state = 0x61 (6 bits, 0x21 buffer) */
{{1, 0x1, 0x30},{2, 0x1, 0x18},{3, 0x1, 0xC},{4, 0x1, 0x6},{5, 0x1, 0x3},{6, 0x21, 0x0},{6, 0x21, 0x0},{6, 0x21, 0x0}},
/* state = 0x62 (6 bits, 0x22 buffer) */
{{1, 0x0, 0x31},{2, 0x2, 0x18},{3, 0x2, 0xC},{4, 0x2, 0x6},{5, 0x2, 0x3},{6, 0x22, 0x0},{6, 0x22, 0x0},{6, 0x22, 0x0}},
/* state = 0x63 (6 bits, 0x23 buffer) */
{{1, 0x1, 0x31},{2, 0x3, 0x18},{3, 0x3, 0xC},{4, 0x3, 0x6},{5, 0x3, 0x3},{6, 0x23, 0x0},{6, 0x23, 0x0},{6, 0x23, 0x0}},
/* state = 0x64 (6 bits, 0x24 buffer) */
{{1, 0x0, 0x32},{2, 0x0, 0x19},{3, 0x4, 0xC},{4, 0x4, 0x6},{5, 0x4, 0x3},{6, 0x24, 0x0},{6, 0x24, 0x0},{6, 0x24, 0x0}},
/* state = 0x65 (6 bits, 0x25 buffer) */
{{1, 0x1, 0x32},{2, 0x1, 0x19},{3, 0x5, 0xC},{4, 0x5, 0x6},{5, 0x5, 0x3},{6, 0x25, 0x0},{6, 0x25, 0x0},{6, 0x25, 0x0}},
/* state = 0x66 (6 bits, 0x26 buffer) */
{{1, 0x0, 0x33},{2, 0x2, 0x19},{3, 0x6, 0xC},{4, 0x6, 0x6},{5, 0x6, 0x3},{6, 0x26, 0x0},{6, 0x26, 0x0},{6, 0x26, 0x0}},
/* state = 0x67 (6 bits, 0x27 buffer) */
{{1, 0x1, 0x33},{2, 0x3, 0x19},{3, 0x7, 0xC},{4, 0x7, 0x6},{5, 0x7, 0x3},{6, 0x27, 0x0},{6, 0x27, 0x0},{6, 0x27, 0x0}},
/* state = 0x68 (6 bits, 0x28 buffer) */
{{1, 0x0, 0x34},{2, 0x0, 0x1A},{3, 0x0, 0xD},{4, 0x8, 0x6},{5, 0x8, 0x3},{6, 0x28, 0x0},{6, 0x28, 0x0},{6, 0x28, 0x0}},
/* state = 0x69 (6 bits, 0x29 buffer) */
{{1, 0x1, 0x34},{2, 0x1, 0x1A},{3, 0x1, 0xD},{4, 0x9, 0x6},{5, 0x9, 0x3},{6, 0x29, 0x0},{6, 0x29, 0x0},{6, 0x29, 0x0}},
/* state = 0x6A (6 bits, 0x2A buffer) */
{{1, 0x0, 0x35},{2, 0x2, 0x1A},{3, 0x2, 0xD},{4, 0xA, 0x6},{5, 0xA, 0x3},{6, 0x2A, 0x0},{6, 0x2A, 0x0},{6, 0x2A, 0x0}},
/* state = 0x6B (6 bits, 0x2B buffer) */
{{1, 0x1, 0x35},{2, 0x3, 0x1A},{3, 0x3, 0xD},{4, 0xB, 0x6},{5, 0xB, 0x3},{6, 0x2B, 0x0},{6, 0x2B, 0x0},{6, 0x2B, 0x0}},
/* state = 0x6C (6 bits, 0x2C buffer) */
{{1, 0x0, 0x36},{2, 0x0, 0x1B},{3, 0x4, 0xD},{4, 0xC, 0x6},{5, 0xC, 0x3},{6, 0x2C, 0x0},{6, 0x2C, 0x0},{6, 0x2C, 0x0}},
/* state = 0x6D (6 bits, 0x2D buffer) */
{{1, 0x1, 0x36},{2, 0x1, 0x1B},{3, 0x5, 0xD},{4, 0xD, 0x6},{5, 0xD, 0x3},{6, 0x2D, 0x0},{6, 0x2D, 0x0},{6, 0x2D, 0x0}},
/* state = 0x6E (6 bits, 0x2E buffer) */
{{1, 0x0, 0x37},{2, 0x2, 0x1B},{3, 0x6, 0xD},{4, 0xE, 0x6},{5, 0xE, 0x3},{6, 0x2E, 0x0},{6, 0x2E, 0x0},{6, 0x2E, 0x0}},
/* state = 0x6F (6 bits, 0x2F buffer) */
{{1, 0x1, 0x37},{2, 0x3, 0x1B},{3, 0x7, 0xD},{4, 0xF, 0x6},{5, 0xF, 0x3},{6, 0x2F, 0x0},{6, 0x2F, 0x0},{6, 0x2F, 0x0}},
/* state = 0x70 (6 bits, 0x30 buffer) */
{{1, 0x0, 0x38},{2, 0x0, 0x1C},{3, 0x0, 0xE},{4, 0x0, 0x7},{5, 0x10, 0x3},{6, 0x30, 0x0},{6, 0x30, 0x0},{6, 0x30, 0x0}},
/* state = 0x71 (6 bits, 0x31 buffer) */
{{1, 0x1, 0x38},{2, 0x1, 0x1C},{3, 0x1, 0xE},{4, 0x1, 0x7},{5, 0x11, 0x3},{6, 0x31, 0x0},{6, 0x31, 0x0},{6, 0x31, 0x0}},
/* state = 0x72 (6 bits, 0x32 buffer) */
{{1, 0x0, 0x39},{2, 0x2, 0x1C},{3, 0x2, 0xE},{4, 0x2, 0x7},{5, 0x12, 0x3},{6, 0x32, 0x0},{6, 0x32, 0x0},{6, 0x32, 0x0}},
/* state = 0x73 (6 bits, 0x33 buffer) */
{{1, 0x1, 0x39},{2, 0x3, 0x1C},{3, 0x3, 0xE},{4, 0x3, 0x7},{5, 0x13, 0x3},{6, 0x33, 0x0},{6, 0x33, 0x0},{6, 0x33, 0x0}},
/* state = 0x74 (6 bits, 0x34 buffer) */
{{1, 0x0, 0x3A},{2, 0x0, 0x1D},{3, 0x4, 0xE},{4, 0x4, 0x7},{5, 0x14, 0x3},{6, 0x34, 0x0},{6, 0x34, 0x0},{6, 0x34, 0x0}},
/* state = 0x75 (6 bits, 0x35 buffer) */
{{1, 0x1, 0x3A},{2, 0x1, 0x1D},{3, 0x5, 0xE},{4, 0x5, 0x7},{5, 0x15, 0x3},{6, 0x35, 0x0},{6, 0x35, 0x0},{6, 0x35, 0x0}},
/* state = 0x76 (6 bits, 0x36 buffer) */
{{1, 0x0, 0x3B},{2, 0x2, 0x1D},{3, 0x6, 0xE},{4, 0x6, 0x7},{5, 0x16, 0x3},{6, 0x36, 0x0},{6, 0x36, 0x0},{6, 0x36, 0x0}},
/* state = 0x77 (6 bits, 0x37 buffer) */
{{1, 0x1, 0x3B},{2, 0x3, 0x1D},{3, 0x7, 0xE},{4, 0x7, 0x7},{5, 0x17, 0x3},{6, 0x37, 0x0},{6, 0x37, 0x0},{6, 0x37, 0x0}},
/* state = 0x78 (6 bits, 0x38 buffer) */
{{1, 0x0, 0x3C},{2, 0x0, 0x1E},{3, 0x0, 0xF},{4, 0x8, 0x7},{5, 0x18, 0x3},{6, 0x38, 0x0},{6, 0x38, 0x0},{6, 0x38, 0x0}},
/* state = 0x79 (6 bits, 0x39 buffer) */
{{1, 0x1, 0x3C},{2, 0x1, 0x1E},{3, 0x1, 0xF},{4, 0x9, 0x7},{5, 0x19, 0x3},{6, 0x39, 0x0},{6, 0x39, 0x0},{6, 0x39, 0x0}},
/* state = 0x7A (6 bits, 0x3A buffer) */
{{1, 0x0, 0x3D},{2, 0x2, 0x1E},{3, 0x2, 0xF},{4, 0xA, 0x7},{5, 0x1A, 0x3},{6, 0x3A, 0x0},{6, 0x3A, 0x0},{6, 0x3A, 0x0}},
/* state = 0x7B (6 bits, 0x3B buffer) */
{{1, 0x1, 0x3D},{2, 0x3, 0x1E},{3, 0x3, 0xF},{4, 0xB, 0x7},{5, 0x1B, 0x3},{6, 0x3B, 0x0},{6, 0x3B, 0x0},{6, 0x3B, 0x0}},
/* state = 0x7C (6 bits, 0x3C buffer) */
{{1, 0x0, 0x3E},{2, 0x0, 0x1F},{3, 0x4, 0xF},{4, 0xC, 0x7},{5, 0x1C, 0x3},{6, 0x3C, 0x0},{6, 0x3C, 0x0},{6, 0x3C, 0x0}},
/* state = 0x7D (6 bits, 0x3D buffer) */
{{1, 0x1, 0x3E},{2, 0x1, 0x1F},{3, 0x5, 0xF},{4, 0xD, 0x7},{5, 0x1D, 0x3},{6, 0x3D, 0x0},{6, 0x3D, 0x0},{6, 0x3D, 0x0}},
/* state = 0x7E (6 bits, 0x3E buffer) */
{{1, 0x0, 0x3F},{2, 0x2, 0x1F},{3, 0x6, 0xF},{4, 0xE, 0x7},{5, 0x1E, 0x3},{6, 0x3E, 0x0},{6, 0x3E, 0x0},{6, 0x3E, 0x0}},
/* state = 0x7F (6 bits, 0x3F buffer) */
{{1, 0x1, 0x3F},{2, 0x3, 0x1F},{3, 0x7, 0xF},{4, 0xF, 0x7},{5, 0x1F, 0x3},{6, 0x3F, 0x0},{6, 0x3F, 0x0},{6, 0x3F, 0x0}},
/* state = 0x80 (7 bits, 0x0 buffer) */
{{1, 0x0, 0x40},{2, 0x0, 0x20},{3, 0x0, 0x10},{4, 0x0, 0x8},{5, 0x0, 0x4},{6, 0x0, 0x2},{7, 0x0, 0x0},{7, 0x0, 0x0}},
/* state = 0x81 (7 bits, 0x1 buffer) */
{{1, 0x1, 0x40},{2, 0x1, 0x20},{3, 0x1, 0x10},{4, 0x1, 0x8},{5, 0x1, 0x4},{6, 0x1, 0x2},{7, 0x1, 0x0},{7, 0x1, 0x0}},
/* state = 0x82 (7 bits, 0x2 buffer) */
{{1, 0x0, 0x41},{2, 0x2, 0x20},{3, 0x2, 0x10},{4, 0x2, 0x8},{5, 0x2, 0x4},{6, 0x2, 0x2},{7, 0x2, 0x0},{7, 0x2, 0x0}},
/* state = 0x83 (7 bits, 0x3 buffer) */
{{1, 0x1, 0x41},{2, 0x3, 0x20},{3, 0x3, 0x10},{4, 0x3, 0x8},{5, 0x3, 0x4},{6, 0x3, 0x2},{7, 0x3, 0x0},{7, 0x3, 0x0}},
/* state = 0x84 (7 bits, 0x4 buffer) */
{{1, 0x0, 0x42},{2, 0x0, 0x21},{3, 0x4, 0x10},{4, 0x4, 0x8},{5, 0x4, 0x4},{6, 0x4, 0x2},{7, 0x4, 0x0},{7, 0x4, 0x0}},
/* state = 0x85 (7 bits, 0x5 buffer) */
{{1, 0x1, 0x42},{2, 0x1, 0x21},{3, 0x5, 0x10},{4, 0x5, 0x8},{5, 0x5, 0x4},{6, 0x5, 0x2},{7, 0x5, 0x0},{7, 0x5, 0x0}},
/* state = 0x86 (7 bits, 0x6 buffer) */
{{1, 0x0, 0x43},{2, 0x2, 0x21},{3, 0x6, 0x10},{4, 0x6, 0x8},{5, 0x6, 0x4},{6, 0x6, 0x2},{7, 0x6, 0x0},{7, 0x6, 0x0}},
/* state = 0x87 (7 bits, 0x7 buffer) */
{{1, 0x1, 0x43},{2, 0x3, 0x21},{3, 0x7, 0x10},{4, 0x7, 0x8},{5, 0x7, 0x4},{6, 0x7, 0x2},{7, 0x7, 0x0},{7, 0x7, 0x0}},
/* state = 0x88 (7 bits, 0x8 buffer) */
{{1, 0x0, 0x44},{2, 0x0, 0x22},{3, 0x0, 0x11},{4, 0x8, 0x8},{5, 0x8, 0x4},{6, 0x8, 0x2},{7, 0x8, 0x0},{7, 0x8, 0x0}},
/* state = 0x89 (7 bits, 0x9 buffer) */
{{1, 0x1, 0x44},{2, 0x1, 0x22},{3, 0x1, 0x11},{4, 0x9, 0x8},{5, 0x9, 0x4},{6, 0x9, 0x2},{7, 0x9, 0x0},{7, 0x9, 0x0}},
/* state = 0x8A (7 bits, 0xA buffer) */
{{1, 0x0, 0x45},{2, 0x2, 0x22},{3, 0x2, 0x11},{4, 0xA, 0x8},{5, 0xA, 0x4},{6, 0xA, 0x2},{7, 0xA, 0x0},{7, 0xA, 0x0}},
/* state = 0x8B (7 bits, 0xB buffer) */
{{1, 0x1, 0x45},{2, 0x3, 0x22},{3, 0x3, 0x11},{4, 0xB, 0x8},{5, 0xB, 0x4},{6, 0xB, 0x2},{7, 0xB, 0x0},{7, 0xB, 0x0}},
/* state = 0x8C (7 bits, 0xC buffer) */
{{1, 0x0, 0x46},{2, 0x0, 0x23},{3, 0x4, 0x11},{4, 0xC, 0x8},{5, 0xC, 0x4},{6, 0xC, 0x2},{7, 0xC, 0x0},{7, 0xC, 0x0}},
/* state = 0x8D (7 bits, 0xD buffer) */
{{1, 0x1, 0x46},{2, 0x1, 0x23},{3, 0x5, 0x11},{4, 0xD, 0x8},{5, 0xD, 0x4},{6, 0xD, 0x2},{7, 0xD, 0x0},{7, 0xD, 0x0}},
/* state = 0x8E (7 bits, 0xE buffer) */
{{1, 0x0, 0x47},{2, 0x2, 0x23},{3, 0x6, 0x11},{4, 0xE, 0x8},{5, 0xE, 0x4},{6, 0xE, 0x2},{7, 0xE, 0x0},{7, 0xE, 0x0}},
/* state = 0x8F (7 bits, 0xF buffer) */
{{1, 0x1, 0x47},{2, 0x3, 0x23},{3, 0x7, 0x11},{4, 0xF, 0x8},{5, 0xF, 0x4},{6, 0xF, 0x2},{7, 0xF, 0x0},{7, 0xF, 0x0}},
/* state = 0x90 (7 bits, 0x10 buffer) */
{{1, 0x0, 0x48},{2, 0x0, 0x24},{3, 0x0, 0x12},{4, 0x0, 0x9},{5, 0x10, 0x4},{6, 0x10, 0x2},{7, 0x10, 0x0},{7, 0x10, 0x0}},
/* state = 0x91 (7 bits, 0x11 buffer) */
{{1, 0x1, 0x48},{2, 0x1, 0x24},{3, 0x1, 0x12},{4, 0x1, 0x9},{5, 0x11, 0x4},{6, 0x11, 0x2},{7, 0x11, 0x0},{7, 0x11, 0x0}},
/* state = 0x92 (7 bits, 0x12 buffer) */
{{1, 0x0, 0x49},{2, 0x2, 0x24},{3, 0x2, 0x12},{4, 0x2, 0x9},{5, 0x12, 0x4},{6, 0x12, 0x2},{7, 0x12, 0x0},{7, 0x12, 0x0}},
/* state = 0x93 (7 bits, 0x13 buffer) */
{{1, 0x1, 0x49},{2, 0x3, 0x24},{3, 0x3, 0x12},{4, 0x3, 0x9},{5, 0x13, 0x4},{6, 0x13, 0x2},{7, 0x13, 0x0},{7, 0x13, 0x0}},
/* state = 0x94 (7 bits, 0x14 buffer) */
{{1, 0x0, 0x4A},{2, 0x0, 0x25},{3, 0x4, 0x12},{4, 0x4, 0x9},{5, 0x14, 0x4},{6, 0x14, 0x2},{7, 0x14, 0x0},{7, 0x14, 0x0}},
/* state = 0x95 (7 bits, 0x15 buffer) */
{{1, 0x1, 0x4A},{2, 0x1, 0x25},{3, 0x5, 0x12},{4, 0x5, 0x9},{5, 0x15, 0x4},{6, 0x15, 0x2},{7, 0x15, 0x0},{7, 0x15, 0x0}},
/* state = 0x96 (7 bits, 0x16 buffer) */
{{1, 0x0, 0x4B},{2, 0x2, 0x25},{3, 0x6, 0x12},{4, 0x6, 0x9},{5, 0x16, 0x4},{6, 0x16, 0x2},{7, 0x16, 0x0},{7, 0x16, 0x0}},
/* state = 0x97 (7 bits, 0x17 buffer) */
{{1, 0x1, 0x4B},{2, 0x3, 0x25},{3, 0x7, 0x12},{4, 0x7, 0x9},{5, 0x17, 0x4},{6, 0x17, 0x2},{7, 0x17, 0x0},{7, 0x17, 0x0}},
/* state = 0x98 (7 bits, 0x18 buffer) */
{{1, 0x0, 0x4C},{2, 0x0, 0x26},{3, 0x0, 0x13},{4, 0x8, 0x9},{5, 0x18, 0x4},{6, 0x18, 0x2},{7, 0x18, 0x0},{7, 0x18, 0x0}},
/* state = 0x99 (7 bits, 0x19 buffer) */
{{1, 0x1, 0x4C},{2, 0x1, 0x26},{3, 0x1, 0x13},{4, 0x9, 0x9},{5, 0x19, 0x4},{6, 0x19, 0x2},{7, 0x19, 0x0},{7, 0x19, 0x0}},
/* state = 0x9A (7 bits, 0x1A buffer) */
{{1, 0x0, 0x4D},{2, 0x2, 0x26},{3, 0x2, 0x13},{4, 0xA, 0x9},{5, 0x1A, 0x4},{6, 0x1A, 0x2},{7, 0x1A, 0x0},{7, 0x1A, 0x0}},
/* state = 0x9B (7 bits, 0x1B buffer) */
{{1, 0x1, 0x4D},{2, 0x3, 0x26},{3, 0x3, 0x13},{4, 0xB, 0x9},{5, 0x1B, 0x4},{6, 0x1B, 0x2},{7, 0x1B, 0x0},{7, 0x1B, 0x0}},
/* state = 0x9C (7 bits, 0x1C buffer) */
{{1, 0x0, 0x4E},{2, 0x0, 0x27},{3, 0x4, 0x13},{4, 0xC, 0x9},{5, 0x1C, 0x4},{6, 0x1C, 0x2},{7, 0x1C, 0x0},{7, 0x1C, 0x0}},
/* state = 0x9D (7 bits, 0x1D buffer) */
{{1, 0x1, 0x4E},{2, 0x1, 0x27},{3, 0x5, 0x13},{4, 0xD, 0x9},{5, 0x1D, 0x4},{6, 0x1D, 0x2},{7, 0x1D, 0x0},{7, 0x1D, 0x0}},
/* state = 0x9E (7 bits, 0x1E buffer) */
{{1, 0x0, 0x4F},{2, 0x2, 0x27},{3, 0x6, 0x13},{4, 0xE, 0x9},{5, 0x1E, 0x4},{6, 0x1E, 0x2},{7, 0x1E, 0x0},{7, 0x1E, 0x0}},
/* state = 0x9F (7 bits, 0x1F buffer) */
{{1, 0x1, 0x4F},{2, 0x3, 0x27},{3, 0x7, 0x13},{4, 0xF, 0x9},{5, 0x1F, 0x4},{6, 0x1F, 0x2},{7, 0x1F, 0x0},{7, 0x1F, 0x0}},
/* state = 0xA0 (7 bits, 0x20 buffer) */
{{1, 0x0, 0x50},{2, 0x0, 0x28},{3, 0x0, 0x14},{4, 0x0, 0xA},{5, 0x0, 0x5},{6, 0x20, 0x2},{7, 0x20, 0x0},{7, 0x20, 0x0}},
/* state = 0xA1 (7 bits, 0x21 buffer) */
{{1, 0x1, 0x50},{2, 0x1, 0x28},{3, 0x1, 0x14},{4, 0x1, 0xA},{5, 0x1, 0x5},{6, 0x21, 0x2},{7, 0x21, 0x0},{7, 0x21, 0x0}},
/* state = 0xA2 (7 bits, 0x22 buffer) */
{{1, 0x0, 0x51},{2, 0x2, 0x28},{3, 0x2, 0x14},{4, 0x2, 0xA},{5, 0x2, 0x5},{6, 0x22, 0x2},{7, 0x22, 0x0},{7, 0x22, 0x0}},
/* state = 0xA3 (7 bits, 0x23 buffer) */
{{1, 0x1, 0x51},{2, 0x3, 0x28},{3, 0x3, 0x14},{4, 0x3, 0xA},{5, 0x3, 0x5},{6, 0x23, 0x2},{7, 0x23, 0x0},{7, 0x23, 0x0}},
/* state = 0xA4 (7 bits, 0x24 buffer) */
{{1, 0x0, 0x52},{2, 0x0, 0x29},{3, 0x4, 0x14},{4, 0x4, 0xA},{5, 0x4, 0x5},{6, 0x24, 0x2},{7, 0x24, 0x0},{7, 0x24, 0x0}},
/* state = 0xA5 (7 bits, 0x25 buffer) */
{{1, 0x1, 0x52},{2, 0x1, 0x29},{3, 0x5, 0x14},{4, 0x5, 0xA},{5, 0x5, 0x5},{6, 0x25, 0x2},{7, 0x25, 0x0},{7, 0x25, 0x0}},
/* state = 0xA6 (7 bits, 0x26 buffer) */
{{1, 0x0, 0x53},{2, 0x2, 0x29},{3, 0x6, 0x14},{4, 0x6, 0xA},{5, 0x6, 0x5},{6, 0x26, 0x2},{7, 0x26, 0x0},{7, 0x26, 0x0}},
/* state = 0xA7 (7 bits, 0x27 buffer) */
{{1, 0x1, 0x53},{2, 0x3, 0x29},{3, 0x7, 0x14},{4, 0x7, 0xA},{5, 0x7, 0x5},{6, 0x27, 0x2},{7, 0x27, 0x0},{7, 0x27, 0x0}},
/* state = 0xA8 (7 bits, 0x28 buffer) */
{{1, 0x0, 0x54},{2, 0x0, 0x2A},{3, 0x0, 0x15},{4, 0x8, 0xA},{5, 0x8, 0x5},{6, 0x28, 0x2},{7, 0x28, 0x0},{7, 0x28, 0x0}},
/* state = 0xA9 (7 bits, 0x29 buffer) */
{{1, 0x1, 0x54},{2, 0x1, 0x2A},{3, 0x1, 0x15},{4, 0x9, 0xA},{5, 0x9, 0x5},{6, 0x29, 0x2},{7, 0x29, 0x0},{7, 0x29, 0x0}},
/* state = 0xAA (7 bits, 0x2A buffer) */
{{1, 0x0, 0x55},{2, 0x2, 0x2A},{3, 0x2, 0x15},{4, 0xA, 0xA},{5, 0xA, 0x5},{6, 0x2A, 0x2},{7, 0x2A, 0x0},{7, 0x2A, 0x0}},
/* state = 0xAB (7 bits, 0x2B buffer) */
{{1, 0x1, 0x55},{2, 0x3, 0x2A},{3, 0x3, 0x15},{4, 0xB, 0xA},{5, 0xB, 0x5},{6, 0x2B, 0x2},{7, 0x2B, 0x0},{7, 0x2B, 0x0}},
/* state = 0xAC (7 bits, 0x2C buffer) */
{{1, 0x0, 0x56},{2, 0x0, 0x2B},{3, 0x4, 0x15},{4, 0xC, 0xA},{5, 0xC, 0x5},{6, 0x2C, 0x2},{7, 0x2C, 0x0},{7, 0x2C, 0x0}},
/* state = 0xAD (7 bits, 0x2D buffer) */
{{1, 0x1, 0x56},{2, 0x1, 0x2B},{3, 0x5, 0x15},{4, 0xD, 0xA},{5, 0xD, 0x5},{6, 0x2D, 0x2},{7, 0x2D, 0x0},{7, 0x2D, 0x0}},
/* state = 0xAE (7 bits, 0x2E buffer) */
{{1, 0x0, 0x57},{2, 0x2, 0x2B},{3, 0x6, 0x15},{4, 0xE, 0xA},{5, 0xE, 0x5},{6, 0x2E, 0x2},{7, 0x2E, 0x0},{7, 0x2E, 0x0}},
/* state = 0xAF (7 bits, 0x2F buffer) */
{{1, 0x1, 0x57},{2, 0x3, 0x2B},{3, 0x7, 0x15},{4, 0xF, 0xA},{5, 0xF, 0x5},{6, 0x2F, 0x2},{7, 0x2F, 0x0},{7, 0x2F, 0x0}},
/* state = 0xB0 (7 bits, 0x30 buffer) */
{{1, 0x0, 0x58},{2, 0x0, 0x2C},{3, 0x0, 0x16},{4, 0x0, 0xB},{5, 0x10, 0x5},{6, 0x30, 0x2},{7, 0x30, 0x0},{7, 0x30, 0x0}},
/* state = 0xB1 (7 bits, 0x31 buffer) */
{{1, 0x1, 0x58},{2, 0x1, 0x2C},{3, 0x1, 0x16},{4, 0x1, 0xB},{5, 0x11, 0x5},{6, 0x31, 0x2},{7, 0x31, 0x0},{7, 0x31, 0x0}},
/* state = 0xB2 (7 bits, 0x32 buffer) */
{{1, 0x0, 0x59},{2, 0x2, 0x2C},{3, 0x2, 0x16},{4, 0x2, 0xB},{5, 0x12, 0x5},{6, 0x32, 0x2},{7, 0x32, 0x0},{7, 0x32, 0x0}},
/* state = 0xB3 (7 bits, 0x33 buffer) */
{{1, 0x1, 0x59},{2, 0x3, 0x2C},{3, 0x3, 0x16},{4, 0x3, 0xB},{5, 0x13, 0x5},{6, 0x33, 0x2},{7, 0x33, 0x0},{7, 0x33, 0x0}},
/* state = 0xB4 (7 bits, 0x34 buffer) */
{{1, 0x0, 0x5A},{2, 0x0, 0x2D},{3, 0x4, 0x16},{4, 0x4, 0xB},{5, 0x14, 0x5},{6, 0x34, 0x2},{7, 0x34, 0x0},{7, 0x34, 0x0}},
/* state = 0xB5 (7 bits, 0x35 buffer) */
{{1, 0x1, 0x5A},{2, 0x1, 0x2D},{3, 0x5, 0x16},{4, 0x5, 0xB},{5, 0x15, 0x5},{6, 0x35, 0x2},{7, 0x35, 0x0},{7, 0x35, 0x0}},
/* state = 0xB6 (7 bits, 0x36 buffer) */
{{1, 0x0, 0x5B},{2, 0x2, 0x2D},{3, 0x6, 0x16},{4, 0x6, 0xB},{5, 0x16, 0x5},{6, 0x36, 0x2},{7, 0x36, 0x0},{7, 0x36, 0x0}},
/* state = 0xB7 (7 bits, 0x37 buffer) */
{{1, 0x1, 0x5B},{2, 0x3, 0x2D},{3, 0x7, 0x16},{4, 0x7, 0xB},{5, 0x17, 0x5},{6, 0x37, 0x2},{7, 0x37, 0x0},{7, 0x37, 0x0}},
/* state = 0xB8 (7 bits, 0x38 buffer) */
{{1, 0x0, 0x5C},{2, 0x0, 0x2E},{3, 0x0, 0x17},{4, 0x8, 0xB},{5, 0x18, 0x5},{6, 0x38, 0x2},{7, 0x38, 0x0},{7, 0x38, 0x0}},
/* state = 0xB9 (7 bits, 0x39 buffer) */
{{1, 0x1, 0x5C},{2, 0x1, 0x2E},{3, 0x1, 0x17},{4, 0x9, 0xB},{5, 0x19, 0x5},{6, 0x39, 0x2},{7, 0x39, 0x0},{7, 0x39, 0x0}},
/* state = 0xBA (7 bits, 0x3A buffer) */
{{1, 0x0, 0x5D},{2, 0x2, 0x2E},{3, 0x2, 0x17},{4, 0xA, 0xB},{5, 0x1A, 0x5},{6, 0x3A, 0x2},{7, 0x3A, 0x0},{7, 0x3A, 0x0}},
/* state = 0xBB (7 bits, 0x3B buffer) */
{{1, 0x1, 0x5D},{2, 0x3, 0x2E},{3, 0x3, 0x17},{4, 0xB, 0xB},{5, 0x1B, 0x5},{6, 0x3B, 0x2},{7, 0x3B, 0x0},{7, 0x3B, 0x0}},
/* state = 0xBC (7 bits, 0x3C buffer) */
{{1, 0x0, 0x5E},{2, 0x0, 0x2F},{3, 0x4, 0x17},{4, 0xC, 0xB},{5, 0x1C, 0x5},{6, 0x3C, 0x2},{7, 0x3C, 0x0},{7, 0x3C, 0x0}},
/* state = 0xBD (7 bits, 0x3D buffer) */
{{1, 0x1, 0x5E},{2, 0x1, 0x2F},{3, 0x5, 0x17},{4, 0xD, 0xB},{5, 0x1D, 0x5},{6, 0x3D, 0x2},{7, 0x3D, 0x0},{7, 0x3D, 0x0}},
/* state = 0xBE (7 bits, 0x3E buffer) */
{{1, 0x0, 0x5F},{2, 0x2, 0x2F},{3, 0x6, 0x17},{4, 0xE, 0xB},{5, 0x1E, 0x5},{6, 0x3E, 0x2},{7, 0x3E, 0x0},{7, 0x3E, 0x0}},
/* state = 0xBF (7 bits, 0x3F buffer) */
{{1, 0x1, 0x5F},{2, 0x3, 0x2F},{3, 0x7, 0x17},{4, 0xF, 0xB},{5, 0x1F, 0x5},{6, 0x3F, 0x2},{7, 0x3F, 0x0},{7, 0x3F, 0x0}},
/* state = 0xC0 (7 bits, 0x40 buffer) */
{{1, 0x0, 0x60},{2, 0x0, 0x30},{3, 0x0, 0x18},{4, 0x0, 0xC},{5, 0x0, 0x6},{6, 0x0, 0x3},{7, 0x40, 0x0},{7, 0x40, 0x0}},
/* state = 0xC1 (7 bits, 0x41 buffer) */
{{1, 0x1, 0x60},{2, 0x1, 0x30},{3, 0x1, 0x18},{4, 0x1, 0xC},{5, 0x1, 0x6},{6, 0x1, 0x3},{7, 0x41, 0x0},{7, 0x41, 0x0}},
/* state = 0xC2 (7 bits, 0x42 buffer) */
{{1, 0x0, 0x61},{2, 0x2, 0x30},{3, 0x2, 0x18},{4, 0x2, 0xC},{5, 0x2, 0x6},{6, 0x2, 0x3},{7, 0x42, 0x0},{7, 0x42, 0x0}},
/* state = 0xC3 (7 bits, 0x43 buffer) */
{{1, 0x1, 0x61},{2, 0x3, 0x30},{3, 0x3, 0x18},{4, 0x3, 0xC},{5, 0x3, 0x6},{6, 0x3, 0x3},{7, 0x43, 0x0},{7, 0x43, 0x0}},
/* state = 0xC4 (7 bits, 0x44 buffer) */
{{1, 0x0, 0x62},{2, 0x0, 0x31},{3, 0x4, 0x18},{4, 0x4, 0xC},{5, 0x4, 0x6},{6, 0x4, 0x3},{7, 0x44, 0x0},{7, 0x44, 0x0}},
/* state = 0xC5 (7 bits, 0x45 buffer) */
{{1, 0x1, 0x62},{2, 0x1, 0x31},{3, 0x5, 0x18},{4, 0x5, 0xC},{5, 0x5, 0x6},{6, 0x5, 0x3},{7, 0x45, 0x0},{7, 0x45, 0x0}},
/* state = 0xC6 (7 bits, 0x46 buffer) */
{{1, 0x0, 0x63},{2, 0x2, 0x31},{3, 0x6, 0x18},{4, 0x6, 0xC},{5, 0x6, 0x6},{6, 0x6, 0x3},{7, 0x46, 0x0},{7, 0x46, 0x0}},
/* state = 0xC7 (7 bits, 0x47 buffer) */
{{1, 0x1, 0x63},{2, 0x3, 0x31},{3, 0x7, 0x18},{4, 0x7, 0xC},{5, 0x7, 0x6},{6, 0x7, 0x3},{7, 0x47, 0x0},{7, 0x47, 0x0}},
/* state = 0xC8 (7 bits, 0x48 buffer) */
{{1, 0x0, 0x64},{2, 0x0, 0x32},{3, 0x0, 0x19},{4, 0x8, 0xC},{5, 0x8, 0x6},{6, 0x8, 0x3},{7, 0x48, 0x0},{7, 0x48, 0x0}},
/* state = 0xC9 (7 bits, 0x49 buffer) */
{{1, 0x1, 0x64},{2, 0x1, 0x32},{3, 0x1, 0x19},{4, 0x9, 0xC},{5, 0x9, 0x6},{6, 0x9, 0x3},{7, 0x49, 0x0},{7, 0x49, 0x0}},
/* state = 0xCA (7 bits, 0x4A buffer) */
{{1, 0x0, 0x65},{2, 0x2, 0x32},{3, 0x2, 0x19},{4, 0xA, 0xC},{5, 0xA, 0x6},{6, 0xA, 0x3},{7, 0x4A, 0x0},{7, 0x4A, 0x0}},
/* state = 0xCB (7 bits, 0x4B buffer) */
{{1, 0x1, 0x65},{2, 0x3, 0x32},{3, 0x3, 0x19},{4, 0xB, 0xC},{5, 0xB, 0x6},{6, 0xB, 0x3},{7, 0x4B, 0x0},{7, 0x4B, 0x0}},
/* state = 0xCC (7 bits, 0x4C buffer) */
{{1, 0x0, 0x66},{2, 0x0, 0x33},{3, 0x4, 0x19},{4, 0xC, 0xC},{5, 0xC, 0x6},{6, 0xC, 0x3},{7, 0x4C, 0x0},{7, 0x4C, 0x0}},
/* state = 0xCD (7 bits, 0x4D buffer) */
{{1, 0x1, 0x66},{2, 0x1, 0x33},{3, 0x5, 0x19},{4, 0xD, 0xC},{5, 0xD, 0x6},{6, 0xD, 0x3},{7, 0x4D, 0x0},{7, 0x4D, 0x0}},
/* state = 0xCE (7 bits, 0x4E buffer) */
{{1, 0x0, 0x67},{2, 0x2, 0x33},{3, 0x6, 0x19},{4, 0xE, 0xC},{5, 0xE, 0x6},{6, 0xE, 0x3},{7, 0x4E, 0x0},{7, 0x4E, 0x0}},
/* state = 0xCF (7 bits, 0x4F buffer) */
{{1, 0x1, 0x67},{2, 0x3, 0x33},{3, 0x7, 0x19},{4, 0xF, 0xC},{5, 0xF, 0x6},{6, 0xF, 0x3},{7, 0x4F, 0x0},{7, 0x4F, 0x0}},
/* state = 0xD0 (7 bits, 0x50 buffer) */
{{1, 0x0, 0x68},{2, 0x0, 0x34},{3, 0x0, 0x1A},{4, 0x0, 0xD},{5, 0x10, 0x6},{6, 0x10, 0x3},{7, 0x50, 0x0},{7, 0x50, 0x0}},
/* state = 0xD1 (7 bits, 0x51 buffer) */
{{1, 0x1, 0x68},{2, 0x1, 0x34},{3, 0x1, 0x1A},{4, 0x1, 0xD},{5, 0x11, 0x6},{6, 0x11, 0x3},{7, 0x51, 0x0},{7, 0x51, 0x0}},
/* state = 0xD2 (7 bits, 0x52 buffer) */
{{1, 0x0, 0x69},{2, 0x2, 0x34},{3, 0x2, 0x1A},{4, 0x2, 0xD},{5, 0x12, 0x6},{6, 0x12, 0x3},{7, 0x52, 0x0},{7, 0x52, 0x0}},
/* state = 0xD3 (7 bits, 0x53 buffer) */
{{1, 0x1, 0x69},{2, 0x3, 0x34},{3, 0x3, 0x1A},{4, 0x3, 0xD},{5, 0x13, 0x6},{6, 0x13, 0x3},{7, 0x53, 0x0},{7, 0x53, 0x0}},
/* state = 0xD4 (7 bits, 0x54 buffer) */
{{1, 0x0, 0x6A},{2, 0x0, 0x35},{3, 0x4, 0x1A},{4, 0x4, 0xD},{5, 0x14, 0x6},{6, 0x14, 0x3},{7, 0x54, 0x0},{7, 0x54, 0x0}},
/* state = 0xD5 (7 bits, 0x55 buffer) */
{{1, 0x1, 0x6A},{2, 0x1, 0x35},{3, 0x5, 0x1A},{4, 0x5, 0xD},{5, 0x15, 0x6},{6, 0x15, 0x3},{7, 0x55, 0x0},{7, 0x55, 0x0}},
/* state = 0xD6 (7 bits, 0x56 buffer) */
{{1, 0x0, 0x6B},{2, 0x2, 0x35},{3, 0x6, 0x1A},{4, 0x6, 0xD},{5, 0x16, 0x6},{6, 0x16, 0x3},{7, 0x56, 0x0},{7, 0x56, 0x0}},
/* state = 0xD7 (7 bits, 0x57 buffer) */
{{1, 0x1, 0x6B},{2, 0x3, 0x35},{3, 0x7, 0x1A},{4, 0x7, 0xD},{5, 0x17, 0x6},{6, 0x17, 0x3},{7, 0x57, 0x0},{7, 0x57, 0x0}},
/* state = 0xD8 (7 bits, 0x58 buffer) */
{{1, 0x0, 0x6C},{2, 0x0, 0x36},{3, 0x0, 0x1B},{4, 0x8, 0xD},{5, 0x18, 0x6},{6, 0x18, 0x3},{7, 0x58, 0x0},{7, 0x58, 0x0}},
/* state = 0xD9 (7 bits, 0x59 buffer) */
{{1, 0x1, 0x6C},{2, 0x1, 0x36},{3, 0x1, 0x1B},{4, 0x9, 0xD},{5, 0x19, 0x6},{6, 0x19, 0x3},{7, 0x59, 0x0},{7, 0x59, 0x0}},
/* state = 0xDA (7 bits, 0x5A buffer) */
{{1, 0x0, 0x6D},{2, 0x2, 0x36},{3, 0x2, 0x1B},{4, 0xA, 0xD},{5, 0x1A, 0x6},{6, 0x1A, 0x3},{7, 0x5A, 0x0},{7, 0x5A, 0x0}},
/* state = 0xDB (7 bits, 0x5B buffer) */
{{1, 0x1, 0x6D},{2, 0x3, 0x36},{3, 0x3, 0x1B},{4, 0xB, 0xD},{5, 0x1B, 0x6},{6, 0x1B, 0x3},{7, 0x5B, 0x0},{7, 0x5B, 0x0}},
/* state = 0xDC (7 bits, 0x5C buffer) */
{{1, 0x0, 0x6E},{2, 0x0, 0x37},{3, 0x4, 0x1B},{4, 0xC, 0xD},{5, 0x1C, 0x6},{6, 0x1C, 0x3},{7, 0x5C, 0x0},{7, 0x5C, 0x0}},
/* state = 0xDD (7 bits, 0x5D buffer) */
{{1, 0x1, 0x6E},{2, 0x1, 0x37},{3, 0x5, 0x1B},{4, 0xD, 0xD},{5, 0x1D, 0x6},{6, 0x1D, 0x3},{7, 0x5D, 0x0},{7, 0x5D, 0x0}},
/* state = 0xDE (7 bits, 0x5E buffer) */
{{1, 0x0, 0x6F},{2, 0x2, 0x37},{3, 0x6, 0x1B},{4, 0xE, 0xD},{5, 0x1E, 0x6},{6, 0x1E, 0x3},{7, 0x5E, 0x0},{7, 0x5E, 0x0}},
/* state = 0xDF (7 bits, 0x5F buffer) */
{{1, 0x1, 0x6F},{2, 0x3, 0x37},{3, 0x7, 0x1B},{4, 0xF, 0xD},{5, 0x1F, 0x6},{6, 0x1F, 0x3},{7, 0x5F, 0x0},{7, 0x5F, 0x0}},
/* state = 0xE0 (7 bits, 0x60 buffer) */
{{1, 0x0, 0x70},{2, 0x0, 0x38},{3, 0x0, 0x1C},{4, 0x0, 0xE},{5, 0x0, 0x7},{6, 0x20, 0x3},{7, 0x60, 0x0},{7, 0x60, 0x0}},
/* state = 0xE1 (7 bits, 0x61 buffer) */
{{1, 0x1, 0x70},{2, 0x1, 0x38},{3, 0x1, 0x1C},{4, 0x1, 0xE},{5, 0x1, 0x7},{6, 0x21, 0x3},{7, 0x61, 0x0},{7, 0x61, 0x0}},
/* state = 0xE2 (7 bits, 0x62 buffer) */
{{1, 0x0, 0x71},{2, 0x2, 0x38},{3, 0x2, 0x1C},{4, 0x2, 0xE},{5, 0x2, 0x7},{6, 0x22, 0x3},{7, 0x62, 0x0},{7, 0x62, 0x0}},
/* state = 0xE3 (7 bits, 0x63 buffer) */
{{1, 0x1, 0x71},{2, 0x3, 0x38},{3, 0x3, 0x1C},{4, 0x3, 0xE},{5, 0x3, 0x7},{6, 0x23, 0x3},{7, 0x63, 0x0},{7, 0x63, 0x0}},
/* state = 0xE4 (7 bits, 0x64 buffer) */
{{1, 0x0, 0x72},{2, 0x0, 0x39},{3, 0x4, 0x1C},{4, 0x4, 0xE},{5, 0x4, 0x7},{6, 0x24, 0x3},{7, 0x64, 0x0},{7, 0x64, 0x0}},
/* state = 0xE5 (7 bits, 0x65 buffer) */
{{1, 0x1, 0x72},{2, 0x1, 0x39},{3, 0x5, 0x1C},{4, 0x5, 0xE},{5, 0x5, 0x7},{6, 0x25, 0x3},{7, 0x65, 0x0},{7, 0x65, 0x0}},
/* state = 0xE6 (7 bits, 0x66 buffer) */
{{1, 0x0, 0x73},{2, 0x2, 0x39},{3, 0x6, 0x1C},{4, 0x6, 0xE},{5, 0x6, 0x7},{6, 0x26, 0x3},{7, 0x66, 0x0},{7, 0x66, 0x0}},
/* state = 0xE7 (7 bits, 0x67 buffer) */
{{1, 0x1, 0x73},{2, 0x3, 0x39},{3, 0x7, 0x1C},{4, 0x7, 0xE},{5, 0x7, 0x7},{6, 0x27, 0x3},{7, 0x67, 0x0},{7, 0x67, 0x0}},
/* state = 0xE8 (7 bits, 0x68 buffer) */
{{1, 0x0, 0x74},{2, 0x0, 0x3A},{3, 0x0, 0x1D},{4, 0x8, 0xE},{5, 0x8, 0x7},{6, 0x28, 0x3},{7, 0x68, 0x0},{7, 0x68, 0x0}},
/* state = 0xE9 (7 bits, 0x69 buffer) */
{{1, 0x1, 0x74},{2, 0x1, 0x3A},{3, 0x1, 0x1D},{4, 0x9, 0xE},{5, 0x9, 0x7},{6, 0x29, 0x3},{7, 0x69, 0x0},{7, 0x69, 0x0}},
/* state = 0xEA (7 bits, 0x6A buffer) */
{{1, 0x0, 0x75},{2, 0x2, 0x3A},{3, 0x2, 0x1D},{4, 0xA, 0xE},{5, 0xA, 0x7},{6, 0x2A, 0x3},{7, 0x6A, 0x0},{7, 0x6A, 0x0}},
/* state = 0xEB (7 bits, 0x6B buffer) */
{{1, 0x1, 0x75},{2, 0x3, 0x3A},{3, 0x3, 0x1D},{4, 0xB, 0xE},{5, 0xB, 0x7},{6, 0x2B, 0x3},{7, 0x6B, 0x0},{7, 0x6B, 0x0}},
/* state = 0xEC (7 bits, 0x6C buffer) */
{{1, 0x0, 0x76},{2, 0x0, 0x3B},{3, 0x4, 0x1D},{4, 0xC, 0xE},{5, 0xC, 0x7},{6, 0x2C, 0x3},{7, 0x6C, 0x0},{7, 0x6C, 0x0}},
/* state = 0xED (7 bits, 0x6D buffer) */
{{1, 0x1, 0x76},{2, 0x1, 0x3B},{3, 0x5, 0x1D},{4, 0xD, 0xE},{5, 0xD, 0x7},{6, 0x2D, 0x3},{7, 0x6D, 0x0},{7, 0x6D, 0x0}},
/* state = 0xEE (7 bits, 0x6E buffer) */
{{1, 0x0, 0x77},{2, 0x2, 0x3B},{3, 0x6, 0x1D},{4, 0xE, 0xE},{5, 0xE, 0x7},{6, 0x2E, 0x3},{7, 0x6E, 0x0},{7, 0x6E, 0x0}},
/* state = 0xEF (7 bits, 0x6F buffer) */
{{1, 0x1, 0x77},{2, 0x3, 0x3B},{3, 0x7, 0x1D},{4, 0xF, 0xE},{5, 0xF, 0x7},{6, 0x2F, 0x3},{7, 0x6F, 0x0},{7, 0x6F, 0x0}},
/* state = 0xF0 (7 bits, 0x70 buffer) */
{{1, 0x0, 0x78},{2, 0x0, 0x3C},{3, 0x0, 0x1E},{4, 0x0, 0xF},{5, 0x10, 0x7},{6, 0x30, 0x3},{7, 0x70, 0x0},{7, 0x70, 0x0}},
/* state = 0xF1 (7 bits, 0x71 buffer) */
{{1, 0x1, 0x78},{2, 0x1, 0x3C},{3, 0x1, 0x1E},{4, 0x1, 0xF},{5, 0x11, 0x7},{6, 0x31, 0x3},{7, 0x71, 0x0},{7, 0x71, 0x0}},
/* state = 0xF2 (7 bits, 0x72 buffer) */
{{1, 0x0, 0x79},{2, 0x2, 0x3C},{3, 0x2, 0x1E},{4, 0x2, 0xF},{5, 0x12, 0x7},{6, 0x32, 0x3},{7, 0x72, 0x0},{7, 0x72, 0x0}},
/* state = 0xF3 (7 bits, 0x73 buffer) */
{{1, 0x1, 0x79},{2, 0x3, 0x3C},{3, 0x3, 0x1E},{4, 0x3, 0xF},{5, 0x13, 0x7},{6, 0x33, 0x3},{7, 0x73, 0x0},{7, 0x73, 0x0}},
/* state = 0xF4 (7 bits, 0x74 buffer) */
{{1, 0x0, 0x7A},{2, 0x0, 0x3D},{3, 0x4, 0x1E},{4, 0x4, 0xF},{5, 0x14, 0x7},{6, 0x34, 0x3},{7, 0x74, 0x0},{7, 0x74, 0x0}},
/* state = 0xF5 (7 bits, 0x75 buffer) */
{{1, 0x1, 0x7A},{2, 0x1, 0x3D},{3, 0x5, 0x1E},{4, 0x5, 0xF},{5, 0x15, 0x7},{6, 0x35, 0x3},{7, 0x75, 0x0},{7, 0x75, 0x0}},
/* state = 0xF6 (7 bits, 0x76 buffer) */
{{1, 0x0, 0x7B},{2, 0x2, 0x3D},{3, 0x6, 0x1E},{4, 0x6, 0xF},{5, 0x16, 0x7},{6, 0x36, 0x3},{7, 0x76, 0x0},{7, 0x76, 0x0}},
/* state = 0xF7 (7 bits, 0x77 buffer) */
{{1, 0x1, 0x7B},{2, 0x3, 0x3D},{3, 0x7, 0x1E},{4, 0x7, 0xF},{5, 0x17, 0x7},{6, 0x37, 0x3},{7, 0x77, 0x0},{7, 0x77, 0x0}},
/* state = 0xF8 (7 bits, 0x78 buffer) */
{{1, 0x0, 0x7C},{2, 0x0, 0x3E},{3, 0x0, 0x1F},{4, 0x8, 0xF},{5, 0x18, 0x7},{6, 0x38, 0x3},{7, 0x78, 0x0},{7, 0x78, 0x0}},
/* state = 0xF9 (7 bits, 0x79 buffer) */
{{1, 0x1, 0x7C},{2, 0x1, 0x3E},{3, 0x1, 0x1F},{4, 0x9, 0xF},{5, 0x19, 0x7},{6, 0x39, 0x3},{7, 0x79, 0x0},{7, 0x79, 0x0}},
/* state = 0xFA (7 bits, 0x7A buffer) */
{{1, 0x0, 0x7D},{2, 0x2, 0x3E},{3, 0x2, 0x1F},{4, 0xA, 0xF},{5, 0x1A, 0x7},{6, 0x3A, 0x3},{7, 0x7A, 0x0},{7, 0x7A, 0x0}},
/* state = 0xFB (7 bits, 0x7B buffer) */
{{1, 0x1, 0x7D},{2, 0x3, 0x3E},{3, 0x3, 0x1F},{4, 0xB, 0xF},{5, 0x1B, 0x7},{6, 0x3B, 0x3},{7, 0x7B, 0x0},{7, 0x7B, 0x0}},
/* state = 0xFC (7 bits, 0x7C buffer) */
{{1, 0x0, 0x7E},{2, 0x0, 0x3F},{3, 0x4, 0x1F},{4, 0xC, 0xF},{5, 0x1C, 0x7},{6, 0x3C, 0x3},{7, 0x7C, 0x0},{7, 0x7C, 0x0}},
/* state = 0xFD (7 bits, 0x7D buffer) */
{{1, 0x1, 0x7E},{2, 0x1, 0x3F},{3, 0x5, 0x1F},{4, 0xD, 0xF},{5, 0x1D, 0x7},{6, 0x3D, 0x3},{7, 0x7D, 0x0},{7, 0x7D, 0x0}},
/* state = 0xFE (7 bits, 0x7E buffer) */
{{1, 0x0, 0x7F},{2, 0x2, 0x3F},{3, 0x6, 0x1F},{4, 0xE, 0xF},{5, 0x1E, 0x7},{6, 0x3E, 0x3},{7, 0x7E, 0x0},{7, 0x7E, 0x0}},
/* state = 0xFF (7 bits, 0x7F buffer) */
{{1, 0x1, 0x7F},{2, 0x3, 0x3F},{3, 0x7, 0x1F},{4, 0xF, 0xF},{5, 0x1F, 0x7},{6, 0x3F, 0x3},{7, 0x7F, 0x0},{7, 0x7F, 0x0}},
/* state = 0x100 (8 bits, 0x0 buffer) */
{{1, 0x0, 0x80},{2, 0x0, 0x40},{3, 0x0, 0x20},{4, 0x0, 0x10},{5, 0x0, 0x8},{6, 0x0, 0x4},{7, 0x0, 0x2},{8, 0x0, 0x0}},
/* state = 0x101 (8 bits, 0x1 buffer) */
{{1, 0x1, 0x80},{2, 0x1, 0x40},{3, 0x1, 0x20},{4, 0x1, 0x10},{5, 0x1, 0x8},{6, 0x1, 0x4},{7, 0x1, 0x2},{8, 0x1, 0x0}},
/* state = 0x102 (8 bits, 0x2 buffer) */
{{1, 0x0, 0x81},{2, 0x2, 0x40},{3, 0x2, 0x20},{4, 0x2, 0x10},{5, 0x2, 0x8},{6, 0x2, 0x4},{7, 0x2, 0x2},{8, 0x2, 0x0}},
/* state = 0x103 (8 bits, 0x3 buffer) */
{{1, 0x1, 0x81},{2, 0x3, 0x40},{3, 0x3, 0x20},{4, 0x3, 0x10},{5, 0x3, 0x8},{6, 0x3, 0x4},{7, 0x3, 0x2},{8, 0x3, 0x0}},
/* state = 0x104 (8 bits, 0x4 buffer) */
{{1, 0x0, 0x82},{2, 0x0, 0x41},{3, 0x4, 0x20},{4, 0x4, 0x10},{5, 0x4, 0x8},{6, 0x4, 0x4},{7, 0x4, 0x2},{8, 0x4, 0x0}},
/* state = 0x105 (8 bits, 0x5 buffer) */
{{1, 0x1, 0x82},{2, 0x1, 0x41},{3, 0x5, 0x20},{4, 0x5, 0x10},{5, 0x5, 0x8},{6, 0x5, 0x4},{7, 0x5, 0x2},{8, 0x5, 0x0}},
/* state = 0x106 (8 bits, 0x6 buffer) */
{{1, 0x0, 0x83},{2, 0x2, 0x41},{3, 0x6, 0x20},{4, 0x6, 0x10},{5, 0x6, 0x8},{6, 0x6, 0x4},{7, 0x6, 0x2},{8, 0x6, 0x0}},
/* state = 0x107 (8 bits, 0x7 buffer) */
{{1, 0x1, 0x83},{2, 0x3, 0x41},{3, 0x7, 0x20},{4, 0x7, 0x10},{5, 0x7, 0x8},{6, 0x7, 0x4},{7, 0x7, 0x2},{8, 0x7, 0x0}},
/* state = 0x108 (8 bits, 0x8 buffer) */
{{1, 0x0, 0x84},{2, 0x0, 0x42},{3, 0x0, 0x21},{4, 0x8, 0x10},{5, 0x8, 0x8},{6, 0x8, 0x4},{7, 0x8, 0x2},{8, 0x8, 0x0}},
/* state = 0x109 (8 bits, 0x9 buffer) */
{{1, 0x1, 0x84},{2, 0x1, 0x42},{3, 0x1, 0x21},{4, 0x9, 0x10},{5, 0x9, 0x8},{6, 0x9, 0x4},{7, 0x9, 0x2},{8, 0x9, 0x0}},
/* state = 0x10A (8 bits, 0xA buffer) */
{{1, 0x0, 0x85},{2, 0x2, 0x42},{3, 0x2, 0x21},{4, 0xA, 0x10},{5, 0xA, 0x8},{6, 0xA, 0x4},{7, 0xA, 0x2},{8, 0xA, 0x0}},
/* state = 0x10B (8 bits, 0xB buffer) */
{{1, 0x1, 0x85},{2, 0x3, 0x42},{3, 0x3, 0x21},{4, 0xB, 0x10},{5, 0xB, 0x8},{6, 0xB, 0x4},{7, 0xB, 0x2},{8, 0xB, 0x0}},
/* state = 0x10C (8 bits, 0xC buffer) */
{{1, 0x0, 0x86},{2, 0x0, 0x43},{3, 0x4, 0x21},{4, 0xC, 0x10},{5, 0xC, 0x8},{6, 0xC, 0x4},{7, 0xC, 0x2},{8, 0xC, 0x0}},
/* state = 0x10D (8 bits, 0xD buffer) */
{{1, 0x1, 0x86},{2, 0x1, 0x43},{3, 0x5, 0x21},{4, 0xD, 0x10},{5, 0xD, 0x8},{6, 0xD, 0x4},{7, 0xD, 0x2},{8, 0xD, 0x0}},
/* state = 0x10E (8 bits, 0xE buffer) */
{{1, 0x0, 0x87},{2, 0x2, 0x43},{3, 0x6, 0x21},{4, 0xE, 0x10},{5, 0xE, 0x8},{6, 0xE, 0x4},{7, 0xE, 0x2},{8, 0xE, 0x0}},
/* state = 0x10F (8 bits, 0xF buffer) */
{{1, 0x1, 0x87},{2, 0x3, 0x43},{3, 0x7, 0x21},{4, 0xF, 0x10},{5, 0xF, 0x8},{6, 0xF, 0x4},{7, 0xF, 0x2},{8, 0xF, 0x0}},
/* state = 0x110 (8 bits, 0x10 buffer) */
{{1, 0x0, 0x88},{2, 0x0, 0x44},{3, 0x0, 0x22},{4, 0x0, 0x11},{5, 0x10, 0x8},{6, 0x10, 0x4},{7, 0x10, 0x2},{8, 0x10, 0x0}},
/* state = 0x111 (8 bits, 0x11 buffer) */
{{1, 0x1, 0x88},{2, 0x1, 0x44},{3, 0x1, 0x22},{4, 0x1, 0x11},{5, 0x11, 0x8},{6, 0x11, 0x4},{7, 0x11, 0x2},{8, 0x11, 0x0}},
/* state = 0x112 (8 bits, 0x12 buffer) */
{{1, 0x0, 0x89},{2, 0x2, 0x44},{3, 0x2, 0x22},{4, 0x2, 0x11},{5, 0x12, 0x8},{6, 0x12, 0x4},{7, 0x12, 0x2},{8, 0x12, 0x0}},
/* state = 0x113 (8 bits, 0x13 buffer) */
{{1, 0x1, 0x89},{2, 0x3, 0x44},{3, 0x3, 0x22},{4, 0x3, 0x11},{5, 0x13, 0x8},{6, 0x13, 0x4},{7, 0x13, 0x2},{8, 0x13, 0x0}},
/* state = 0x114 (8 bits, 0x14 buffer) */
{{1, 0x0, 0x8A},{2, 0x0, 0x45},{3, 0x4, 0x22},{4, 0x4, 0x11},{5, 0x14, 0x8},{6, 0x14, 0x4},{7, 0x14, 0x2},{8, 0x14, 0x0}},
/* state = 0x115 (8 bits, 0x15 buffer) */
{{1, 0x1, 0x8A},{2, 0x1, 0x45},{3, 0x5, 0x22},{4, 0x5, 0x11},{5, 0x15, 0x8},{6, 0x15, 0x4},{7, 0x15, 0x2},{8, 0x15, 0x0}},
/* state = 0x116 (8 bits, 0x16 buffer) */
{{1, 0x0, 0x8B},{2, 0x2, 0x45},{3, 0x6, 0x22},{4, 0x6, 0x11},{5, 0x16, 0x8},{6, 0x16, 0x4},{7, 0x16, 0x2},{8, 0x16, 0x0}},
/* state = 0x117 (8 bits, 0x17 buffer) */
{{1, 0x1, 0x8B},{2, 0x3, 0x45},{3, 0x7, 0x22},{4, 0x7, 0x11},{5, 0x17, 0x8},{6, 0x17, 0x4},{7, 0x17, 0x2},{8, 0x17, 0x0}},
/* state = 0x118 (8 bits, 0x18 buffer) */
{{1, 0x0, 0x8C},{2, 0x0, 0x46},{3, 0x0, 0x23},{4, 0x8, 0x11},{5, 0x18, 0x8},{6, 0x18, 0x4},{7, 0x18, 0x2},{8, 0x18, 0x0}},
/* state = 0x119 (8 bits, 0x19 buffer) */
{{1, 0x1, 0x8C},{2, 0x1, 0x46},{3, 0x1, 0x23},{4, 0x9, 0x11},{5, 0x19, 0x8},{6, 0x19, 0x4},{7, 0x19, 0x2},{8, 0x19, 0x0}},
/* state = 0x11A (8 bits, 0x1A buffer) */
{{1, 0x0, 0x8D},{2, 0x2, 0x46},{3, 0x2, 0x23},{4, 0xA, 0x11},{5, 0x1A, 0x8},{6, 0x1A, 0x4},{7, 0x1A, 0x2},{8, 0x1A, 0x0}},
/* state = 0x11B (8 bits, 0x1B buffer) */
{{1, 0x1, 0x8D},{2, 0x3, 0x46},{3, 0x3, 0x23},{4, 0xB, 0x11},{5, 0x1B, 0x8},{6, 0x1B, 0x4},{7, 0x1B, 0x2},{8, 0x1B, 0x0}},
/* state = 0x11C (8 bits, 0x1C buffer) */
{{1, 0x0, 0x8E},{2, 0x0, 0x47},{3, 0x4, 0x23},{4, 0xC, 0x11},{5, 0x1C, 0x8},{6, 0x1C, 0x4},{7, 0x1C, 0x2},{8, 0x1C, 0x0}},
/* state = 0x11D (8 bits, 0x1D buffer) */
{{1, 0x1, 0x8E},{2, 0x1, 0x47},{3, 0x5, 0x23},{4, 0xD, 0x11},{5, 0x1D, 0x8},{6, 0x1D, 0x4},{7, 0x1D, 0x2},{8, 0x1D, 0x0}},
/* state = 0x11E (8 bits, 0x1E buffer) */
{{1, 0x0, 0x8F},{2, 0x2, 0x47},{3, 0x6, 0x23},{4, 0xE, 0x11},{5, 0x1E, 0x8},{6, 0x1E, 0x4},{7, 0x1E, 0x2},{8, 0x1E, 0x0}},
/* state = 0x11F (8 bits, 0x1F buffer) */
{{1, 0x1, 0x8F},{2, 0x3, 0x47},{3, 0x7, 0x23},{4, 0xF, 0x11},{5, 0x1F, 0x8},{6, 0x1F, 0x4},{7, 0x1F, 0x2},{8, 0x1F, 0x0}},
/* state = 0x120 (8 bits, 0x20 buffer) */
{{1, 0x0, 0x90},{2, 0x0, 0x48},{3, 0x0, 0x24},{4, 0x0, 0x12},{5, 0x0, 0x9},{6, 0x20, 0x4},{7, 0x20, 0x2},{8, 0x20, 0x0}},
/* state = 0x121 (8 bits, 0x21 buffer) */
{{1, 0x1, 0x90},{2, 0x1, 0x48},{3, 0x1, 0x24},{4, 0x1, 0x12},{5, 0x1, 0x9},{6, 0x21, 0x4},{7, 0x21, 0x2},{8, 0x21, 0x0}},
/* state = 0x122 (8 bits, 0x22 buffer) */
{{1, 0x0, 0x91},{2, 0x2, 0x48},{3, 0x2, 0x24},{4, 0x2, 0x12},{5, 0x2, 0x9},{6, 0x22, 0x4},{7, 0x22, 0x2},{8, 0x22, 0x0}},
/* state = 0x123 (8 bits, 0x23 buffer) */
{{1, 0x1, 0x91},{2, 0x3, 0x48},{3, 0x3, 0x24},{4, 0x3, 0x12},{5, 0x3, 0x9},{6, 0x23, 0x4},{7, 0x23, 0x2},{8, 0x23, 0x0}},
/* state = 0x124 (8 bits, 0x24 buffer) */
{{1, 0x0, 0x92},{2, 0x0, 0x49},{3, 0x4, 0x24},{4, 0x4, 0x12},{5, 0x4, 0x9},{6, 0x24, 0x4},{7, 0x24, 0x2},{8, 0x24, 0x0}},
/* state = 0x125 (8 bits, 0x25 buffer) */
{{1, 0x1, 0x92},{2, 0x1, 0x49},{3, 0x5, 0x24},{4, 0x5, 0x12},{5, 0x5, 0x9},{6, 0x25, 0x4},{7, 0x25, 0x2},{8, 0x25, 0x0}},
/* state = 0x126 (8 bits, 0x26 buffer) */
{{1, 0x0, 0x93},{2, 0x2, 0x49},{3, 0x6, 0x24},{4, 0x6, 0x12},{5, 0x6, 0x9},{6, 0x26, 0x4},{7, 0x26, 0x2},{8, 0x26, 0x0}},
/* state = 0x127 (8 bits, 0x27 buffer) */
{{1, 0x1, 0x93},{2, 0x3, 0x49},{3, 0x7, 0x24},{4, 0x7, 0x12},{5, 0x7, 0x9},{6, 0x27, 0x4},{7, 0x27, 0x2},{8, 0x27, 0x0}},
/* state = 0x128 (8 bits, 0x28 buffer) */
{{1, 0x0, 0x94},{2, 0x0, 0x4A},{3, 0x0, 0x25},{4, 0x8, 0x12},{5, 0x8, 0x9},{6, 0x28, 0x4},{7, 0x28, 0x2},{8, 0x28, 0x0}},
/* state = 0x129 (8 bits, 0x29 buffer) */
{{1, 0x1, 0x94},{2, 0x1, 0x4A},{3, 0x1, 0x25},{4, 0x9, 0x12},{5, 0x9, 0x9},{6, 0x29, 0x4},{7, 0x29, 0x2},{8, 0x29, 0x0}},
/* state = 0x12A (8 bits, 0x2A buffer) */
{{1, 0x0, 0x95},{2, 0x2, 0x4A},{3, 0x2, 0x25},{4, 0xA, 0x12},{5, 0xA, 0x9},{6, 0x2A, 0x4},{7, 0x2A, 0x2},{8, 0x2A, 0x0}},
/* state = 0x12B (8 bits, 0x2B buffer) */
{{1, 0x1, 0x95},{2, 0x3, 0x4A},{3, 0x3, 0x25},{4, 0xB, 0x12},{5, 0xB, 0x9},{6, 0x2B, 0x4},{7, 0x2B, 0x2},{8, 0x2B, 0x0}},
/* state = 0x12C (8 bits, 0x2C buffer) */
{{1, 0x0, 0x96},{2, 0x0, 0x4B},{3, 0x4, 0x25},{4, 0xC, 0x12},{5, 0xC, 0x9},{6, 0x2C, 0x4},{7, 0x2C, 0x2},{8, 0x2C, 0x0}},
/* state = 0x12D (8 bits, 0x2D buffer) */
{{1, 0x1, 0x96},{2, 0x1, 0x4B},{3, 0x5, 0x25},{4, 0xD, 0x12},{5, 0xD, 0x9},{6, 0x2D, 0x4},{7, 0x2D, 0x2},{8, 0x2D, 0x0}},
/* state = 0x12E (8 bits, 0x2E buffer) */
{{1, 0x0, 0x97},{2, 0x2, 0x4B},{3, 0x6, 0x25},{4, 0xE, 0x12},{5, 0xE, 0x9},{6, 0x2E, 0x4},{7, 0x2E, 0x2},{8, 0x2E, 0x0}},
/* state = 0x12F (8 bits, 0x2F buffer) */
{{1, 0x1, 0x97},{2, 0x3, 0x4B},{3, 0x7, 0x25},{4, 0xF, 0x12},{5, 0xF, 0x9},{6, 0x2F, 0x4},{7, 0x2F, 0x2},{8, 0x2F, 0x0}},
/* state = 0x130 (8 bits, 0x30 buffer) */
{{1, 0x0, 0x98},{2, 0x0, 0x4C},{3, 0x0, 0x26},{4, 0x0, 0x13},{5, 0x10, 0x9},{6, 0x30, 0x4},{7, 0x30, 0x2},{8, 0x30, 0x0}},
/* state = 0x131 (8 bits, 0x31 buffer) */
{{1, 0x1, 0x98},{2, 0x1, 0x4C},{3, 0x1, 0x26},{4, 0x1, 0x13},{5, 0x11, 0x9},{6, 0x31, 0x4},{7, 0x31, 0x2},{8, 0x31, 0x0}},
/* state = 0x132 (8 bits, 0x32 buffer) */
{{1, 0x0, 0x99},{2, 0x2, 0x4C},{3, 0x2, 0x26},{4, 0x2, 0x13},{5, 0x12, 0x9},{6, 0x32, 0x4},{7, 0x32, 0x2},{8, 0x32, 0x0}},
/* state = 0x133 (8 bits, 0x33 buffer) */
{{1, 0x1, 0x99},{2, 0x3, 0x4C},{3, 0x3, 0x26},{4, 0x3, 0x13},{5, 0x13, 0x9},{6, 0x33, 0x4},{7, 0x33, 0x2},{8, 0x33, 0x0}},
/* state = 0x134 (8 bits, 0x34 buffer) */
{{1, 0x0, 0x9A},{2, 0x0, 0x4D},{3, 0x4, 0x26},{4, 0x4, 0x13},{5, 0x14, 0x9},{6, 0x34, 0x4},{7, 0x34, 0x2},{8, 0x34, 0x0}},
/* state = 0x135 (8 bits, 0x35 buffer) */
{{1, 0x1, 0x9A},{2, 0x1, 0x4D},{3, 0x5, 0x26},{4, 0x5, 0x13},{5, 0x15, 0x9},{6, 0x35, 0x4},{7, 0x35, 0x2},{8, 0x35, 0x0}},
/* state = 0x136 (8 bits, 0x36 buffer) */
{{1, 0x0, 0x9B},{2, 0x2, 0x4D},{3, 0x6, 0x26},{4, 0x6, 0x13},{5, 0x16, 0x9},{6, 0x36, 0x4},{7, 0x36, 0x2},{8, 0x36, 0x0}},
/* state = 0x137 (8 bits, 0x37 buffer) */
{{1, 0x1, 0x9B},{2, 0x3, 0x4D},{3, 0x7, 0x26},{4, 0x7, 0x13},{5, 0x17, 0x9},{6, 0x37, 0x4},{7, 0x37, 0x2},{8, 0x37, 0x0}},
/* state = 0x138 (8 bits, 0x38 buffer) */
{{1, 0x0, 0x9C},{2, 0x0, 0x4E},{3, 0x0, 0x27},{4, 0x8, 0x13},{5, 0x18, 0x9},{6, 0x38, 0x4},{7, 0x38, 0x2},{8, 0x38, 0x0}},
/* state = 0x139 (8 bits, 0x39 buffer) */
{{1, 0x1, 0x9C},{2, 0x1, 0x4E},{3, 0x1, 0x27},{4, 0x9, 0x13},{5, 0x19, 0x9},{6, 0x39, 0x4},{7, 0x39, 0x2},{8, 0x39, 0x0}},
/* state = 0x13A (8 bits, 0x3A buffer) */
{{1, 0x0, 0x9D},{2, 0x2, 0x4E},{3, 0x2, 0x27},{4, 0xA, 0x13},{5, 0x1A, 0x9},{6, 0x3A, 0x4},{7, 0x3A, 0x2},{8, 0x3A, 0x0}},
/* state = 0x13B (8 bits, 0x3B buffer) */
{{1, 0x1, 0x9D},{2, 0x3, 0x4E},{3, 0x3, 0x27},{4, 0xB, 0x13},{5, 0x1B, 0x9},{6, 0x3B, 0x4},{7, 0x3B, 0x2},{8, 0x3B, 0x0}},
/* state = 0x13C (8 bits, 0x3C buffer) */
{{1, 0x0, 0x9E},{2, 0x0, 0x4F},{3, 0x4, 0x27},{4, 0xC, 0x13},{5, 0x1C, 0x9},{6, 0x3C, 0x4},{7, 0x3C, 0x2},{8, 0x3C, 0x0}},
/* state = 0x13D (8 bits, 0x3D buffer) */
{{1, 0x1, 0x9E},{2, 0x1, 0x4F},{3, 0x5, 0x27},{4, 0xD, 0x13},{5, 0x1D, 0x9},{6, 0x3D, 0x4},{7, 0x3D, 0x2},{8, 0x3D, 0x0}},
/* state = 0x13E (8 bits, 0x3E buffer) */
{{1, 0x0, 0x9F},{2, 0x2, 0x4F},{3, 0x6, 0x27},{4, 0xE, 0x13},{5, 0x1E, 0x9},{6, 0x3E, 0x4},{7, 0x3E, 0x2},{8, 0x3E, 0x0}},
/* state = 0x13F (8 bits, 0x3F buffer) */
{{1, 0x1, 0x9F},{2, 0x3, 0x4F},{3, 0x7, 0x27},{4, 0xF, 0x13},{5, 0x1F, 0x9},{6, 0x3F, 0x4},{7, 0x3F, 0x2},{8, 0x3F, 0x0}},
/* state = 0x140 (8 bits, 0x40 buffer) */
{{1, 0x0, 0xA0},{2, 0x0, 0x50},{3, 0x0, 0x28},{4, 0x0, 0x14},{5, 0x0, 0xA},{6, 0x0, 0x5},{7, 0x40, 0x2},{8, 0x40, 0x0}},
/* state = 0x141 (8 bits, 0x41 buffer) */
{{1, 0x1, 0xA0},{2, 0x1, 0x50},{3, 0x1, 0x28},{4, 0x1, 0x14},{5, 0x1, 0xA},{6, 0x1, 0x5},{7, 0x41, 0x2},{8, 0x41, 0x0}},
/* state = 0x142 (8 bits, 0x42 buffer) */
{{1, 0x0, 0xA1},{2, 0x2, 0x50},{3, 0x2, 0x28},{4, 0x2, 0x14},{5, 0x2, 0xA},{6, 0x2, 0x5},{7, 0x42, 0x2},{8, 0x42, 0x0}},
/* state = 0x143 (8 bits, 0x43 buffer) */
{{1, 0x1, 0xA1},{2, 0x3, 0x50},{3, 0x3, 0x28},{4, 0x3, 0x14},{5, 0x3, 0xA},{6, 0x3, 0x5},{7, 0x43, 0x2},{8, 0x43, 0x0}},
/* state = 0x144 (8 bits, 0x44 buffer) */
{{1, 0x0, 0xA2},{2, 0x0, 0x51},{3, 0x4, 0x28},{4, 0x4, 0x14},{5, 0x4, 0xA},{6, 0x4, 0x5},{7, 0x44, 0x2},{8, 0x44, 0x0}},
/* state = 0x145 (8 bits, 0x45 buffer) */
{{1, 0x1, 0xA2},{2, 0x1, 0x51},{3, 0x5, 0x28},{4, 0x5, 0x14},{5, 0x5, 0xA},{6, 0x5, 0x5},{7, 0x45, 0x2},{8, 0x45, 0x0}},
/* state = 0x146 (8 bits, 0x46 buffer) */
{{1, 0x0, 0xA3},{2, 0x2, 0x51},{3, 0x6, 0x28},{4, 0x6, 0x14},{5, 0x6, 0xA},{6, 0x6, 0x5},{7, 0x46, 0x2},{8, 0x46, 0x0}},
/* state = 0x147 (8 bits, 0x47 buffer) */
{{1, 0x1, 0xA3},{2, 0x3, 0x51},{3, 0x7, 0x28},{4, 0x7, 0x14},{5, 0x7, 0xA},{6, 0x7, 0x5},{7, 0x47, 0x2},{8, 0x47, 0x0}},
/* state = 0x148 (8 bits, 0x48 buffer) */
{{1, 0x0, 0xA4},{2, 0x0, 0x52},{3, 0x0, 0x29},{4, 0x8, 0x14},{5, 0x8, 0xA},{6, 0x8, 0x5},{7, 0x48, 0x2},{8, 0x48, 0x0}},
/* state = 0x149 (8 bits, 0x49 buffer) */
{{1, 0x1, 0xA4},{2, 0x1, 0x52},{3, 0x1, 0x29},{4, 0x9, 0x14},{5, 0x9, 0xA},{6, 0x9, 0x5},{7, 0x49, 0x2},{8, 0x49, 0x0}},
/* state = 0x14A (8 bits, 0x4A buffer) */
{{1, 0x0, 0xA5},{2, 0x2, 0x52},{3, 0x2, 0x29},{4, 0xA, 0x14},{5, 0xA, 0xA},{6, 0xA, 0x5},{7, 0x4A, 0x2},{8, 0x4A, 0x0}},
/* state = 0x14B (8 bits, 0x4B buffer) */
{{1, 0x1, 0xA5},{2, 0x3, 0x52},{3, 0x3, 0x29},{4, 0xB, 0x14},{5, 0xB, 0xA},{6, 0xB, 0x5},{7, 0x4B, 0x2},{8, 0x4B, 0x0}},
/* state = 0x14C (8 bits, 0x4C buffer) */
{{1, 0x0, 0xA6},{2, 0x0, 0x53},{3, 0x4, 0x29},{4, 0xC, 0x14},{5, 0xC, 0xA},{6, 0xC, 0x5},{7, 0x4C, 0x2},{8, 0x4C, 0x0}},
/* state = 0x14D (8 bits, 0x4D buffer) */
{{1, 0x1, 0xA6},{2, 0x1, 0x53},{3, 0x5, 0x29},{4, 0xD, 0x14},{5, 0xD, 0xA},{6, 0xD, 0x5},{7, 0x4D, 0x2},{8, 0x4D, 0x0}},
/* state = 0x14E (8 bits, 0x4E buffer) */
{{1, 0x0, 0xA7},{2, 0x2, 0x53},{3, 0x6, 0x29},{4, 0xE, 0x14},{5, 0xE, 0xA},{6, 0xE, 0x5},{7, 0x4E, 0x2},{8, 0x4E, 0x0}},
/* state = 0x14F (8 bits, 0x4F buffer) */
{{1, 0x1, 0xA7},{2, 0x3, 0x53},{3, 0x7, 0x29},{4, 0xF, 0x14},{5, 0xF, 0xA},{6, 0xF, 0x5},{7, 0x4F, 0x2},{8, 0x4F, 0x0}},
/* state = 0x150 (8 bits, 0x50 buffer) */
{{1, 0x0, 0xA8},{2, 0x0, 0x54},{3, 0x0, 0x2A},{4, 0x0, 0x15},{5, 0x10, 0xA},{6, 0x10, 0x5},{7, 0x50, 0x2},{8, 0x50, 0x0}},
/* state = 0x151 (8 bits, 0x51 buffer) */
{{1, 0x1, 0xA8},{2, 0x1, 0x54},{3, 0x1, 0x2A},{4, 0x1, 0x15},{5, 0x11, 0xA},{6, 0x11, 0x5},{7, 0x51, 0x2},{8, 0x51, 0x0}},
/* state = 0x152 (8 bits, 0x52 buffer) */
{{1, 0x0, 0xA9},{2, 0x2, 0x54},{3, 0x2, 0x2A},{4, 0x2, 0x15},{5, 0x12, 0xA},{6, 0x12, 0x5},{7, 0x52, 0x2},{8, 0x52, 0x0}},
/* state = 0x153 (8 bits, 0x53 buffer) */
{{1, 0x1, 0xA9},{2, 0x3, 0x54},{3, 0x3, 0x2A},{4, 0x3, 0x15},{5, 0x13, 0xA},{6, 0x13, 0x5},{7, 0x53, 0x2},{8, 0x53, 0x0}},
/* state = 0x154 (8 bits, 0x54 buffer) */
{{1, 0x0, 0xAA},{2, 0x0, 0x55},{3, 0x4, 0x2A},{4, 0x4, 0x15},{5, 0x14, 0xA},{6, 0x14, 0x5},{7, 0x54, 0x2},{8, 0x54, 0x0}},
/* state = 0x155 (8 bits, 0x55 buffer) */
{{1, 0x1, 0xAA},{2, 0x1, 0x55},{3, 0x5, 0x2A},{4, 0x5, 0x15},{5, 0x15, 0xA},{6, 0x15, 0x5},{7, 0x55, 0x2},{8, 0x55, 0x0}},
/* state = 0x156 (8 bits, 0x56 buffer) */
{{1, 0x0, 0xAB},{2, 0x2, 0x55},{3, 0x6, 0x2A},{4, 0x6, 0x15},{5, 0x16, 0xA},{6, 0x16, 0x5},{7, 0x56, 0x2},{8, 0x56, 0x0}},
/* state = 0x157 (8 bits, 0x57 buffer) */
{{1, 0x1, 0xAB},{2, 0x3, 0x55},{3, 0x7, 0x2A},{4, 0x7, 0x15},{5, 0x17, 0xA},{6, 0x17, 0x5},{7, 0x57, 0x2},{8, 0x57, 0x0}},
/* state = 0x158 (8 bits, 0x58 buffer) */
{{1, 0x0, 0xAC},{2, 0x0, 0x56},{3, 0x0, 0x2B},{4, 0x8, 0x15},{5, 0x18, 0xA},{6, 0x18, 0x5},{7, 0x58, 0x2},{8, 0x58, 0x0}},
/* state = 0x159 (8 bits, 0x59 buffer) */
{{1, 0x1, 0xAC},{2, 0x1, 0x56},{3, 0x1, 0x2B},{4, 0x9, 0x15},{5, 0x19, 0xA},{6, 0x19, 0x5},{7, 0x59, 0x2},{8, 0x59, 0x0}},
/* state = 0x15A (8 bits, 0x5A buffer) */
{{1, 0x0, 0xAD},{2, 0x2, 0x56},{3, 0x2, 0x2B},{4, 0xA, 0x15},{5, 0x1A, 0xA},{6, 0x1A, 0x5},{7, 0x5A, 0x2},{8, 0x5A, 0x0}},
/* state = 0x15B (8 bits, 0x5B buffer) */
{{1, 0x1, 0xAD},{2, 0x3, 0x56},{3, 0x3, 0x2B},{4, 0xB, 0x15},{5, 0x1B, 0xA},{6, 0x1B, 0x5},{7, 0x5B, 0x2},{8, 0x5B, 0x0}},
/* state = 0x15C (8 bits, 0x5C buffer) */
{{1, 0x0, 0xAE},{2, 0x0, 0x57},{3, 0x4, 0x2B},{4, 0xC, 0x15},{5, 0x1C, 0xA},{6, 0x1C, 0x5},{7, 0x5C, 0x2},{8, 0x5C, 0x0}},
/* state = 0x15D (8 bits, 0x5D buffer) */
{{1, 0x1, 0xAE},{2, 0x1, 0x57},{3, 0x5, 0x2B},{4, 0xD, 0x15},{5, 0x1D, 0xA},{6, 0x1D, 0x5},{7, 0x5D, 0x2},{8, 0x5D, 0x0}},
/* state = 0x15E (8 bits, 0x5E buffer) */
{{1, 0x0, 0xAF},{2, 0x2, 0x57},{3, 0x6, 0x2B},{4, 0xE, 0x15},{5, 0x1E, 0xA},{6, 0x1E, 0x5},{7, 0x5E, 0x2},{8, 0x5E, 0x0}},
/* state = 0x15F (8 bits, 0x5F buffer) */
{{1, 0x1, 0xAF},{2, 0x3, 0x57},{3, 0x7, 0x2B},{4, 0xF, 0x15},{5, 0x1F, 0xA},{6, 0x1F, 0x5},{7, 0x5F, 0x2},{8, 0x5F, 0x0}},
/* state = 0x160 (8 bits, 0x60 buffer) */
{{1, 0x0, 0xB0},{2, 0x0, 0x58},{3, 0x0, 0x2C},{4, 0x0, 0x16},{5, 0x0, 0xB},{6, 0x20, 0x5},{7, 0x60, 0x2},{8, 0x60, 0x0}},
/* state = 0x161 (8 bits, 0x61 buffer) */
{{1, 0x1, 0xB0},{2, 0x1, 0x58},{3, 0x1, 0x2C},{4, 0x1, 0x16},{5, 0x1, 0xB},{6, 0x21, 0x5},{7, 0x61, 0x2},{8, 0x61, 0x0}},
/* state = 0x162 (8 bits, 0x62 buffer) */
{{1, 0x0, 0xB1},{2, 0x2, 0x58},{3, 0x2, 0x2C},{4, 0x2, 0x16},{5, 0x2, 0xB},{6, 0x22, 0x5},{7, 0x62, 0x2},{8, 0x62, 0x0}},
/* state = 0x163 (8 bits, 0x63 buffer) */
{{1, 0x1, 0xB1},{2, 0x3, 0x58},{3, 0x3, 0x2C},{4, 0x3, 0x16},{5, 0x3, 0xB},{6, 0x23, 0x5},{7, 0x63, 0x2},{8, 0x63, 0x0}},
/* state = 0x164 (8 bits, 0x64 buffer) */
{{1, 0x0, 0xB2},{2, 0x0, 0x59},{3, 0x4, 0x2C},{4, 0x4, 0x16},{5, 0x4, 0xB},{6, 0x24, 0x5},{7, 0x64, 0x2},{8, 0x64, 0x0}},
/* state = 0x165 (8 bits, 0x65 buffer) */
{{1, 0x1, 0xB2},{2, 0x1, 0x59},{3, 0x5, 0x2C},{4, 0x5, 0x16},{5, 0x5, 0xB},{6, 0x25, 0x5},{7, 0x65, 0x2},{8, 0x65, 0x0}},
/* state = 0x166 (8 bits, 0x66 buffer) */
{{1, 0x0, 0xB3},{2, 0x2, 0x59},{3, 0x6, 0x2C},{4, 0x6, 0x16},{5, 0x6, 0xB},{6, 0x26, 0x5},{7, 0x66, 0x2},{8, 0x66, 0x0}},
/* state = 0x167 (8 bits, 0x67 buffer) */
{{1, 0x1, 0xB3},{2, 0x3, 0x59},{3, 0x7, 0x2C},{4, 0x7, 0x16},{5, 0x7, 0xB},{6, 0x27, 0x5},{7, 0x67, 0x2},{8, 0x67, 0x0}},
/* state = 0x168 (8 bits, 0x68 buffer) */
{{1, 0x0, 0xB4},{2, 0x0, 0x5A},{3, 0x0, 0x2D},{4, 0x8, 0x16},{5, 0x8, 0xB},{6, 0x28, 0x5},{7, 0x68, 0x2},{8, 0x68, 0x0}},
/* state = 0x169 (8 bits, 0x69 buffer) */
{{1, 0x1, 0xB4},{2, 0x1, 0x5A},{3, 0x1, 0x2D},{4, 0x9, 0x16},{5, 0x9, 0xB},{6, 0x29, 0x5},{7, 0x69, 0x2},{8, 0x69, 0x0}},
/* state = 0x16A (8 bits, 0x6A buffer) */
{{1, 0x0, 0xB5},{2, 0x2, 0x5A},{3, 0x2, 0x2D},{4, 0xA, 0x16},{5, 0xA, 0xB},{6, 0x2A, 0x5},{7, 0x6A, 0x2},{8, 0x6A, 0x0}},
/* state = 0x16B (8 bits, 0x6B buffer) */
{{1, 0x1, 0xB5},{2, 0x3, 0x5A},{3, 0x3, 0x2D},{4, 0xB, 0x16},{5, 0xB, 0xB},{6, 0x2B, 0x5},{7, 0x6B, 0x2},{8, 0x6B, 0x0}},
/* state = 0x16C (8 bits, 0x6C buffer) */
{{1, 0x0, 0xB6},{2, 0x0, 0x5B},{3, 0x4, 0x2D},{4, 0xC, 0x16},{5, 0xC, 0xB},{6, 0x2C, 0x5},{7, 0x6C, 0x2},{8, 0x6C, 0x0}},
/* state = 0x16D (8 bits, 0x6D buffer) */
{{1, 0x1, 0xB6},{2, 0x1, 0x5B},{3, 0x5, 0x2D},{4, 0xD, 0x16},{5, 0xD, 0xB},{6, 0x2D, 0x5},{7, 0x6D, 0x2},{8, 0x6D, 0x0}},
/* state = 0x16E (8 bits, 0x6E buffer) */
{{1, 0x0, 0xB7},{2, 0x2, 0x5B},{3, 0x6, 0x2D},{4, 0xE, 0x16},{5, 0xE, 0xB},{6, 0x2E, 0x5},{7, 0x6E, 0x2},{8, 0x6E, 0x0}},
/* state = 0x16F (8 bits, 0x6F buffer) */
{{1, 0x1, 0xB7},{2, 0x3, 0x5B},{3, 0x7, 0x2D},{4, 0xF, 0x16},{5, 0xF, 0xB},{6, 0x2F, 0x5},{7, 0x6F, 0x2},{8, 0x6F, 0x0}},
/* state = 0x170 (8 bits, 0x70 buffer) */
{{1, 0x0, 0xB8},{2, 0x0, 0x5C},{3, 0x0, 0x2E},{4, 0x0, 0x17},{5, 0x10, 0xB},{6, 0x30, 0x5},{7, 0x70, 0x2},{8, 0x70, 0x0}},
/* state = 0x171 (8 bits, 0x71 buffer) */
{{1, 0x1, 0xB8},{2, 0x1, 0x5C},{3, 0x1, 0x2E},{4, 0x1, 0x17},{5, 0x11, 0xB},{6, 0x31, 0x5},{7, 0x71, 0x2},{8, 0x71, 0x0}},
/* state = 0x172 (8 bits, 0x72 buffer) */
{{1, 0x0, 0xB9},{2, 0x2, 0x5C},{3, 0x2, 0x2E},{4, 0x2, 0x17},{5, 0x12, 0xB},{6, 0x32, 0x5},{7, 0x72, 0x2},{8, 0x72, 0x0}},
/* state = 0x173 (8 bits, 0x73 buffer) */
{{1, 0x1, 0xB9},{2, 0x3, 0x5C},{3, 0x3, 0x2E},{4, 0x3, 0x17},{5, 0x13, 0xB},{6, 0x33, 0x5},{7, 0x73, 0x2},{8, 0x73, 0x0}},
/* state = 0x174 (8 bits, 0x74 buffer) */
{{1, 0x0, 0xBA},{2, 0x0, 0x5D},{3, 0x4, 0x2E},{4, 0x4, 0x17},{5, 0x14, 0xB},{6, 0x34, 0x5},{7, 0x74, 0x2},{8, 0x74, 0x0}},
/* state = 0x175 (8 bits, 0x75 buffer) */
{{1, 0x1, 0xBA},{2, 0x1, 0x5D},{3, 0x5, 0x2E},{4, 0x5, 0x17},{5, 0x15, 0xB},{6, 0x35, 0x5},{7, 0x75, 0x2},{8, 0x75, 0x0}},
/* state = 0x176 (8 bits, 0x76 buffer) */
{{1, 0x0, 0xBB},{2, 0x2, 0x5D},{3, 0x6, 0x2E},{4, 0x6, 0x17},{5, 0x16, 0xB},{6, 0x36, 0x5},{7, 0x76, 0x2},{8, 0x76, 0x0}},
/* state = 0x177 (8 bits, 0x77 buffer) */
{{1, 0x1, 0xBB},{2, 0x3, 0x5D},{3, 0x7, 0x2E},{4, 0x7, 0x17},{5, 0x17, 0xB},{6, 0x37, 0x5},{7, 0x77, 0x2},{8, 0x77, 0x0}},
/* state = 0x178 (8 bits, 0x78 buffer) */
{{1, 0x0, 0xBC},{2, 0x0, 0x5E},{3, 0x0, 0x2F},{4, 0x8, 0x17},{5, 0x18, 0xB},{6, 0x38, 0x5},{7, 0x78, 0x2},{8, 0x78, 0x0}},
/* state = 0x179 (8 bits, 0x79 buffer) */
{{1, 0x1, 0xBC},{2, 0x1, 0x5E},{3, 0x1, 0x2F},{4, 0x9, 0x17},{5, 0x19, 0xB},{6, 0x39, 0x5},{7, 0x79, 0x2},{8, 0x79, 0x0}},
/* state = 0x17A (8 bits, 0x7A buffer) */
{{1, 0x0, 0xBD},{2, 0x2, 0x5E},{3, 0x2, 0x2F},{4, 0xA, 0x17},{5, 0x1A, 0xB},{6, 0x3A, 0x5},{7, 0x7A, 0x2},{8, 0x7A, 0x0}},
/* state = 0x17B (8 bits, 0x7B buffer) */
{{1, 0x1, 0xBD},{2, 0x3, 0x5E},{3, 0x3, 0x2F},{4, 0xB, 0x17},{5, 0x1B, 0xB},{6, 0x3B, 0x5},{7, 0x7B, 0x2},{8, 0x7B, 0x0}},
/* state = 0x17C (8 bits, 0x7C buffer) */
{{1, 0x0, 0xBE},{2, 0x0, 0x5F},{3, 0x4, 0x2F},{4, 0xC, 0x17},{5, 0x1C, 0xB},{6, 0x3C, 0x5},{7, 0x7C, 0x2},{8, 0x7C, 0x0}},
/* state = 0x17D (8 bits, 0x7D buffer) */
{{1, 0x1, 0xBE},{2, 0x1, 0x5F},{3, 0x5, 0x2F},{4, 0xD, 0x17},{5, 0x1D, 0xB},{6, 0x3D, 0x5},{7, 0x7D, 0x2},{8, 0x7D, 0x0}},
/* state = 0x17E (8 bits, 0x7E buffer) */
{{1, 0x0, 0xBF},{2, 0x2, 0x5F},{3, 0x6, 0x2F},{4, 0xE, 0x17},{5, 0x1E, 0xB},{6, 0x3E, 0x5},{7, 0x7E, 0x2},{8, 0x7E, 0x0}},
/* state = 0x17F (8 bits, 0x7F buffer) */
{{1, 0x1, 0xBF},{2, 0x3, 0x5F},{3, 0x7, 0x2F},{4, 0xF, 0x17},{5, 0x1F, 0xB},{6, 0x3F, 0x5},{7, 0x7F, 0x2},{8, 0x7F, 0x0}},
/* state = 0x180 (8 bits, 0x80 buffer) */
{{1, 0x0, 0xC0},{2, 0x0, 0x60},{3, 0x0, 0x30},{4, 0x0, 0x18},{5, 0x0, 0xC},{6, 0x0, 0x6},{7, 0x0, 0x3},{8, 0x80, 0x0}},
/* state = 0x181 (8 bits, 0x81 buffer) */
{{1, 0x1, 0xC0},{2, 0x1, 0x60},{3, 0x1, 0x30},{4, 0x1, 0x18},{5, 0x1, 0xC},{6, 0x1, 0x6},{7, 0x1, 0x3},{8, 0x81, 0x0}},
/* state = 0x182 (8 bits, 0x82 buffer) */
{{1, 0x0, 0xC1},{2, 0x2, 0x60},{3, 0x2, 0x30},{4, 0x2, 0x18},{5, 0x2, 0xC},{6, 0x2, 0x6},{7, 0x2, 0x3},{8, 0x82, 0x0}},
/* state = 0x183 (8 bits, 0x83 buffer) */
{{1, 0x1, 0xC1},{2, 0x3, 0x60},{3, 0x3, 0x30},{4, 0x3, 0x18},{5, 0x3, 0xC},{6, 0x3, 0x6},{7, 0x3, 0x3},{8, 0x83, 0x0}},
/* state = 0x184 (8 bits, 0x84 buffer) */
{{1, 0x0, 0xC2},{2, 0x0, 0x61},{3, 0x4, 0x30},{4, 0x4, 0x18},{5, 0x4, 0xC},{6, 0x4, 0x6},{7, 0x4, 0x3},{8, 0x84, 0x0}},
/* state = 0x185 (8 bits, 0x85 buffer) */
{{1, 0x1, 0xC2},{2, 0x1, 0x61},{3, 0x5, 0x30},{4, 0x5, 0x18},{5, 0x5, 0xC},{6, 0x5, 0x6},{7, 0x5, 0x3},{8, 0x85, 0x0}},
/* state = 0x186 (8 bits, 0x86 buffer) */
{{1, 0x0, 0xC3},{2, 0x2, 0x61},{3, 0x6, 0x30},{4, 0x6, 0x18},{5, 0x6, 0xC},{6, 0x6, 0x6},{7, 0x6, 0x3},{8, 0x86, 0x0}},
/* state = 0x187 (8 bits, 0x87 buffer) */
{{1, 0x1, 0xC3},{2, 0x3, 0x61},{3, 0x7, 0x30},{4, 0x7, 0x18},{5, 0x7, 0xC},{6, 0x7, 0x6},{7, 0x7, 0x3},{8, 0x87, 0x0}},
/* state = 0x188 (8 bits, 0x88 buffer) */
{{1, 0x0, 0xC4},{2, 0x0, 0x62},{3, 0x0, 0x31},{4, 0x8, 0x18},{5, 0x8, 0xC},{6, 0x8, 0x6},{7, 0x8, 0x3},{8, 0x88, 0x0}},
/* state = 0x189 (8 bits, 0x89 buffer) */
{{1, 0x1, 0xC4},{2, 0x1, 0x62},{3, 0x1, 0x31},{4, 0x9, 0x18},{5, 0x9, 0xC},{6, 0x9, 0x6},{7, 0x9, 0x3},{8, 0x89, 0x0}},
/* state = 0x18A (8 bits, 0x8A buffer) */
{{1, 0x0, 0xC5},{2, 0x2, 0x62},{3, 0x2, 0x31},{4, 0xA, 0x18},{5, 0xA, 0xC},{6, 0xA, 0x6},{7, 0xA, 0x3},{8, 0x8A, 0x0}},
/* state = 0x18B (8 bits, 0x8B buffer) */
{{1, 0x1, 0xC5},{2, 0x3, 0x62},{3, 0x3, 0x31},{4, 0xB, 0x18},{5, 0xB, 0xC},{6, 0xB, 0x6},{7, 0xB, 0x3},{8, 0x8B, 0x0}},
/* state = 0x18C (8 bits, 0x8C buffer) */
{{1, 0x0, 0xC6},{2, 0x0, 0x63},{3, 0x4, 0x31},{4, 0xC, 0x18},{5, 0xC, 0xC},{6, 0xC, 0x6},{7, 0xC, 0x3},{8, 0x8C, 0x0}},
/* state = 0x18D (8 bits, 0x8D buffer) */
{{1, 0x1, 0xC6},{2, 0x1, 0x63},{3, 0x5, 0x31},{4, 0xD, 0x18},{5, 0xD, 0xC},{6, 0xD, 0x6},{7, 0xD, 0x3},{8, 0x8D, 0x0}},
/* state = 0x18E (8 bits, 0x8E buffer) */
{{1, 0x0, 0xC7},{2, 0x2, 0x63},{3, 0x6, 0x31},{4, 0xE, 0x18},{5, 0xE, 0xC},{6, 0xE, 0x6},{7, 0xE, 0x3},{8, 0x8E, 0x0}},
/* state = 0x18F (8 bits, 0x8F buffer) */
{{1, 0x1, 0xC7},{2, 0x3, 0x63},{3, 0x7, 0x31},{4, 0xF, 0x18},{5, 0xF, 0xC},{6, 0xF, 0x6},{7, 0xF, 0x3},{8, 0x8F, 0x0}},
/* state = 0x190 (8 bits, 0x90 buffer) */
{{1, 0x0, 0xC8},{2, 0x0, 0x64},{3, 0x0, 0x32},{4, 0x0, 0x19},{5, 0x10, 0xC},{6, 0x10, 0x6},{7, 0x10, 0x3},{8, 0x90, 0x0}},
/* state = 0x191 (8 bits, 0x91 buffer) */
{{1, 0x1, 0xC8},{2, 0x1, 0x64},{3, 0x1, 0x32},{4, 0x1, 0x19},{5, 0x11, 0xC},{6, 0x11, 0x6},{7, 0x11, 0x3},{8, 0x91, 0x0}},
/* state = 0x192 (8 bits, 0x92 buffer) */
{{1, 0x0, 0xC9},{2, 0x2, 0x64},{3, 0x2, 0x32},{4, 0x2, 0x19},{5, 0x12, 0xC},{6, 0x12, 0x6},{7, 0x12, 0x3},{8, 0x92, 0x0}},
/* state = 0x193 (8 bits, 0x93 buffer) */
{{1, 0x1, 0xC9},{2, 0x3, 0x64},{3, 0x3, 0x32},{4, 0x3, 0x19},{5, 0x13, 0xC},{6, 0x13, 0x6},{7, 0x13, 0x3},{8, 0x93, 0x0}},
/* state = 0x194 (8 bits, 0x94 buffer) */
{{1, 0x0, 0xCA},{2, 0x0, 0x65},{3, 0x4, 0x32},{4, 0x4, 0x19},{5, 0x14, 0xC},{6, 0x14, 0x6},{7, 0x14, 0x3},{8, 0x94, 0x0}},
/* state = 0x195 (8 bits, 0x95 buffer) */
{{1, 0x1, 0xCA},{2, 0x1, 0x65},{3, 0x5, 0x32},{4, 0x5, 0x19},{5, 0x15, 0xC},{6, 0x15, 0x6},{7, 0x15, 0x3},{8, 0x95, 0x0}},
/* state = 0x196 (8 bits, 0x96 buffer) */
{{1, 0x0, 0xCB},{2, 0x2, 0x65},{3, 0x6, 0x32},{4, 0x6, 0x19},{5, 0x16, 0xC},{6, 0x16, 0x6},{7, 0x16, 0x3},{8, 0x96, 0x0}},
/* state = 0x197 (8 bits, 0x97 buffer) */
{{1, 0x1, 0xCB},{2, 0x3, 0x65},{3, 0x7, 0x32},{4, 0x7, 0x19},{5, 0x17, 0xC},{6, 0x17, 0x6},{7, 0x17, 0x3},{8, 0x97, 0x0}},
/* state = 0x198 (8 bits, 0x98 buffer) */
{{1, 0x0, 0xCC},{2, 0x0, 0x66},{3, 0x0, 0x33},{4, 0x8, 0x19},{5, 0x18, 0xC},{6, 0x18, 0x6},{7, 0x18, 0x3},{8, 0x98, 0x0}},
/* state = 0x199 (8 bits, 0x99 buffer) */
{{1, 0x1, 0xCC},{2, 0x1, 0x66},{3, 0x1, 0x33},{4, 0x9, 0x19},{5, 0x19, 0xC},{6, 0x19, 0x6},{7, 0x19, 0x3},{8, 0x99, 0x0}},
/* state = 0x19A (8 bits, 0x9A buffer) */
{{1, 0x0, 0xCD},{2, 0x2, 0x66},{3, 0x2, 0x33},{4, 0xA, 0x19},{5, 0x1A, 0xC},{6, 0x1A, 0x6},{7, 0x1A, 0x3},{8, 0x9A, 0x0}},
/* state = 0x19B (8 bits, 0x9B buffer) */
{{1, 0x1, 0xCD},{2, 0x3, 0x66},{3, 0x3, 0x33},{4, 0xB, 0x19},{5, 0x1B, 0xC},{6, 0x1B, 0x6},{7, 0x1B, 0x3},{8, 0x9B, 0x0}},
/* state = 0x19C (8 bits, 0x9C buffer) */
{{1, 0x0, 0xCE},{2, 0x0, 0x67},{3, 0x4, 0x33},{4, 0xC, 0x19},{5, 0x1C, 0xC},{6, 0x1C, 0x6},{7, 0x1C, 0x3},{8, 0x9C, 0x0}},
/* state = 0x19D (8 bits, 0x9D buffer) */
{{1, 0x1, 0xCE},{2, 0x1, 0x67},{3, 0x5, 0x33},{4, 0xD, 0x19},{5, 0x1D, 0xC},{6, 0x1D, 0x6},{7, 0x1D, 0x3},{8, 0x9D, 0x0}},
/* state = 0x19E (8 bits, 0x9E buffer) */
{{1, 0x0, 0xCF},{2, 0x2, 0x67},{3, 0x6, 0x33},{4, 0xE, 0x19},{5, 0x1E, 0xC},{6, 0x1E, 0x6},{7, 0x1E, 0x3},{8, 0x9E, 0x0}},
/* state = 0x19F (8 bits, 0x9F buffer) */
{{1, 0x1, 0xCF},{2, 0x3, 0x67},{3, 0x7, 0x33},{4, 0xF, 0x19},{5, 0x1F, 0xC},{6, 0x1F, 0x6},{7, 0x1F, 0x3},{8, 0x9F, 0x0}},
/* state = 0x1A0 (8 bits, 0xA0 buffer) */
{{1, 0x0, 0xD0},{2, 0x0, 0x68},{3, 0x0, 0x34},{4, 0x0, 0x1A},{5, 0x0, 0xD},{6, 0x20, 0x6},{7, 0x20, 0x3},{8, 0xA0, 0x0}},
/* state = 0x1A1 (8 bits, 0xA1 buffer) */
{{1, 0x1, 0xD0},{2, 0x1, 0x68},{3, 0x1, 0x34},{4, 0x1, 0x1A},{5, 0x1, 0xD},{6, 0x21, 0x6},{7, 0x21, 0x3},{8, 0xA1, 0x0}},
/* state = 0x1A2 (8 bits, 0xA2 buffer) */
{{1, 0x0, 0xD1},{2, 0x2, 0x68},{3, 0x2, 0x34},{4, 0x2, 0x1A},{5, 0x2, 0xD},{6, 0x22, 0x6},{7, 0x22, 0x3},{8, 0xA2, 0x0}},
/* state = 0x1A3 (8 bits, 0xA3 buffer) */
{{1, 0x1, 0xD1},{2, 0x3, 0x68},{3, 0x3, 0x34},{4, 0x3, 0x1A},{5, 0x3, 0xD},{6, 0x23, 0x6},{7, 0x23, 0x3},{8, 0xA3, 0x0}},
/* state = 0x1A4 (8 bits, 0xA4 buffer) */
{{1, 0x0, 0xD2},{2, 0x0, 0x69},{3, 0x4, 0x34},{4, 0x4, 0x1A},{5, 0x4, 0xD},{6, 0x24, 0x6},{7, 0x24, 0x3},{8, 0xA4, 0x0}},
/* state = 0x1A5 (8 bits, 0xA5 buffer) */
{{1, 0x1, 0xD2},{2, 0x1, 0x69},{3, 0x5, 0x34},{4, 0x5, 0x1A},{5, 0x5, 0xD},{6, 0x25, 0x6},{7, 0x25, 0x3},{8, 0xA5, 0x0}},
/* state = 0x1A6 (8 bits, 0xA6 buffer) */
{{1, 0x0, 0xD3},{2, 0x2, 0x69},{3, 0x6, 0x34},{4, 0x6, 0x1A},{5, 0x6, 0xD},{6, 0x26, 0x6},{7, 0x26, 0x3},{8, 0xA6, 0x0}},
/* state = 0x1A7 (8 bits, 0xA7 buffer) */
{{1, 0x1, 0xD3},{2, 0x3, 0x69},{3, 0x7, 0x34},{4, 0x7, 0x1A},{5, 0x7, 0xD},{6, 0x27, 0x6},{7, 0x27, 0x3},{8, 0xA7, 0x0}},
/* state = 0x1A8 (8 bits, 0xA8 buffer) */
{{1, 0x0, 0xD4},{2, 0x0, 0x6A},{3, 0x0, 0x35},{4, 0x8, 0x1A},{5, 0x8, 0xD},{6, 0x28, 0x6},{7, 0x28, 0x3},{8, 0xA8, 0x0}},
/* state = 0x1A9 (8 bits, 0xA9 buffer) */
{{1, 0x1, 0xD4},{2, 0x1, 0x6A},{3, 0x1, 0x35},{4, 0x9, 0x1A},{5, 0x9, 0xD},{6, 0x29, 0x6},{7, 0x29, 0x3},{8, 0xA9, 0x0}},
/* state = 0x1AA (8 bits, 0xAA buffer) */
{{1, 0x0, 0xD5},{2, 0x2, 0x6A},{3, 0x2, 0x35},{4, 0xA, 0x1A},{5, 0xA, 0xD},{6, 0x2A, 0x6},{7, 0x2A, 0x3},{8, 0xAA, 0x0}},
/* state = 0x1AB (8 bits, 0xAB buffer) */
{{1, 0x1, 0xD5},{2, 0x3, 0x6A},{3, 0x3, 0x35},{4, 0xB, 0x1A},{5, 0xB, 0xD},{6, 0x2B, 0x6},{7, 0x2B, 0x3},{8, 0xAB, 0x0}},
/* state = 0x1AC (8 bits, 0xAC buffer) */
{{1, 0x0, 0xD6},{2, 0x0, 0x6B},{3, 0x4, 0x35},{4, 0xC, 0x1A},{5, 0xC, 0xD},{6, 0x2C, 0x6},{7, 0x2C, 0x3},{8, 0xAC, 0x0}},
/* state = 0x1AD (8 bits, 0xAD buffer) */
{{1, 0x1, 0xD6},{2, 0x1, 0x6B},{3, 0x5, 0x35},{4, 0xD, 0x1A},{5, 0xD, 0xD},{6, 0x2D, 0x6},{7, 0x2D, 0x3},{8, 0xAD, 0x0}},
/* state = 0x1AE (8 bits, 0xAE buffer) */
{{1, 0x0, 0xD7},{2, 0x2, 0x6B},{3, 0x6, 0x35},{4, 0xE, 0x1A},{5, 0xE, 0xD},{6, 0x2E, 0x6},{7, 0x2E, 0x3},{8, 0xAE, 0x0}},
/* state = 0x1AF (8 bits, 0xAF buffer) */
{{1, 0x1, 0xD7},{2, 0x3, 0x6B},{3, 0x7, 0x35},{4, 0xF, 0x1A},{5, 0xF, 0xD},{6, 0x2F, 0x6},{7, 0x2F, 0x3},{8, 0xAF, 0x0}},
/* state = 0x1B0 (8 bits, 0xB0 buffer) */
{{1, 0x0, 0xD8},{2, 0x0, 0x6C},{3, 0x0, 0x36},{4, 0x0, 0x1B},{5, 0x10, 0xD},{6, 0x30, 0x6},{7, 0x30, 0x3},{8, 0xB0, 0x0}},
/* state = 0x1B1 (8 bits, 0xB1 buffer) */
{{1, 0x1, 0xD8},{2, 0x1, 0x6C},{3, 0x1, 0x36},{4, 0x1, 0x1B},{5, 0x11, 0xD},{6, 0x31, 0x6},{7, 0x31, 0x3},{8, 0xB1, 0x0}},
/* state = 0x1B2 (8 bits, 0xB2 buffer) */
{{1, 0x0, 0xD9},{2, 0x2, 0x6C},{3, 0x2, 0x36},{4, 0x2, 0x1B},{5, 0x12, 0xD},{6, 0x32, 0x6},{7, 0x32, 0x3},{8, 0xB2, 0x0}},
/* state = 0x1B3 (8 bits, 0xB3 buffer) */
{{1, 0x1, 0xD9},{2, 0x3, 0x6C},{3, 0x3, 0x36},{4, 0x3, 0x1B},{5, 0x13, 0xD},{6, 0x33, 0x6},{7, 0x33, 0x3},{8, 0xB3, 0x0}},
/* state = 0x1B4 (8 bits, 0xB4 buffer) */
{{1, 0x0, 0xDA},{2, 0x0, 0x6D},{3, 0x4, 0x36},{4, 0x4, 0x1B},{5, 0x14, 0xD},{6, 0x34, 0x6},{7, 0x34, 0x3},{8, 0xB4, 0x0}},
/* state = 0x1B5 (8 bits, 0xB5 buffer) */
{{1, 0x1, 0xDA},{2, 0x1, 0x6D},{3, 0x5, 0x36},{4, 0x5, 0x1B},{5, 0x15, 0xD},{6, 0x35, 0x6},{7, 0x35, 0x3},{8, 0xB5, 0x0}},
/* state = 0x1B6 (8 bits, 0xB6 buffer) */
{{1, 0x0, 0xDB},{2, 0x2, 0x6D},{3, 0x6, 0x36},{4, 0x6, 0x1B},{5, 0x16, 0xD},{6, 0x36, 0x6},{7, 0x36, 0x3},{8, 0xB6, 0x0}},
/* state = 0x1B7 (8 bits, 0xB7 buffer) */
{{1, 0x1, 0xDB},{2, 0x3, 0x6D},{3, 0x7, 0x36},{4, 0x7, 0x1B},{5, 0x17, 0xD},{6, 0x37, 0x6},{7, 0x37, 0x3},{8, 0xB7, 0x0}},
/* state = 0x1B8 (8 bits, 0xB8 buffer) */
{{1, 0x0, 0xDC},{2, 0x0, 0x6E},{3, 0x0, 0x37},{4, 0x8, 0x1B},{5, 0x18, 0xD},{6, 0x38, 0x6},{7, 0x38, 0x3},{8, 0xB8, 0x0}},
/* state = 0x1B9 (8 bits, 0xB9 buffer) */
{{1, 0x1, 0xDC},{2, 0x1, 0x6E},{3, 0x1, 0x37},{4, 0x9, 0x1B},{5, 0x19, 0xD},{6, 0x39, 0x6},{7, 0x39, 0x3},{8, 0xB9, 0x0}},
/* state = 0x1BA (8 bits, 0xBA buffer) */
{{1, 0x0, 0xDD},{2, 0x2, 0x6E},{3, 0x2, 0x37},{4, 0xA, 0x1B},{5, 0x1A, 0xD},{6, 0x3A, 0x6},{7, 0x3A, 0x3},{8, 0xBA, 0x0}},
/* state = 0x1BB (8 bits, 0xBB buffer) */
{{1, 0x1, 0xDD},{2, 0x3, 0x6E},{3, 0x3, 0x37},{4, 0xB, 0x1B},{5, 0x1B, 0xD},{6, 0x3B, 0x6},{7, 0x3B, 0x3},{8, 0xBB, 0x0}},
/* state = 0x1BC (8 bits, 0xBC buffer) */
{{1, 0x0, 0xDE},{2, 0x0, 0x6F},{3, 0x4, 0x37},{4, 0xC, 0x1B},{5, 0x1C, 0xD},{6, 0x3C, 0x6},{7, 0x3C, 0x3},{8, 0xBC, 0x0}},
/* state = 0x1BD (8 bits, 0xBD buffer) */
{{1, 0x1, 0xDE},{2, 0x1, 0x6F},{3, 0x5, 0x37},{4, 0xD, 0x1B},{5, 0x1D, 0xD},{6, 0x3D, 0x6},{7, 0x3D, 0x3},{8, 0xBD, 0x0}},
/* state = 0x1BE (8 bits, 0xBE buffer) */
{{1, 0x0, 0xDF},{2, 0x2, 0x6F},{3, 0x6, 0x37},{4, 0xE, 0x1B},{5, 0x1E, 0xD},{6, 0x3E, 0x6},{7, 0x3E, 0x3},{8, 0xBE, 0x0}},
/* state = 0x1BF (8 bits, 0xBF buffer) */
{{1, 0x1, 0xDF},{2, 0x3, 0x6F},{3, 0x7, 0x37},{4, 0xF, 0x1B},{5, 0x1F, 0xD},{6, 0x3F, 0x6},{7, 0x3F, 0x3},{8, 0xBF, 0x0}},
/* state = 0x1C0 (8 bits, 0xC0 buffer) */
{{1, 0x0, 0xE0},{2, 0x0, 0x70},{3, 0x0, 0x38},{4, 0x0, 0x1C},{5, 0x0, 0xE},{6, 0x0, 0x7},{7, 0x40, 0x3},{8, 0xC0, 0x0}},
/* state = 0x1C1 (8 bits, 0xC1 buffer) */
{{1, 0x1, 0xE0},{2, 0x1, 0x70},{3, 0x1, 0x38},{4, 0x1, 0x1C},{5, 0x1, 0xE},{6, 0x1, 0x7},{7, 0x41, 0x3},{8, 0xC1, 0x0}},
/* state = 0x1C2 (8 bits, 0xC2 buffer) */
{{1, 0x0, 0xE1},{2, 0x2, 0x70},{3, 0x2, 0x38},{4, 0x2, 0x1C},{5, 0x2, 0xE},{6, 0x2, 0x7},{7, 0x42, 0x3},{8, 0xC2, 0x0}},
/* state = 0x1C3 (8 bits, 0xC3 buffer) */
{{1, 0x1, 0xE1},{2, 0x3, 0x70},{3, 0x3, 0x38},{4, 0x3, 0x1C},{5, 0x3, 0xE},{6, 0x3, 0x7},{7, 0x43, 0x3},{8, 0xC3, 0x0}},
/* state = 0x1C4 (8 bits, 0xC4 buffer) */
{{1, 0x0, 0xE2},{2, 0x0, 0x71},{3, 0x4, 0x38},{4, 0x4, 0x1C},{5, 0x4, 0xE},{6, 0x4, 0x7},{7, 0x44, 0x3},{8, 0xC4, 0x0}},
/* state = 0x1C5 (8 bits, 0xC5 buffer) */
{{1, 0x1, 0xE2},{2, 0x1, 0x71},{3, 0x5, 0x38},{4, 0x5, 0x1C},{5, 0x5, 0xE},{6, 0x5, 0x7},{7, 0x45, 0x3},{8, 0xC5, 0x0}},
/* state = 0x1C6 (8 bits, 0xC6 buffer) */
{{1, 0x0, 0xE3},{2, 0x2, 0x71},{3, 0x6, 0x38},{4, 0x6, 0x1C},{5, 0x6, 0xE},{6, 0x6, 0x7},{7, 0x46, 0x3},{8, 0xC6, 0x0}},
/* state = 0x1C7 (8 bits, 0xC7 buffer) */
{{1, 0x1, 0xE3},{2, 0x3, 0x71},{3, 0x7, 0x38},{4, 0x7, 0x1C},{5, 0x7, 0xE},{6, 0x7, 0x7},{7, 0x47, 0x3},{8, 0xC7, 0x0}},
/* state = 0x1C8 (8 bits, 0xC8 buffer) */
{{1, 0x0, 0xE4},{2, 0x0, 0x72},{3, 0x0, 0x39},{4, 0x8, 0x1C},{5, 0x8, 0xE},{6, 0x8, 0x7},{7, 0x48, 0x3},{8, 0xC8, 0x0}},
/* state = 0x1C9 (8 bits, 0xC9 buffer) */
{{1, 0x1, 0xE4},{2, 0x1, 0x72},{3, 0x1, 0x39},{4, 0x9, 0x1C},{5, 0x9, 0xE},{6, 0x9, 0x7},{7, 0x49, 0x3},{8, 0xC9, 0x0}},
/* state = 0x1CA (8 bits, 0xCA buffer) */
{{1, 0x0, 0xE5},{2, 0x2, 0x72},{3, 0x2, 0x39},{4, 0xA, 0x1C},{5, 0xA, 0xE},{6, 0xA, 0x7},{7, 0x4A, 0x3},{8, 0xCA, 0x0}},
/* state = 0x1CB (8 bits, 0xCB buffer) */
{{1, 0x1, 0xE5},{2, 0x3, 0x72},{3, 0x3, 0x39},{4, 0xB, 0x1C},{5, 0xB, 0xE},{6, 0xB, 0x7},{7, 0x4B, 0x3},{8, 0xCB, 0x0}},
/* state = 0x1CC (8 bits, 0xCC buffer) */
{{1, 0x0, 0xE6},{2, 0x0, 0x73},{3, 0x4, 0x39},{4, 0xC, 0x1C},{5, 0xC, 0xE},{6, 0xC, 0x7},{7, 0x4C, 0x3},{8, 0xCC, 0x0}},
/* state = 0x1CD (8 bits, 0xCD buffer) */
{{1, 0x1, 0xE6},{2, 0x1, 0x73},{3, 0x5, 0x39},{4, 0xD, 0x1C},{5, 0xD, 0xE},{6, 0xD, 0x7},{7, 0x4D, 0x3},{8, 0xCD, 0x0}},
/* state = 0x1CE (8 bits, 0xCE buffer) */
{{1, 0x0, 0xE7},{2, 0x2, 0x73},{3, 0x6, 0x39},{4, 0xE, 0x1C},{5, 0xE, 0xE},{6, 0xE, 0x7},{7, 0x4E, 0x3},{8, 0xCE, 0x0}},
/* state = 0x1CF (8 bits, 0xCF buffer) */
{{1, 0x1, 0xE7},{2, 0x3, 0x73},{3, 0x7, 0x39},{4, 0xF, 0x1C},{5, 0xF, 0xE},{6, 0xF, 0x7},{7, 0x4F, 0x3},{8, 0xCF, 0x0}},
/* state = 0x1D0 (8 bits, 0xD0 buffer) */
{{1, 0x0, 0xE8},{2, 0x0, 0x74},{3, 0x0, 0x3A},{4, 0x0, 0x1D},{5, 0x10, 0xE},{6, 0x10, 0x7},{7, 0x50, 0x3},{8, 0xD0, 0x0}},
/* state = 0x1D1 (8 bits, 0xD1 buffer) */
{{1, 0x1, 0xE8},{2, 0x1, 0x74},{3, 0x1, 0x3A},{4, 0x1, 0x1D},{5, 0x11, 0xE},{6, 0x11, 0x7},{7, 0x51, 0x3},{8, 0xD1, 0x0}},
/* state = 0x1D2 (8 bits, 0xD2 buffer) */
{{1, 0x0, 0xE9},{2, 0x2, 0x74},{3, 0x2, 0x3A},{4, 0x2, 0x1D},{5, 0x12, 0xE},{6, 0x12, 0x7},{7, 0x52, 0x3},{8, 0xD2, 0x0}},
/* state = 0x1D3 (8 bits, 0xD3 buffer) */
{{1, 0x1, 0xE9},{2, 0x3, 0x74},{3, 0x3, 0x3A},{4, 0x3, 0x1D},{5, 0x13, 0xE},{6, 0x13, 0x7},{7, 0x53, 0x3},{8, 0xD3, 0x0}},
/* state = 0x1D4 (8 bits, 0xD4 buffer) */
{{1, 0x0, 0xEA},{2, 0x0, 0x75},{3, 0x4, 0x3A},{4, 0x4, 0x1D},{5, 0x14, 0xE},{6, 0x14, 0x7},{7, 0x54, 0x3},{8, 0xD4, 0x0}},
/* state = 0x1D5 (8 bits, 0xD5 buffer) */
{{1, 0x1, 0xEA},{2, 0x1, 0x75},{3, 0x5, 0x3A},{4, 0x5, 0x1D},{5, 0x15, 0xE},{6, 0x15, 0x7},{7, 0x55, 0x3},{8, 0xD5, 0x0}},
/* state = 0x1D6 (8 bits, 0xD6 buffer) */
{{1, 0x0, 0xEB},{2, 0x2, 0x75},{3, 0x6, 0x3A},{4, 0x6, 0x1D},{5, 0x16, 0xE},{6, 0x16, 0x7},{7, 0x56, 0x3},{8, 0xD6, 0x0}},
/* state = 0x1D7 (8 bits, 0xD7 buffer) */
{{1, 0x1, 0xEB},{2, 0x3, 0x75},{3, 0x7, 0x3A},{4, 0x7, 0x1D},{5, 0x17, 0xE},{6, 0x17, 0x7},{7, 0x57, 0x3},{8, 0xD7, 0x0}},
/* state = 0x1D8 (8 bits, 0xD8 buffer) */
{{1, 0x0, 0xEC},{2, 0x0, 0x76},{3, 0x0, 0x3B},{4, 0x8, 0x1D},{5, 0x18, 0xE},{6, 0x18, 0x7},{7, 0x58, 0x3},{8, 0xD8, 0x0}},
/* state = 0x1D9 (8 bits, 0xD9 buffer) */
{{1, 0x1, 0xEC},{2, 0x1, 0x76},{3, 0x1, 0x3B},{4, 0x9, 0x1D},{5, 0x19, 0xE},{6, 0x19, 0x7},{7, 0x59, 0x3},{8, 0xD9, 0x0}},
/* state = 0x1DA (8 bits, 0xDA buffer) */
{{1, 0x0, 0xED},{2, 0x2, 0x76},{3, 0x2, 0x3B},{4, 0xA, 0x1D},{5, 0x1A, 0xE},{6, 0x1A, 0x7},{7, 0x5A, 0x3},{8, 0xDA, 0x0}},
/* state = 0x1DB (8 bits, 0xDB buffer) */
{{1, 0x1, 0xED},{2, 0x3, 0x76},{3, 0x3, 0x3B},{4, 0xB, 0x1D},{5, 0x1B, 0xE},{6, 0x1B, 0x7},{7, 0x5B, 0x3},{8, 0xDB, 0x0}},
/* state = 0x1DC (8 bits, 0xDC buffer) */
{{1, 0x0, 0xEE},{2, 0x0, 0x77},{3, 0x4, 0x3B},{4, 0xC, 0x1D},{5, 0x1C, 0xE},{6, 0x1C, 0x7},{7, 0x5C, 0x3},{8, 0xDC, 0x0}},
/* state = 0x1DD (8 bits, 0xDD buffer) */
{{1, 0x1, 0xEE},{2, 0x1, 0x77},{3, 0x5, 0x3B},{4, 0xD, 0x1D},{5, 0x1D, 0xE},{6, 0x1D, 0x7},{7, 0x5D, 0x3},{8, 0xDD, 0x0}},
/* state = 0x1DE (8 bits, 0xDE buffer) */
{{1, 0x0, 0xEF},{2, 0x2, 0x77},{3, 0x6, 0x3B},{4, 0xE, 0x1D},{5, 0x1E, 0xE},{6, 0x1E, 0x7},{7, 0x5E, 0x3},{8, 0xDE, 0x0}},
/* state = 0x1DF (8 bits, 0xDF buffer) */
{{1, 0x1, 0xEF},{2, 0x3, 0x77},{3, 0x7, 0x3B},{4, 0xF, 0x1D},{5, 0x1F, 0xE},{6, 0x1F, 0x7},{7, 0x5F, 0x3},{8, 0xDF, 0x0}},
/* state = 0x1E0 (8 bits, 0xE0 buffer) */
{{1, 0x0, 0xF0},{2, 0x0, 0x78},{3, 0x0, 0x3C},{4, 0x0, 0x1E},{5, 0x0, 0xF},{6, 0x20, 0x7},{7, 0x60, 0x3},{8, 0xE0, 0x0}},
/* state = 0x1E1 (8 bits, 0xE1 buffer) */
{{1, 0x1, 0xF0},{2, 0x1, 0x78},{3, 0x1, 0x3C},{4, 0x1, 0x1E},{5, 0x1, 0xF},{6, 0x21, 0x7},{7, 0x61, 0x3},{8, 0xE1, 0x0}},
/* state = 0x1E2 (8 bits, 0xE2 buffer) */
{{1, 0x0, 0xF1},{2, 0x2, 0x78},{3, 0x2, 0x3C},{4, 0x2, 0x1E},{5, 0x2, 0xF},{6, 0x22, 0x7},{7, 0x62, 0x3},{8, 0xE2, 0x0}},
/* state = 0x1E3 (8 bits, 0xE3 buffer) */
{{1, 0x1, 0xF1},{2, 0x3, 0x78},{3, 0x3, 0x3C},{4, 0x3, 0x1E},{5, 0x3, 0xF},{6, 0x23, 0x7},{7, 0x63, 0x3},{8, 0xE3, 0x0}},
/* state = 0x1E4 (8 bits, 0xE4 buffer) */
{{1, 0x0, 0xF2},{2, 0x0, 0x79},{3, 0x4, 0x3C},{4, 0x4, 0x1E},{5, 0x4, 0xF},{6, 0x24, 0x7},{7, 0x64, 0x3},{8, 0xE4, 0x0}},
/* state = 0x1E5 (8 bits, 0xE5 buffer) */
{{1, 0x1, 0xF2},{2, 0x1, 0x79},{3, 0x5, 0x3C},{4, 0x5, 0x1E},{5, 0x5, 0xF},{6, 0x25, 0x7},{7, 0x65, 0x3},{8, 0xE5, 0x0}},
/* state = 0x1E6 (8 bits, 0xE6 buffer) */
{{1, 0x0, 0xF3},{2, 0x2, 0x79},{3, 0x6, 0x3C},{4, 0x6, 0x1E},{5, 0x6, 0xF},{6, 0x26, 0x7},{7, 0x66, 0x3},{8, 0xE6, 0x0}},
/* state = 0x1E7 (8 bits, 0xE7 buffer) */
{{1, 0x1, 0xF3},{2, 0x3, 0x79},{3, 0x7, 0x3C},{4, 0x7, 0x1E},{5, 0x7, 0xF},{6, 0x27, 0x7},{7, 0x67, 0x3},{8, 0xE7, 0x0}},
/* state = 0x1E8 (8 bits, 0xE8 buffer) */
{{1, 0x0, 0xF4},{2, 0x0, 0x7A},{3, 0x0, 0x3D},{4, 0x8, 0x1E},{5, 0x8, 0xF},{6, 0x28, 0x7},{7, 0x68, 0x3},{8, 0xE8, 0x0}},
/* state = 0x1E9 (8 bits, 0xE9 buffer) */
{{1, 0x1, 0xF4},{2, 0x1, 0x7A},{3, 0x1, 0x3D},{4, 0x9, 0x1E},{5, 0x9, 0xF},{6, 0x29, 0x7},{7, 0x69, 0x3},{8, 0xE9, 0x0}},
/* state = 0x1EA (8 bits, 0xEA buffer) */
{{1, 0x0, 0xF5},{2, 0x2, 0x7A},{3, 0x2, 0x3D},{4, 0xA, 0x1E},{5, 0xA, 0xF},{6, 0x2A, 0x7},{7, 0x6A, 0x3},{8, 0xEA, 0x0}},
/* state = 0x1EB (8 bits, 0xEB buffer) */
{{1, 0x1, 0xF5},{2, 0x3, 0x7A},{3, 0x3, 0x3D},{4, 0xB, 0x1E},{5, 0xB, 0xF},{6, 0x2B, 0x7},{7, 0x6B, 0x3},{8, 0xEB, 0x0}},
/* state = 0x1EC (8 bits, 0xEC buffer) */
{{1, 0x0, 0xF6},{2, 0x0, 0x7B},{3, 0x4, 0x3D},{4, 0xC, 0x1E},{5, 0xC, 0xF},{6, 0x2C, 0x7},{7, 0x6C, 0x3},{8, 0xEC, 0x0}},
/* state = 0x1ED (8 bits, 0xED buffer) */
{{1, 0x1, 0xF6},{2, 0x1, 0x7B},{3, 0x5, 0x3D},{4, 0xD, 0x1E},{5, 0xD, 0xF},{6, 0x2D, 0x7},{7, 0x6D, 0x3},{8, 0xED, 0x0}},
/* state = 0x1EE (8 bits, 0xEE buffer) */
{{1, 0x0, 0xF7},{2, 0x2, 0x7B},{3, 0x6, 0x3D},{4, 0xE, 0x1E},{5, 0xE, 0xF},{6, 0x2E, 0x7},{7, 0x6E, 0x3},{8, 0xEE, 0x0}},
/* state = 0x1EF (8 bits, 0xEF buffer) */
{{1, 0x1, 0xF7},{2, 0x3, 0x7B},{3, 0x7, 0x3D},{4, 0xF, 0x1E},{5, 0xF, 0xF},{6, 0x2F, 0x7},{7, 0x6F, 0x3},{8, 0xEF, 0x0}},
/* state = 0x1F0 (8 bits, 0xF0 buffer) */
{{1, 0x0, 0xF8},{2, 0x0, 0x7C},{3, 0x0, 0x3E},{4, 0x0, 0x1F},{5, 0x10, 0xF},{6, 0x30, 0x7},{7, 0x70, 0x3},{8, 0xF0, 0x0}},
/* state = 0x1F1 (8 bits, 0xF1 buffer) */
{{1, 0x1, 0xF8},{2, 0x1, 0x7C},{3, 0x1, 0x3E},{4, 0x1, 0x1F},{5, 0x11, 0xF},{6, 0x31, 0x7},{7, 0x71, 0x3},{8, 0xF1, 0x0}},
/* state = 0x1F2 (8 bits, 0xF2 buffer) */
{{1, 0x0, 0xF9},{2, 0x2, 0x7C},{3, 0x2, 0x3E},{4, 0x2, 0x1F},{5, 0x12, 0xF},{6, 0x32, 0x7},{7, 0x72, 0x3},{8, 0xF2, 0x0}},
/* state = 0x1F3 (8 bits, 0xF3 buffer) */
{{1, 0x1, 0xF9},{2, 0x3, 0x7C},{3, 0x3, 0x3E},{4, 0x3, 0x1F},{5, 0x13, 0xF},{6, 0x33, 0x7},{7, 0x73, 0x3},{8, 0xF3, 0x0}},
/* state = 0x1F4 (8 bits, 0xF4 buffer) */
{{1, 0x0, 0xFA},{2, 0x0, 0x7D},{3, 0x4, 0x3E},{4, 0x4, 0x1F},{5, 0x14, 0xF},{6, 0x34, 0x7},{7, 0x74, 0x3},{8, 0xF4, 0x0}},
/* state = 0x1F5 (8 bits, 0xF5 buffer) */
{{1, 0x1, 0xFA},{2, 0x1, 0x7D},{3, 0x5, 0x3E},{4, 0x5, 0x1F},{5, 0x15, 0xF},{6, 0x35, 0x7},{7, 0x75, 0x3},{8, 0xF5, 0x0}},
/* state = 0x1F6 (8 bits, 0xF6 buffer) */
{{1, 0x0, 0xFB},{2, 0x2, 0x7D},{3, 0x6, 0x3E},{4, 0x6, 0x1F},{5, 0x16, 0xF},{6, 0x36, 0x7},{7, 0x76, 0x3},{8, 0xF6, 0x0}},
/* state = 0x1F7 (8 bits, 0xF7 buffer) */
{{1, 0x1, 0xFB},{2, 0x3, 0x7D},{3, 0x7, 0x3E},{4, 0x7, 0x1F},{5, 0x17, 0xF},{6, 0x37, 0x7},{7, 0x77, 0x3},{8, 0xF7, 0x0}},
/* state = 0x1F8 (8 bits, 0xF8 buffer) */
{{1, 0x0, 0xFC},{2, 0x0, 0x7E},{3, 0x0, 0x3F},{4, 0x8, 0x1F},{5, 0x18, 0xF},{6, 0x38, 0x7},{7, 0x78, 0x3},{8, 0xF8, 0x0}},
/* state = 0x1F9 (8 bits, 0xF9 buffer) */
{{1, 0x1, 0xFC},{2, 0x1, 0x7E},{3, 0x1, 0x3F},{4, 0x9, 0x1F},{5, 0x19, 0xF},{6, 0x39, 0x7},{7, 0x79, 0x3},{8, 0xF9, 0x0}},
/* state = 0x1FA (8 bits, 0xFA buffer) */
{{1, 0x0, 0xFD},{2, 0x2, 0x7E},{3, 0x2, 0x3F},{4, 0xA, 0x1F},{5, 0x1A, 0xF},{6, 0x3A, 0x7},{7, 0x7A, 0x3},{8, 0xFA, 0x0}},
/* state = 0x1FB (8 bits, 0xFB buffer) */
{{1, 0x1, 0xFD},{2, 0x3, 0x7E},{3, 0x3, 0x3F},{4, 0xB, 0x1F},{5, 0x1B, 0xF},{6, 0x3B, 0x7},{7, 0x7B, 0x3},{8, 0xFB, 0x0}},
/* state = 0x1FC (8 bits, 0xFC buffer) */
{{1, 0x0, 0xFE},{2, 0x0, 0x7F},{3, 0x4, 0x3F},{4, 0xC, 0x1F},{5, 0x1C, 0xF},{6, 0x3C, 0x7},{7, 0x7C, 0x3},{8, 0xFC, 0x0}},
/* state = 0x1FD (8 bits, 0xFD buffer) */
{{1, 0x1, 0xFE},{2, 0x1, 0x7F},{3, 0x5, 0x3F},{4, 0xD, 0x1F},{5, 0x1D, 0xF},{6, 0x3D, 0x7},{7, 0x7D, 0x3},{8, 0xFD, 0x0}},
/* state = 0x1FE (8 bits, 0xFE buffer) */
{{1, 0x0, 0xFF},{2, 0x2, 0x7F},{3, 0x6, 0x3F},{4, 0xE, 0x1F},{5, 0x1E, 0xF},{6, 0x3E, 0x7},{7, 0x7E, 0x3},{8, 0xFE, 0x0}},
/* state = 0x1FF (8 bits, 0xFF buffer) */
{{1, 0x1, 0xFF},{2, 0x3, 0x7F},{3, 0x7, 0x3F},{4, 0xF, 0x1F},{5, 0x1F, 0xF},{6, 0x3F, 0x7},{7, 0x7F, 0x3},{8, 0xFF, 0x0}}
}
