/********************************************************
 Bitstream Library, a module for reading bits of data

 Copyright (C) 2007-2015  Brian Langenberger

 The Bitstream Library is free software; you can redistribute it and/or modify
 it under the terms of either:

   * the GNU Lesser General Public License as published by the Free
     Software Foundation; either version 3 of the License, or (at your
     option) any later version.

 or

   * the GNU General Public License as published by the Free Software
     Foundation; either version 2 of the License, or (at your option) any
     later version.

 or both in parallel, as here.

 The Bitstream Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.

 You should have received copies of the GNU General Public License and the
 GNU Lesser General Public License along with the GNU MP Library.  If not,
 see https://www.gnu.org/licenses/.
 *******************************************************/

{
/* state = 0x0 (0 bits, 0x0 buffer) */
{{1, 0x0, 0x0},{1, 0x0, 0x0}},
/* state = 0x1 (0 bits, 0x0 buffer) */
{{1, 0x0, 0x0},{1, 0x0, 0x0}},
/* state = 0x2 (1 bits, 0x0 buffer) */
{{0, 0x0, 0x0},{1, 0x1, 0x0}},
/* state = 0x3 (1 bits, 0x1 buffer) */
{{1, 0x1, 0x0},{0, 0x0, 0x0}},
/* state = 0x4 (2 bits, 0x0 buffer) */
{{0, 0x0, 0x2},{1, 0x2, 0x0}},
/* state = 0x5 (2 bits, 0x1 buffer) */
{{0, 0x1, 0x0},{0, 0x0, 0x2}},
/* state = 0x6 (2 bits, 0x2 buffer) */
{{0, 0x0, 0x3},{0, 0x1, 0x0}},
/* state = 0x7 (2 bits, 0x3 buffer) */
{{1, 0x2, 0x0},{0, 0x0, 0x3}},
/* state = 0x8 (3 bits, 0x0 buffer) */
{{0, 0x0, 0x4},{1, 0x3, 0x0}},
/* state = 0x9 (3 bits, 0x1 buffer) */
{{0, 0x1, 0x2},{0, 0x0, 0x4}},
/* state = 0xA (3 bits, 0x2 buffer) */
{{0, 0x0, 0x5},{0, 0x1, 0x2}},
/* state = 0xB (3 bits, 0x3 buffer) */
{{0, 0x2, 0x0},{0, 0x0, 0x5}},
/* state = 0xC (3 bits, 0x4 buffer) */
{{0, 0x0, 0x6},{0, 0x2, 0x0}},
/* state = 0xD (3 bits, 0x5 buffer) */
{{0, 0x1, 0x3},{0, 0x0, 0x6}},
/* state = 0xE (3 bits, 0x6 buffer) */
{{0, 0x0, 0x7},{0, 0x1, 0x3}},
/* state = 0xF (3 bits, 0x7 buffer) */
{{1, 0x3, 0x0},{0, 0x0, 0x7}},
/* state = 0x10 (4 bits, 0x0 buffer) */
{{0, 0x0, 0x8},{1, 0x4, 0x0}},
/* state = 0x11 (4 bits, 0x1 buffer) */
{{0, 0x1, 0x4},{0, 0x0, 0x8}},
/* state = 0x12 (4 bits, 0x2 buffer) */
{{0, 0x0, 0x9},{0, 0x1, 0x4}},
/* state = 0x13 (4 bits, 0x3 buffer) */
{{0, 0x2, 0x2},{0, 0x0, 0x9}},
/* state = 0x14 (4 bits, 0x4 buffer) */
{{0, 0x0, 0xA},{0, 0x2, 0x2}},
/* state = 0x15 (4 bits, 0x5 buffer) */
{{0, 0x1, 0x5},{0, 0x0, 0xA}},
/* state = 0x16 (4 bits, 0x6 buffer) */
{{0, 0x0, 0xB},{0, 0x1, 0x5}},
/* state = 0x17 (4 bits, 0x7 buffer) */
{{0, 0x3, 0x0},{0, 0x0, 0xB}},
/* state = 0x18 (4 bits, 0x8 buffer) */
{{0, 0x0, 0xC},{0, 0x3, 0x0}},
/* state = 0x19 (4 bits, 0x9 buffer) */
{{0, 0x1, 0x6},{0, 0x0, 0xC}},
/* state = 0x1A (4 bits, 0xA buffer) */
{{0, 0x0, 0xD},{0, 0x1, 0x6}},
/* state = 0x1B (4 bits, 0xB buffer) */
{{0, 0x2, 0x3},{0, 0x0, 0xD}},
/* state = 0x1C (4 bits, 0xC buffer) */
{{0, 0x0, 0xE},{0, 0x2, 0x3}},
/* state = 0x1D (4 bits, 0xD buffer) */
{{0, 0x1, 0x7},{0, 0x0, 0xE}},
/* state = 0x1E (4 bits, 0xE buffer) */
{{0, 0x0, 0xF},{0, 0x1, 0x7}},
/* state = 0x1F (4 bits, 0xF buffer) */
{{1, 0x4, 0x0},{0, 0x0, 0xF}},
/* state = 0x20 (5 bits, 0x0 buffer) */
{{0, 0x0, 0x10},{1, 0x5, 0x0}},
/* state = 0x21 (5 bits, 0x1 buffer) */
{{0, 0x1, 0x8},{0, 0x0, 0x10}},
/* state = 0x22 (5 bits, 0x2 buffer) */
{{0, 0x0, 0x11},{0, 0x1, 0x8}},
/* state = 0x23 (5 bits, 0x3 buffer) */
{{0, 0x2, 0x4},{0, 0x0, 0x11}},
/* state = 0x24 (5 bits, 0x4 buffer) */
{{0, 0x0, 0x12},{0, 0x2, 0x4}},
/* state = 0x25 (5 bits, 0x5 buffer) */
{{0, 0x1, 0x9},{0, 0x0, 0x12}},
/* state = 0x26 (5 bits, 0x6 buffer) */
{{0, 0x0, 0x13},{0, 0x1, 0x9}},
/* state = 0x27 (5 bits, 0x7 buffer) */
{{0, 0x3, 0x2},{0, 0x0, 0x13}},
/* state = 0x28 (5 bits, 0x8 buffer) */
{{0, 0x0, 0x14},{0, 0x3, 0x2}},
/* state = 0x29 (5 bits, 0x9 buffer) */
{{0, 0x1, 0xA},{0, 0x0, 0x14}},
/* state = 0x2A (5 bits, 0xA buffer) */
{{0, 0x0, 0x15},{0, 0x1, 0xA}},
/* state = 0x2B (5 bits, 0xB buffer) */
{{0, 0x2, 0x5},{0, 0x0, 0x15}},
/* state = 0x2C (5 bits, 0xC buffer) */
{{0, 0x0, 0x16},{0, 0x2, 0x5}},
/* state = 0x2D (5 bits, 0xD buffer) */
{{0, 0x1, 0xB},{0, 0x0, 0x16}},
/* state = 0x2E (5 bits, 0xE buffer) */
{{0, 0x0, 0x17},{0, 0x1, 0xB}},
/* state = 0x2F (5 bits, 0xF buffer) */
{{0, 0x4, 0x0},{0, 0x0, 0x17}},
/* state = 0x30 (5 bits, 0x10 buffer) */
{{0, 0x0, 0x18},{0, 0x4, 0x0}},
/* state = 0x31 (5 bits, 0x11 buffer) */
{{0, 0x1, 0xC},{0, 0x0, 0x18}},
/* state = 0x32 (5 bits, 0x12 buffer) */
{{0, 0x0, 0x19},{0, 0x1, 0xC}},
/* state = 0x33 (5 bits, 0x13 buffer) */
{{0, 0x2, 0x6},{0, 0x0, 0x19}},
/* state = 0x34 (5 bits, 0x14 buffer) */
{{0, 0x0, 0x1A},{0, 0x2, 0x6}},
/* state = 0x35 (5 bits, 0x15 buffer) */
{{0, 0x1, 0xD},{0, 0x0, 0x1A}},
/* state = 0x36 (5 bits, 0x16 buffer) */
{{0, 0x0, 0x1B},{0, 0x1, 0xD}},
/* state = 0x37 (5 bits, 0x17 buffer) */
{{0, 0x3, 0x3},{0, 0x0, 0x1B}},
/* state = 0x38 (5 bits, 0x18 buffer) */
{{0, 0x0, 0x1C},{0, 0x3, 0x3}},
/* state = 0x39 (5 bits, 0x19 buffer) */
{{0, 0x1, 0xE},{0, 0x0, 0x1C}},
/* state = 0x3A (5 bits, 0x1A buffer) */
{{0, 0x0, 0x1D},{0, 0x1, 0xE}},
/* state = 0x3B (5 bits, 0x1B buffer) */
{{0, 0x2, 0x7},{0, 0x0, 0x1D}},
/* state = 0x3C (5 bits, 0x1C buffer) */
{{0, 0x0, 0x1E},{0, 0x2, 0x7}},
/* state = 0x3D (5 bits, 0x1D buffer) */
{{0, 0x1, 0xF},{0, 0x0, 0x1E}},
/* state = 0x3E (5 bits, 0x1E buffer) */
{{0, 0x0, 0x1F},{0, 0x1, 0xF}},
/* state = 0x3F (5 bits, 0x1F buffer) */
{{1, 0x5, 0x0},{0, 0x0, 0x1F}},
/* state = 0x40 (6 bits, 0x0 buffer) */
{{0, 0x0, 0x20},{1, 0x6, 0x0}},
/* state = 0x41 (6 bits, 0x1 buffer) */
{{0, 0x1, 0x10},{0, 0x0, 0x20}},
/* state = 0x42 (6 bits, 0x2 buffer) */
{{0, 0x0, 0x21},{0, 0x1, 0x10}},
/* state = 0x43 (6 bits, 0x3 buffer) */
{{0, 0x2, 0x8},{0, 0x0, 0x21}},
/* state = 0x44 (6 bits, 0x4 buffer) */
{{0, 0x0, 0x22},{0, 0x2, 0x8}},
/* state = 0x45 (6 bits, 0x5 buffer) */
{{0, 0x1, 0x11},{0, 0x0, 0x22}},
/* state = 0x46 (6 bits, 0x6 buffer) */
{{0, 0x0, 0x23},{0, 0x1, 0x11}},
/* state = 0x47 (6 bits, 0x7 buffer) */
{{0, 0x3, 0x4},{0, 0x0, 0x23}},
/* state = 0x48 (6 bits, 0x8 buffer) */
{{0, 0x0, 0x24},{0, 0x3, 0x4}},
/* state = 0x49 (6 bits, 0x9 buffer) */
{{0, 0x1, 0x12},{0, 0x0, 0x24}},
/* state = 0x4A (6 bits, 0xA buffer) */
{{0, 0x0, 0x25},{0, 0x1, 0x12}},
/* state = 0x4B (6 bits, 0xB buffer) */
{{0, 0x2, 0x9},{0, 0x0, 0x25}},
/* state = 0x4C (6 bits, 0xC buffer) */
{{0, 0x0, 0x26},{0, 0x2, 0x9}},
/* state = 0x4D (6 bits, 0xD buffer) */
{{0, 0x1, 0x13},{0, 0x0, 0x26}},
/* state = 0x4E (6 bits, 0xE buffer) */
{{0, 0x0, 0x27},{0, 0x1, 0x13}},
/* state = 0x4F (6 bits, 0xF buffer) */
{{0, 0x4, 0x2},{0, 0x0, 0x27}},
/* state = 0x50 (6 bits, 0x10 buffer) */
{{0, 0x0, 0x28},{0, 0x4, 0x2}},
/* state = 0x51 (6 bits, 0x11 buffer) */
{{0, 0x1, 0x14},{0, 0x0, 0x28}},
/* state = 0x52 (6 bits, 0x12 buffer) */
{{0, 0x0, 0x29},{0, 0x1, 0x14}},
/* state = 0x53 (6 bits, 0x13 buffer) */
{{0, 0x2, 0xA},{0, 0x0, 0x29}},
/* state = 0x54 (6 bits, 0x14 buffer) */
{{0, 0x0, 0x2A},{0, 0x2, 0xA}},
/* state = 0x55 (6 bits, 0x15 buffer) */
{{0, 0x1, 0x15},{0, 0x0, 0x2A}},
/* state = 0x56 (6 bits, 0x16 buffer) */
{{0, 0x0, 0x2B},{0, 0x1, 0x15}},
/* state = 0x57 (6 bits, 0x17 buffer) */
{{0, 0x3, 0x5},{0, 0x0, 0x2B}},
/* state = 0x58 (6 bits, 0x18 buffer) */
{{0, 0x0, 0x2C},{0, 0x3, 0x5}},
/* state = 0x59 (6 bits, 0x19 buffer) */
{{0, 0x1, 0x16},{0, 0x0, 0x2C}},
/* state = 0x5A (6 bits, 0x1A buffer) */
{{0, 0x0, 0x2D},{0, 0x1, 0x16}},
/* state = 0x5B (6 bits, 0x1B buffer) */
{{0, 0x2, 0xB},{0, 0x0, 0x2D}},
/* state = 0x5C (6 bits, 0x1C buffer) */
{{0, 0x0, 0x2E},{0, 0x2, 0xB}},
/* state = 0x5D (6 bits, 0x1D buffer) */
{{0, 0x1, 0x17},{0, 0x0, 0x2E}},
/* state = 0x5E (6 bits, 0x1E buffer) */
{{0, 0x0, 0x2F},{0, 0x1, 0x17}},
/* state = 0x5F (6 bits, 0x1F buffer) */
{{0, 0x5, 0x0},{0, 0x0, 0x2F}},
/* state = 0x60 (6 bits, 0x20 buffer) */
{{0, 0x0, 0x30},{0, 0x5, 0x0}},
/* state = 0x61 (6 bits, 0x21 buffer) */
{{0, 0x1, 0x18},{0, 0x0, 0x30}},
/* state = 0x62 (6 bits, 0x22 buffer) */
{{0, 0x0, 0x31},{0, 0x1, 0x18}},
/* state = 0x63 (6 bits, 0x23 buffer) */
{{0, 0x2, 0xC},{0, 0x0, 0x31}},
/* state = 0x64 (6 bits, 0x24 buffer) */
{{0, 0x0, 0x32},{0, 0x2, 0xC}},
/* state = 0x65 (6 bits, 0x25 buffer) */
{{0, 0x1, 0x19},{0, 0x0, 0x32}},
/* state = 0x66 (6 bits, 0x26 buffer) */
{{0, 0x0, 0x33},{0, 0x1, 0x19}},
/* state = 0x67 (6 bits, 0x27 buffer) */
{{0, 0x3, 0x6},{0, 0x0, 0x33}},
/* state = 0x68 (6 bits, 0x28 buffer) */
{{0, 0x0, 0x34},{0, 0x3, 0x6}},
/* state = 0x69 (6 bits, 0x29 buffer) */
{{0, 0x1, 0x1A},{0, 0x0, 0x34}},
/* state = 0x6A (6 bits, 0x2A buffer) */
{{0, 0x0, 0x35},{0, 0x1, 0x1A}},
/* state = 0x6B (6 bits, 0x2B buffer) */
{{0, 0x2, 0xD},{0, 0x0, 0x35}},
/* state = 0x6C (6 bits, 0x2C buffer) */
{{0, 0x0, 0x36},{0, 0x2, 0xD}},
/* state = 0x6D (6 bits, 0x2D buffer) */
{{0, 0x1, 0x1B},{0, 0x0, 0x36}},
/* state = 0x6E (6 bits, 0x2E buffer) */
{{0, 0x0, 0x37},{0, 0x1, 0x1B}},
/* state = 0x6F (6 bits, 0x2F buffer) */
{{0, 0x4, 0x3},{0, 0x0, 0x37}},
/* state = 0x70 (6 bits, 0x30 buffer) */
{{0, 0x0, 0x38},{0, 0x4, 0x3}},
/* state = 0x71 (6 bits, 0x31 buffer) */
{{0, 0x1, 0x1C},{0, 0x0, 0x38}},
/* state = 0x72 (6 bits, 0x32 buffer) */
{{0, 0x0, 0x39},{0, 0x1, 0x1C}},
/* state = 0x73 (6 bits, 0x33 buffer) */
{{0, 0x2, 0xE},{0, 0x0, 0x39}},
/* state = 0x74 (6 bits, 0x34 buffer) */
{{0, 0x0, 0x3A},{0, 0x2, 0xE}},
/* state = 0x75 (6 bits, 0x35 buffer) */
{{0, 0x1, 0x1D},{0, 0x0, 0x3A}},
/* state = 0x76 (6 bits, 0x36 buffer) */
{{0, 0x0, 0x3B},{0, 0x1, 0x1D}},
/* state = 0x77 (6 bits, 0x37 buffer) */
{{0, 0x3, 0x7},{0, 0x0, 0x3B}},
/* state = 0x78 (6 bits, 0x38 buffer) */
{{0, 0x0, 0x3C},{0, 0x3, 0x7}},
/* state = 0x79 (6 bits, 0x39 buffer) */
{{0, 0x1, 0x1E},{0, 0x0, 0x3C}},
/* state = 0x7A (6 bits, 0x3A buffer) */
{{0, 0x0, 0x3D},{0, 0x1, 0x1E}},
/* state = 0x7B (6 bits, 0x3B buffer) */
{{0, 0x2, 0xF},{0, 0x0, 0x3D}},
/* state = 0x7C (6 bits, 0x3C buffer) */
{{0, 0x0, 0x3E},{0, 0x2, 0xF}},
/* state = 0x7D (6 bits, 0x3D buffer) */
{{0, 0x1, 0x1F},{0, 0x0, 0x3E}},
/* state = 0x7E (6 bits, 0x3E buffer) */
{{0, 0x0, 0x3F},{0, 0x1, 0x1F}},
/* state = 0x7F (6 bits, 0x3F buffer) */
{{1, 0x6, 0x0},{0, 0x0, 0x3F}},
/* state = 0x80 (7 bits, 0x0 buffer) */
{{0, 0x0, 0x40},{1, 0x7, 0x0}},
/* state = 0x81 (7 bits, 0x1 buffer) */
{{0, 0x1, 0x20},{0, 0x0, 0x40}},
/* state = 0x82 (7 bits, 0x2 buffer) */
{{0, 0x0, 0x41},{0, 0x1, 0x20}},
/* state = 0x83 (7 bits, 0x3 buffer) */
{{0, 0x2, 0x10},{0, 0x0, 0x41}},
/* state = 0x84 (7 bits, 0x4 buffer) */
{{0, 0x0, 0x42},{0, 0x2, 0x10}},
/* state = 0x85 (7 bits, 0x5 buffer) */
{{0, 0x1, 0x21},{0, 0x0, 0x42}},
/* state = 0x86 (7 bits, 0x6 buffer) */
{{0, 0x0, 0x43},{0, 0x1, 0x21}},
/* state = 0x87 (7 bits, 0x7 buffer) */
{{0, 0x3, 0x8},{0, 0x0, 0x43}},
/* state = 0x88 (7 bits, 0x8 buffer) */
{{0, 0x0, 0x44},{0, 0x3, 0x8}},
/* state = 0x89 (7 bits, 0x9 buffer) */
{{0, 0x1, 0x22},{0, 0x0, 0x44}},
/* state = 0x8A (7 bits, 0xA buffer) */
{{0, 0x0, 0x45},{0, 0x1, 0x22}},
/* state = 0x8B (7 bits, 0xB buffer) */
{{0, 0x2, 0x11},{0, 0x0, 0x45}},
/* state = 0x8C (7 bits, 0xC buffer) */
{{0, 0x0, 0x46},{0, 0x2, 0x11}},
/* state = 0x8D (7 bits, 0xD buffer) */
{{0, 0x1, 0x23},{0, 0x0, 0x46}},
/* state = 0x8E (7 bits, 0xE buffer) */
{{0, 0x0, 0x47},{0, 0x1, 0x23}},
/* state = 0x8F (7 bits, 0xF buffer) */
{{0, 0x4, 0x4},{0, 0x0, 0x47}},
/* state = 0x90 (7 bits, 0x10 buffer) */
{{0, 0x0, 0x48},{0, 0x4, 0x4}},
/* state = 0x91 (7 bits, 0x11 buffer) */
{{0, 0x1, 0x24},{0, 0x0, 0x48}},
/* state = 0x92 (7 bits, 0x12 buffer) */
{{0, 0x0, 0x49},{0, 0x1, 0x24}},
/* state = 0x93 (7 bits, 0x13 buffer) */
{{0, 0x2, 0x12},{0, 0x0, 0x49}},
/* state = 0x94 (7 bits, 0x14 buffer) */
{{0, 0x0, 0x4A},{0, 0x2, 0x12}},
/* state = 0x95 (7 bits, 0x15 buffer) */
{{0, 0x1, 0x25},{0, 0x0, 0x4A}},
/* state = 0x96 (7 bits, 0x16 buffer) */
{{0, 0x0, 0x4B},{0, 0x1, 0x25}},
/* state = 0x97 (7 bits, 0x17 buffer) */
{{0, 0x3, 0x9},{0, 0x0, 0x4B}},
/* state = 0x98 (7 bits, 0x18 buffer) */
{{0, 0x0, 0x4C},{0, 0x3, 0x9}},
/* state = 0x99 (7 bits, 0x19 buffer) */
{{0, 0x1, 0x26},{0, 0x0, 0x4C}},
/* state = 0x9A (7 bits, 0x1A buffer) */
{{0, 0x0, 0x4D},{0, 0x1, 0x26}},
/* state = 0x9B (7 bits, 0x1B buffer) */
{{0, 0x2, 0x13},{0, 0x0, 0x4D}},
/* state = 0x9C (7 bits, 0x1C buffer) */
{{0, 0x0, 0x4E},{0, 0x2, 0x13}},
/* state = 0x9D (7 bits, 0x1D buffer) */
{{0, 0x1, 0x27},{0, 0x0, 0x4E}},
/* state = 0x9E (7 bits, 0x1E buffer) */
{{0, 0x0, 0x4F},{0, 0x1, 0x27}},
/* state = 0x9F (7 bits, 0x1F buffer) */
{{0, 0x5, 0x2},{0, 0x0, 0x4F}},
/* state = 0xA0 (7 bits, 0x20 buffer) */
{{0, 0x0, 0x50},{0, 0x5, 0x2}},
/* state = 0xA1 (7 bits, 0x21 buffer) */
{{0, 0x1, 0x28},{0, 0x0, 0x50}},
/* state = 0xA2 (7 bits, 0x22 buffer) */
{{0, 0x0, 0x51},{0, 0x1, 0x28}},
/* state = 0xA3 (7 bits, 0x23 buffer) */
{{0, 0x2, 0x14},{0, 0x0, 0x51}},
/* state = 0xA4 (7 bits, 0x24 buffer) */
{{0, 0x0, 0x52},{0, 0x2, 0x14}},
/* state = 0xA5 (7 bits, 0x25 buffer) */
{{0, 0x1, 0x29},{0, 0x0, 0x52}},
/* state = 0xA6 (7 bits, 0x26 buffer) */
{{0, 0x0, 0x53},{0, 0x1, 0x29}},
/* state = 0xA7 (7 bits, 0x27 buffer) */
{{0, 0x3, 0xA},{0, 0x0, 0x53}},
/* state = 0xA8 (7 bits, 0x28 buffer) */
{{0, 0x0, 0x54},{0, 0x3, 0xA}},
/* state = 0xA9 (7 bits, 0x29 buffer) */
{{0, 0x1, 0x2A},{0, 0x0, 0x54}},
/* state = 0xAA (7 bits, 0x2A buffer) */
{{0, 0x0, 0x55},{0, 0x1, 0x2A}},
/* state = 0xAB (7 bits, 0x2B buffer) */
{{0, 0x2, 0x15},{0, 0x0, 0x55}},
/* state = 0xAC (7 bits, 0x2C buffer) */
{{0, 0x0, 0x56},{0, 0x2, 0x15}},
/* state = 0xAD (7 bits, 0x2D buffer) */
{{0, 0x1, 0x2B},{0, 0x0, 0x56}},
/* state = 0xAE (7 bits, 0x2E buffer) */
{{0, 0x0, 0x57},{0, 0x1, 0x2B}},
/* state = 0xAF (7 bits, 0x2F buffer) */
{{0, 0x4, 0x5},{0, 0x0, 0x57}},
/* state = 0xB0 (7 bits, 0x30 buffer) */
{{0, 0x0, 0x58},{0, 0x4, 0x5}},
/* state = 0xB1 (7 bits, 0x31 buffer) */
{{0, 0x1, 0x2C},{0, 0x0, 0x58}},
/* state = 0xB2 (7 bits, 0x32 buffer) */
{{0, 0x0, 0x59},{0, 0x1, 0x2C}},
/* state = 0xB3 (7 bits, 0x33 buffer) */
{{0, 0x2, 0x16},{0, 0x0, 0x59}},
/* state = 0xB4 (7 bits, 0x34 buffer) */
{{0, 0x0, 0x5A},{0, 0x2, 0x16}},
/* state = 0xB5 (7 bits, 0x35 buffer) */
{{0, 0x1, 0x2D},{0, 0x0, 0x5A}},
/* state = 0xB6 (7 bits, 0x36 buffer) */
{{0, 0x0, 0x5B},{0, 0x1, 0x2D}},
/* state = 0xB7 (7 bits, 0x37 buffer) */
{{0, 0x3, 0xB},{0, 0x0, 0x5B}},
/* state = 0xB8 (7 bits, 0x38 buffer) */
{{0, 0x0, 0x5C},{0, 0x3, 0xB}},
/* state = 0xB9 (7 bits, 0x39 buffer) */
{{0, 0x1, 0x2E},{0, 0x0, 0x5C}},
/* state = 0xBA (7 bits, 0x3A buffer) */
{{0, 0x0, 0x5D},{0, 0x1, 0x2E}},
/* state = 0xBB (7 bits, 0x3B buffer) */
{{0, 0x2, 0x17},{0, 0x0, 0x5D}},
/* state = 0xBC (7 bits, 0x3C buffer) */
{{0, 0x0, 0x5E},{0, 0x2, 0x17}},
/* state = 0xBD (7 bits, 0x3D buffer) */
{{0, 0x1, 0x2F},{0, 0x0, 0x5E}},
/* state = 0xBE (7 bits, 0x3E buffer) */
{{0, 0x0, 0x5F},{0, 0x1, 0x2F}},
/* state = 0xBF (7 bits, 0x3F buffer) */
{{0, 0x6, 0x0},{0, 0x0, 0x5F}},
/* state = 0xC0 (7 bits, 0x40 buffer) */
{{0, 0x0, 0x60},{0, 0x6, 0x0}},
/* state = 0xC1 (7 bits, 0x41 buffer) */
{{0, 0x1, 0x30},{0, 0x0, 0x60}},
/* state = 0xC2 (7 bits, 0x42 buffer) */
{{0, 0x0, 0x61},{0, 0x1, 0x30}},
/* state = 0xC3 (7 bits, 0x43 buffer) */
{{0, 0x2, 0x18},{0, 0x0, 0x61}},
/* state = 0xC4 (7 bits, 0x44 buffer) */
{{0, 0x0, 0x62},{0, 0x2, 0x18}},
/* state = 0xC5 (7 bits, 0x45 buffer) */
{{0, 0x1, 0x31},{0, 0x0, 0x62}},
/* state = 0xC6 (7 bits, 0x46 buffer) */
{{0, 0x0, 0x63},{0, 0x1, 0x31}},
/* state = 0xC7 (7 bits, 0x47 buffer) */
{{0, 0x3, 0xC},{0, 0x0, 0x63}},
/* state = 0xC8 (7 bits, 0x48 buffer) */
{{0, 0x0, 0x64},{0, 0x3, 0xC}},
/* state = 0xC9 (7 bits, 0x49 buffer) */
{{0, 0x1, 0x32},{0, 0x0, 0x64}},
/* state = 0xCA (7 bits, 0x4A buffer) */
{{0, 0x0, 0x65},{0, 0x1, 0x32}},
/* state = 0xCB (7 bits, 0x4B buffer) */
{{0, 0x2, 0x19},{0, 0x0, 0x65}},
/* state = 0xCC (7 bits, 0x4C buffer) */
{{0, 0x0, 0x66},{0, 0x2, 0x19}},
/* state = 0xCD (7 bits, 0x4D buffer) */
{{0, 0x1, 0x33},{0, 0x0, 0x66}},
/* state = 0xCE (7 bits, 0x4E buffer) */
{{0, 0x0, 0x67},{0, 0x1, 0x33}},
/* state = 0xCF (7 bits, 0x4F buffer) */
{{0, 0x4, 0x6},{0, 0x0, 0x67}},
/* state = 0xD0 (7 bits, 0x50 buffer) */
{{0, 0x0, 0x68},{0, 0x4, 0x6}},
/* state = 0xD1 (7 bits, 0x51 buffer) */
{{0, 0x1, 0x34},{0, 0x0, 0x68}},
/* state = 0xD2 (7 bits, 0x52 buffer) */
{{0, 0x0, 0x69},{0, 0x1, 0x34}},
/* state = 0xD3 (7 bits, 0x53 buffer) */
{{0, 0x2, 0x1A},{0, 0x0, 0x69}},
/* state = 0xD4 (7 bits, 0x54 buffer) */
{{0, 0x0, 0x6A},{0, 0x2, 0x1A}},
/* state = 0xD5 (7 bits, 0x55 buffer) */
{{0, 0x1, 0x35},{0, 0x0, 0x6A}},
/* state = 0xD6 (7 bits, 0x56 buffer) */
{{0, 0x0, 0x6B},{0, 0x1, 0x35}},
/* state = 0xD7 (7 bits, 0x57 buffer) */
{{0, 0x3, 0xD},{0, 0x0, 0x6B}},
/* state = 0xD8 (7 bits, 0x58 buffer) */
{{0, 0x0, 0x6C},{0, 0x3, 0xD}},
/* state = 0xD9 (7 bits, 0x59 buffer) */
{{0, 0x1, 0x36},{0, 0x0, 0x6C}},
/* state = 0xDA (7 bits, 0x5A buffer) */
{{0, 0x0, 0x6D},{0, 0x1, 0x36}},
/* state = 0xDB (7 bits, 0x5B buffer) */
{{0, 0x2, 0x1B},{0, 0x0, 0x6D}},
/* state = 0xDC (7 bits, 0x5C buffer) */
{{0, 0x0, 0x6E},{0, 0x2, 0x1B}},
/* state = 0xDD (7 bits, 0x5D buffer) */
{{0, 0x1, 0x37},{0, 0x0, 0x6E}},
/* state = 0xDE (7 bits, 0x5E buffer) */
{{0, 0x0, 0x6F},{0, 0x1, 0x37}},
/* state = 0xDF (7 bits, 0x5F buffer) */
{{0, 0x5, 0x3},{0, 0x0, 0x6F}},
/* state = 0xE0 (7 bits, 0x60 buffer) */
{{0, 0x0, 0x70},{0, 0x5, 0x3}},
/* state = 0xE1 (7 bits, 0x61 buffer) */
{{0, 0x1, 0x38},{0, 0x0, 0x70}},
/* state = 0xE2 (7 bits, 0x62 buffer) */
{{0, 0x0, 0x71},{0, 0x1, 0x38}},
/* state = 0xE3 (7 bits, 0x63 buffer) */
{{0, 0x2, 0x1C},{0, 0x0, 0x71}},
/* state = 0xE4 (7 bits, 0x64 buffer) */
{{0, 0x0, 0x72},{0, 0x2, 0x1C}},
/* state = 0xE5 (7 bits, 0x65 buffer) */
{{0, 0x1, 0x39},{0, 0x0, 0x72}},
/* state = 0xE6 (7 bits, 0x66 buffer) */
{{0, 0x0, 0x73},{0, 0x1, 0x39}},
/* state = 0xE7 (7 bits, 0x67 buffer) */
{{0, 0x3, 0xE},{0, 0x0, 0x73}},
/* state = 0xE8 (7 bits, 0x68 buffer) */
{{0, 0x0, 0x74},{0, 0x3, 0xE}},
/* state = 0xE9 (7 bits, 0x69 buffer) */
{{0, 0x1, 0x3A},{0, 0x0, 0x74}},
/* state = 0xEA (7 bits, 0x6A buffer) */
{{0, 0x0, 0x75},{0, 0x1, 0x3A}},
/* state = 0xEB (7 bits, 0x6B buffer) */
{{0, 0x2, 0x1D},{0, 0x0, 0x75}},
/* state = 0xEC (7 bits, 0x6C buffer) */
{{0, 0x0, 0x76},{0, 0x2, 0x1D}},
/* state = 0xED (7 bits, 0x6D buffer) */
{{0, 0x1, 0x3B},{0, 0x0, 0x76}},
/* state = 0xEE (7 bits, 0x6E buffer) */
{{0, 0x0, 0x77},{0, 0x1, 0x3B}},
/* state = 0xEF (7 bits, 0x6F buffer) */
{{0, 0x4, 0x7},{0, 0x0, 0x77}},
/* state = 0xF0 (7 bits, 0x70 buffer) */
{{0, 0x0, 0x78},{0, 0x4, 0x7}},
/* state = 0xF1 (7 bits, 0x71 buffer) */
{{0, 0x1, 0x3C},{0, 0x0, 0x78}},
/* state = 0xF2 (7 bits, 0x72 buffer) */
{{0, 0x0, 0x79},{0, 0x1, 0x3C}},
/* state = 0xF3 (7 bits, 0x73 buffer) */
{{0, 0x2, 0x1E},{0, 0x0, 0x79}},
/* state = 0xF4 (7 bits, 0x74 buffer) */
{{0, 0x0, 0x7A},{0, 0x2, 0x1E}},
/* state = 0xF5 (7 bits, 0x75 buffer) */
{{0, 0x1, 0x3D},{0, 0x0, 0x7A}},
/* state = 0xF6 (7 bits, 0x76 buffer) */
{{0, 0x0, 0x7B},{0, 0x1, 0x3D}},
/* state = 0xF7 (7 bits, 0x77 buffer) */
{{0, 0x3, 0xF},{0, 0x0, 0x7B}},
/* state = 0xF8 (7 bits, 0x78 buffer) */
{{0, 0x0, 0x7C},{0, 0x3, 0xF}},
/* state = 0xF9 (7 bits, 0x79 buffer) */
{{0, 0x1, 0x3E},{0, 0x0, 0x7C}},
/* state = 0xFA (7 bits, 0x7A buffer) */
{{0, 0x0, 0x7D},{0, 0x1, 0x3E}},
/* state = 0xFB (7 bits, 0x7B buffer) */
{{0, 0x2, 0x1F},{0, 0x0, 0x7D}},
/* state = 0xFC (7 bits, 0x7C buffer) */
{{0, 0x0, 0x7E},{0, 0x2, 0x1F}},
/* state = 0xFD (7 bits, 0x7D buffer) */
{{0, 0x1, 0x3F},{0, 0x0, 0x7E}},
/* state = 0xFE (7 bits, 0x7E buffer) */
{{0, 0x0, 0x7F},{0, 0x1, 0x3F}},
/* state = 0xFF (7 bits, 0x7F buffer) */
{{1, 0x7, 0x0},{0, 0x0, 0x7F}},
/* state = 0x100 (8 bits, 0x0 buffer) */
{{0, 0x0, 0x80},{1, 0x8, 0x0}},
/* state = 0x101 (8 bits, 0x1 buffer) */
{{0, 0x1, 0x40},{0, 0x0, 0x80}},
/* state = 0x102 (8 bits, 0x2 buffer) */
{{0, 0x0, 0x81},{0, 0x1, 0x40}},
/* state = 0x103 (8 bits, 0x3 buffer) */
{{0, 0x2, 0x20},{0, 0x0, 0x81}},
/* state = 0x104 (8 bits, 0x4 buffer) */
{{0, 0x0, 0x82},{0, 0x2, 0x20}},
/* state = 0x105 (8 bits, 0x5 buffer) */
{{0, 0x1, 0x41},{0, 0x0, 0x82}},
/* state = 0x106 (8 bits, 0x6 buffer) */
{{0, 0x0, 0x83},{0, 0x1, 0x41}},
/* state = 0x107 (8 bits, 0x7 buffer) */
{{0, 0x3, 0x10},{0, 0x0, 0x83}},
/* state = 0x108 (8 bits, 0x8 buffer) */
{{0, 0x0, 0x84},{0, 0x3, 0x10}},
/* state = 0x109 (8 bits, 0x9 buffer) */
{{0, 0x1, 0x42},{0, 0x0, 0x84}},
/* state = 0x10A (8 bits, 0xA buffer) */
{{0, 0x0, 0x85},{0, 0x1, 0x42}},
/* state = 0x10B (8 bits, 0xB buffer) */
{{0, 0x2, 0x21},{0, 0x0, 0x85}},
/* state = 0x10C (8 bits, 0xC buffer) */
{{0, 0x0, 0x86},{0, 0x2, 0x21}},
/* state = 0x10D (8 bits, 0xD buffer) */
{{0, 0x1, 0x43},{0, 0x0, 0x86}},
/* state = 0x10E (8 bits, 0xE buffer) */
{{0, 0x0, 0x87},{0, 0x1, 0x43}},
/* state = 0x10F (8 bits, 0xF buffer) */
{{0, 0x4, 0x8},{0, 0x0, 0x87}},
/* state = 0x110 (8 bits, 0x10 buffer) */
{{0, 0x0, 0x88},{0, 0x4, 0x8}},
/* state = 0x111 (8 bits, 0x11 buffer) */
{{0, 0x1, 0x44},{0, 0x0, 0x88}},
/* state = 0x112 (8 bits, 0x12 buffer) */
{{0, 0x0, 0x89},{0, 0x1, 0x44}},
/* state = 0x113 (8 bits, 0x13 buffer) */
{{0, 0x2, 0x22},{0, 0x0, 0x89}},
/* state = 0x114 (8 bits, 0x14 buffer) */
{{0, 0x0, 0x8A},{0, 0x2, 0x22}},
/* state = 0x115 (8 bits, 0x15 buffer) */
{{0, 0x1, 0x45},{0, 0x0, 0x8A}},
/* state = 0x116 (8 bits, 0x16 buffer) */
{{0, 0x0, 0x8B},{0, 0x1, 0x45}},
/* state = 0x117 (8 bits, 0x17 buffer) */
{{0, 0x3, 0x11},{0, 0x0, 0x8B}},
/* state = 0x118 (8 bits, 0x18 buffer) */
{{0, 0x0, 0x8C},{0, 0x3, 0x11}},
/* state = 0x119 (8 bits, 0x19 buffer) */
{{0, 0x1, 0x46},{0, 0x0, 0x8C}},
/* state = 0x11A (8 bits, 0x1A buffer) */
{{0, 0x0, 0x8D},{0, 0x1, 0x46}},
/* state = 0x11B (8 bits, 0x1B buffer) */
{{0, 0x2, 0x23},{0, 0x0, 0x8D}},
/* state = 0x11C (8 bits, 0x1C buffer) */
{{0, 0x0, 0x8E},{0, 0x2, 0x23}},
/* state = 0x11D (8 bits, 0x1D buffer) */
{{0, 0x1, 0x47},{0, 0x0, 0x8E}},
/* state = 0x11E (8 bits, 0x1E buffer) */
{{0, 0x0, 0x8F},{0, 0x1, 0x47}},
/* state = 0x11F (8 bits, 0x1F buffer) */
{{0, 0x5, 0x4},{0, 0x0, 0x8F}},
/* state = 0x120 (8 bits, 0x20 buffer) */
{{0, 0x0, 0x90},{0, 0x5, 0x4}},
/* state = 0x121 (8 bits, 0x21 buffer) */
{{0, 0x1, 0x48},{0, 0x0, 0x90}},
/* state = 0x122 (8 bits, 0x22 buffer) */
{{0, 0x0, 0x91},{0, 0x1, 0x48}},
/* state = 0x123 (8 bits, 0x23 buffer) */
{{0, 0x2, 0x24},{0, 0x0, 0x91}},
/* state = 0x124 (8 bits, 0x24 buffer) */
{{0, 0x0, 0x92},{0, 0x2, 0x24}},
/* state = 0x125 (8 bits, 0x25 buffer) */
{{0, 0x1, 0x49},{0, 0x0, 0x92}},
/* state = 0x126 (8 bits, 0x26 buffer) */
{{0, 0x0, 0x93},{0, 0x1, 0x49}},
/* state = 0x127 (8 bits, 0x27 buffer) */
{{0, 0x3, 0x12},{0, 0x0, 0x93}},
/* state = 0x128 (8 bits, 0x28 buffer) */
{{0, 0x0, 0x94},{0, 0x3, 0x12}},
/* state = 0x129 (8 bits, 0x29 buffer) */
{{0, 0x1, 0x4A},{0, 0x0, 0x94}},
/* state = 0x12A (8 bits, 0x2A buffer) */
{{0, 0x0, 0x95},{0, 0x1, 0x4A}},
/* state = 0x12B (8 bits, 0x2B buffer) */
{{0, 0x2, 0x25},{0, 0x0, 0x95}},
/* state = 0x12C (8 bits, 0x2C buffer) */
{{0, 0x0, 0x96},{0, 0x2, 0x25}},
/* state = 0x12D (8 bits, 0x2D buffer) */
{{0, 0x1, 0x4B},{0, 0x0, 0x96}},
/* state = 0x12E (8 bits, 0x2E buffer) */
{{0, 0x0, 0x97},{0, 0x1, 0x4B}},
/* state = 0x12F (8 bits, 0x2F buffer) */
{{0, 0x4, 0x9},{0, 0x0, 0x97}},
/* state = 0x130 (8 bits, 0x30 buffer) */
{{0, 0x0, 0x98},{0, 0x4, 0x9}},
/* state = 0x131 (8 bits, 0x31 buffer) */
{{0, 0x1, 0x4C},{0, 0x0, 0x98}},
/* state = 0x132 (8 bits, 0x32 buffer) */
{{0, 0x0, 0x99},{0, 0x1, 0x4C}},
/* state = 0x133 (8 bits, 0x33 buffer) */
{{0, 0x2, 0x26},{0, 0x0, 0x99}},
/* state = 0x134 (8 bits, 0x34 buffer) */
{{0, 0x0, 0x9A},{0, 0x2, 0x26}},
/* state = 0x135 (8 bits, 0x35 buffer) */
{{0, 0x1, 0x4D},{0, 0x0, 0x9A}},
/* state = 0x136 (8 bits, 0x36 buffer) */
{{0, 0x0, 0x9B},{0, 0x1, 0x4D}},
/* state = 0x137 (8 bits, 0x37 buffer) */
{{0, 0x3, 0x13},{0, 0x0, 0x9B}},
/* state = 0x138 (8 bits, 0x38 buffer) */
{{0, 0x0, 0x9C},{0, 0x3, 0x13}},
/* state = 0x139 (8 bits, 0x39 buffer) */
{{0, 0x1, 0x4E},{0, 0x0, 0x9C}},
/* state = 0x13A (8 bits, 0x3A buffer) */
{{0, 0x0, 0x9D},{0, 0x1, 0x4E}},
/* state = 0x13B (8 bits, 0x3B buffer) */
{{0, 0x2, 0x27},{0, 0x0, 0x9D}},
/* state = 0x13C (8 bits, 0x3C buffer) */
{{0, 0x0, 0x9E},{0, 0x2, 0x27}},
/* state = 0x13D (8 bits, 0x3D buffer) */
{{0, 0x1, 0x4F},{0, 0x0, 0x9E}},
/* state = 0x13E (8 bits, 0x3E buffer) */
{{0, 0x0, 0x9F},{0, 0x1, 0x4F}},
/* state = 0x13F (8 bits, 0x3F buffer) */
{{0, 0x6, 0x2},{0, 0x0, 0x9F}},
/* state = 0x140 (8 bits, 0x40 buffer) */
{{0, 0x0, 0xA0},{0, 0x6, 0x2}},
/* state = 0x141 (8 bits, 0x41 buffer) */
{{0, 0x1, 0x50},{0, 0x0, 0xA0}},
/* state = 0x142 (8 bits, 0x42 buffer) */
{{0, 0x0, 0xA1},{0, 0x1, 0x50}},
/* state = 0x143 (8 bits, 0x43 buffer) */
{{0, 0x2, 0x28},{0, 0x0, 0xA1}},
/* state = 0x144 (8 bits, 0x44 buffer) */
{{0, 0x0, 0xA2},{0, 0x2, 0x28}},
/* state = 0x145 (8 bits, 0x45 buffer) */
{{0, 0x1, 0x51},{0, 0x0, 0xA2}},
/* state = 0x146 (8 bits, 0x46 buffer) */
{{0, 0x0, 0xA3},{0, 0x1, 0x51}},
/* state = 0x147 (8 bits, 0x47 buffer) */
{{0, 0x3, 0x14},{0, 0x0, 0xA3}},
/* state = 0x148 (8 bits, 0x48 buffer) */
{{0, 0x0, 0xA4},{0, 0x3, 0x14}},
/* state = 0x149 (8 bits, 0x49 buffer) */
{{0, 0x1, 0x52},{0, 0x0, 0xA4}},
/* state = 0x14A (8 bits, 0x4A buffer) */
{{0, 0x0, 0xA5},{0, 0x1, 0x52}},
/* state = 0x14B (8 bits, 0x4B buffer) */
{{0, 0x2, 0x29},{0, 0x0, 0xA5}},
/* state = 0x14C (8 bits, 0x4C buffer) */
{{0, 0x0, 0xA6},{0, 0x2, 0x29}},
/* state = 0x14D (8 bits, 0x4D buffer) */
{{0, 0x1, 0x53},{0, 0x0, 0xA6}},
/* state = 0x14E (8 bits, 0x4E buffer) */
{{0, 0x0, 0xA7},{0, 0x1, 0x53}},
/* state = 0x14F (8 bits, 0x4F buffer) */
{{0, 0x4, 0xA},{0, 0x0, 0xA7}},
/* state = 0x150 (8 bits, 0x50 buffer) */
{{0, 0x0, 0xA8},{0, 0x4, 0xA}},
/* state = 0x151 (8 bits, 0x51 buffer) */
{{0, 0x1, 0x54},{0, 0x0, 0xA8}},
/* state = 0x152 (8 bits, 0x52 buffer) */
{{0, 0x0, 0xA9},{0, 0x1, 0x54}},
/* state = 0x153 (8 bits, 0x53 buffer) */
{{0, 0x2, 0x2A},{0, 0x0, 0xA9}},
/* state = 0x154 (8 bits, 0x54 buffer) */
{{0, 0x0, 0xAA},{0, 0x2, 0x2A}},
/* state = 0x155 (8 bits, 0x55 buffer) */
{{0, 0x1, 0x55},{0, 0x0, 0xAA}},
/* state = 0x156 (8 bits, 0x56 buffer) */
{{0, 0x0, 0xAB},{0, 0x1, 0x55}},
/* state = 0x157 (8 bits, 0x57 buffer) */
{{0, 0x3, 0x15},{0, 0x0, 0xAB}},
/* state = 0x158 (8 bits, 0x58 buffer) */
{{0, 0x0, 0xAC},{0, 0x3, 0x15}},
/* state = 0x159 (8 bits, 0x59 buffer) */
{{0, 0x1, 0x56},{0, 0x0, 0xAC}},
/* state = 0x15A (8 bits, 0x5A buffer) */
{{0, 0x0, 0xAD},{0, 0x1, 0x56}},
/* state = 0x15B (8 bits, 0x5B buffer) */
{{0, 0x2, 0x2B},{0, 0x0, 0xAD}},
/* state = 0x15C (8 bits, 0x5C buffer) */
{{0, 0x0, 0xAE},{0, 0x2, 0x2B}},
/* state = 0x15D (8 bits, 0x5D buffer) */
{{0, 0x1, 0x57},{0, 0x0, 0xAE}},
/* state = 0x15E (8 bits, 0x5E buffer) */
{{0, 0x0, 0xAF},{0, 0x1, 0x57}},
/* state = 0x15F (8 bits, 0x5F buffer) */
{{0, 0x5, 0x5},{0, 0x0, 0xAF}},
/* state = 0x160 (8 bits, 0x60 buffer) */
{{0, 0x0, 0xB0},{0, 0x5, 0x5}},
/* state = 0x161 (8 bits, 0x61 buffer) */
{{0, 0x1, 0x58},{0, 0x0, 0xB0}},
/* state = 0x162 (8 bits, 0x62 buffer) */
{{0, 0x0, 0xB1},{0, 0x1, 0x58}},
/* state = 0x163 (8 bits, 0x63 buffer) */
{{0, 0x2, 0x2C},{0, 0x0, 0xB1}},
/* state = 0x164 (8 bits, 0x64 buffer) */
{{0, 0x0, 0xB2},{0, 0x2, 0x2C}},
/* state = 0x165 (8 bits, 0x65 buffer) */
{{0, 0x1, 0x59},{0, 0x0, 0xB2}},
/* state = 0x166 (8 bits, 0x66 buffer) */
{{0, 0x0, 0xB3},{0, 0x1, 0x59}},
/* state = 0x167 (8 bits, 0x67 buffer) */
{{0, 0x3, 0x16},{0, 0x0, 0xB3}},
/* state = 0x168 (8 bits, 0x68 buffer) */
{{0, 0x0, 0xB4},{0, 0x3, 0x16}},
/* state = 0x169 (8 bits, 0x69 buffer) */
{{0, 0x1, 0x5A},{0, 0x0, 0xB4}},
/* state = 0x16A (8 bits, 0x6A buffer) */
{{0, 0x0, 0xB5},{0, 0x1, 0x5A}},
/* state = 0x16B (8 bits, 0x6B buffer) */
{{0, 0x2, 0x2D},{0, 0x0, 0xB5}},
/* state = 0x16C (8 bits, 0x6C buffer) */
{{0, 0x0, 0xB6},{0, 0x2, 0x2D}},
/* state = 0x16D (8 bits, 0x6D buffer) */
{{0, 0x1, 0x5B},{0, 0x0, 0xB6}},
/* state = 0x16E (8 bits, 0x6E buffer) */
{{0, 0x0, 0xB7},{0, 0x1, 0x5B}},
/* state = 0x16F (8 bits, 0x6F buffer) */
{{0, 0x4, 0xB},{0, 0x0, 0xB7}},
/* state = 0x170 (8 bits, 0x70 buffer) */
{{0, 0x0, 0xB8},{0, 0x4, 0xB}},
/* state = 0x171 (8 bits, 0x71 buffer) */
{{0, 0x1, 0x5C},{0, 0x0, 0xB8}},
/* state = 0x172 (8 bits, 0x72 buffer) */
{{0, 0x0, 0xB9},{0, 0x1, 0x5C}},
/* state = 0x173 (8 bits, 0x73 buffer) */
{{0, 0x2, 0x2E},{0, 0x0, 0xB9}},
/* state = 0x174 (8 bits, 0x74 buffer) */
{{0, 0x0, 0xBA},{0, 0x2, 0x2E}},
/* state = 0x175 (8 bits, 0x75 buffer) */
{{0, 0x1, 0x5D},{0, 0x0, 0xBA}},
/* state = 0x176 (8 bits, 0x76 buffer) */
{{0, 0x0, 0xBB},{0, 0x1, 0x5D}},
/* state = 0x177 (8 bits, 0x77 buffer) */
{{0, 0x3, 0x17},{0, 0x0, 0xBB}},
/* state = 0x178 (8 bits, 0x78 buffer) */
{{0, 0x0, 0xBC},{0, 0x3, 0x17}},
/* state = 0x179 (8 bits, 0x79 buffer) */
{{0, 0x1, 0x5E},{0, 0x0, 0xBC}},
/* state = 0x17A (8 bits, 0x7A buffer) */
{{0, 0x0, 0xBD},{0, 0x1, 0x5E}},
/* state = 0x17B (8 bits, 0x7B buffer) */
{{0, 0x2, 0x2F},{0, 0x0, 0xBD}},
/* state = 0x17C (8 bits, 0x7C buffer) */
{{0, 0x0, 0xBE},{0, 0x2, 0x2F}},
/* state = 0x17D (8 bits, 0x7D buffer) */
{{0, 0x1, 0x5F},{0, 0x0, 0xBE}},
/* state = 0x17E (8 bits, 0x7E buffer) */
{{0, 0x0, 0xBF},{0, 0x1, 0x5F}},
/* state = 0x17F (8 bits, 0x7F buffer) */
{{0, 0x7, 0x0},{0, 0x0, 0xBF}},
/* state = 0x180 (8 bits, 0x80 buffer) */
{{0, 0x0, 0xC0},{0, 0x7, 0x0}},
/* state = 0x181 (8 bits, 0x81 buffer) */
{{0, 0x1, 0x60},{0, 0x0, 0xC0}},
/* state = 0x182 (8 bits, 0x82 buffer) */
{{0, 0x0, 0xC1},{0, 0x1, 0x60}},
/* state = 0x183 (8 bits, 0x83 buffer) */
{{0, 0x2, 0x30},{0, 0x0, 0xC1}},
/* state = 0x184 (8 bits, 0x84 buffer) */
{{0, 0x0, 0xC2},{0, 0x2, 0x30}},
/* state = 0x185 (8 bits, 0x85 buffer) */
{{0, 0x1, 0x61},{0, 0x0, 0xC2}},
/* state = 0x186 (8 bits, 0x86 buffer) */
{{0, 0x0, 0xC3},{0, 0x1, 0x61}},
/* state = 0x187 (8 bits, 0x87 buffer) */
{{0, 0x3, 0x18},{0, 0x0, 0xC3}},
/* state = 0x188 (8 bits, 0x88 buffer) */
{{0, 0x0, 0xC4},{0, 0x3, 0x18}},
/* state = 0x189 (8 bits, 0x89 buffer) */
{{0, 0x1, 0x62},{0, 0x0, 0xC4}},
/* state = 0x18A (8 bits, 0x8A buffer) */
{{0, 0x0, 0xC5},{0, 0x1, 0x62}},
/* state = 0x18B (8 bits, 0x8B buffer) */
{{0, 0x2, 0x31},{0, 0x0, 0xC5}},
/* state = 0x18C (8 bits, 0x8C buffer) */
{{0, 0x0, 0xC6},{0, 0x2, 0x31}},
/* state = 0x18D (8 bits, 0x8D buffer) */
{{0, 0x1, 0x63},{0, 0x0, 0xC6}},
/* state = 0x18E (8 bits, 0x8E buffer) */
{{0, 0x0, 0xC7},{0, 0x1, 0x63}},
/* state = 0x18F (8 bits, 0x8F buffer) */
{{0, 0x4, 0xC},{0, 0x0, 0xC7}},
/* state = 0x190 (8 bits, 0x90 buffer) */
{{0, 0x0, 0xC8},{0, 0x4, 0xC}},
/* state = 0x191 (8 bits, 0x91 buffer) */
{{0, 0x1, 0x64},{0, 0x0, 0xC8}},
/* state = 0x192 (8 bits, 0x92 buffer) */
{{0, 0x0, 0xC9},{0, 0x1, 0x64}},
/* state = 0x193 (8 bits, 0x93 buffer) */
{{0, 0x2, 0x32},{0, 0x0, 0xC9}},
/* state = 0x194 (8 bits, 0x94 buffer) */
{{0, 0x0, 0xCA},{0, 0x2, 0x32}},
/* state = 0x195 (8 bits, 0x95 buffer) */
{{0, 0x1, 0x65},{0, 0x0, 0xCA}},
/* state = 0x196 (8 bits, 0x96 buffer) */
{{0, 0x0, 0xCB},{0, 0x1, 0x65}},
/* state = 0x197 (8 bits, 0x97 buffer) */
{{0, 0x3, 0x19},{0, 0x0, 0xCB}},
/* state = 0x198 (8 bits, 0x98 buffer) */
{{0, 0x0, 0xCC},{0, 0x3, 0x19}},
/* state = 0x199 (8 bits, 0x99 buffer) */
{{0, 0x1, 0x66},{0, 0x0, 0xCC}},
/* state = 0x19A (8 bits, 0x9A buffer) */
{{0, 0x0, 0xCD},{0, 0x1, 0x66}},
/* state = 0x19B (8 bits, 0x9B buffer) */
{{0, 0x2, 0x33},{0, 0x0, 0xCD}},
/* state = 0x19C (8 bits, 0x9C buffer) */
{{0, 0x0, 0xCE},{0, 0x2, 0x33}},
/* state = 0x19D (8 bits, 0x9D buffer) */
{{0, 0x1, 0x67},{0, 0x0, 0xCE}},
/* state = 0x19E (8 bits, 0x9E buffer) */
{{0, 0x0, 0xCF},{0, 0x1, 0x67}},
/* state = 0x19F (8 bits, 0x9F buffer) */
{{0, 0x5, 0x6},{0, 0x0, 0xCF}},
/* state = 0x1A0 (8 bits, 0xA0 buffer) */
{{0, 0x0, 0xD0},{0, 0x5, 0x6}},
/* state = 0x1A1 (8 bits, 0xA1 buffer) */
{{0, 0x1, 0x68},{0, 0x0, 0xD0}},
/* state = 0x1A2 (8 bits, 0xA2 buffer) */
{{0, 0x0, 0xD1},{0, 0x1, 0x68}},
/* state = 0x1A3 (8 bits, 0xA3 buffer) */
{{0, 0x2, 0x34},{0, 0x0, 0xD1}},
/* state = 0x1A4 (8 bits, 0xA4 buffer) */
{{0, 0x0, 0xD2},{0, 0x2, 0x34}},
/* state = 0x1A5 (8 bits, 0xA5 buffer) */
{{0, 0x1, 0x69},{0, 0x0, 0xD2}},
/* state = 0x1A6 (8 bits, 0xA6 buffer) */
{{0, 0x0, 0xD3},{0, 0x1, 0x69}},
/* state = 0x1A7 (8 bits, 0xA7 buffer) */
{{0, 0x3, 0x1A},{0, 0x0, 0xD3}},
/* state = 0x1A8 (8 bits, 0xA8 buffer) */
{{0, 0x0, 0xD4},{0, 0x3, 0x1A}},
/* state = 0x1A9 (8 bits, 0xA9 buffer) */
{{0, 0x1, 0x6A},{0, 0x0, 0xD4}},
/* state = 0x1AA (8 bits, 0xAA buffer) */
{{0, 0x0, 0xD5},{0, 0x1, 0x6A}},
/* state = 0x1AB (8 bits, 0xAB buffer) */
{{0, 0x2, 0x35},{0, 0x0, 0xD5}},
/* state = 0x1AC (8 bits, 0xAC buffer) */
{{0, 0x0, 0xD6},{0, 0x2, 0x35}},
/* state = 0x1AD (8 bits, 0xAD buffer) */
{{0, 0x1, 0x6B},{0, 0x0, 0xD6}},
/* state = 0x1AE (8 bits, 0xAE buffer) */
{{0, 0x0, 0xD7},{0, 0x1, 0x6B}},
/* state = 0x1AF (8 bits, 0xAF buffer) */
{{0, 0x4, 0xD},{0, 0x0, 0xD7}},
/* state = 0x1B0 (8 bits, 0xB0 buffer) */
{{0, 0x0, 0xD8},{0, 0x4, 0xD}},
/* state = 0x1B1 (8 bits, 0xB1 buffer) */
{{0, 0x1, 0x6C},{0, 0x0, 0xD8}},
/* state = 0x1B2 (8 bits, 0xB2 buffer) */
{{0, 0x0, 0xD9},{0, 0x1, 0x6C}},
/* state = 0x1B3 (8 bits, 0xB3 buffer) */
{{0, 0x2, 0x36},{0, 0x0, 0xD9}},
/* state = 0x1B4 (8 bits, 0xB4 buffer) */
{{0, 0x0, 0xDA},{0, 0x2, 0x36}},
/* state = 0x1B5 (8 bits, 0xB5 buffer) */
{{0, 0x1, 0x6D},{0, 0x0, 0xDA}},
/* state = 0x1B6 (8 bits, 0xB6 buffer) */
{{0, 0x0, 0xDB},{0, 0x1, 0x6D}},
/* state = 0x1B7 (8 bits, 0xB7 buffer) */
{{0, 0x3, 0x1B},{0, 0x0, 0xDB}},
/* state = 0x1B8 (8 bits, 0xB8 buffer) */
{{0, 0x0, 0xDC},{0, 0x3, 0x1B}},
/* state = 0x1B9 (8 bits, 0xB9 buffer) */
{{0, 0x1, 0x6E},{0, 0x0, 0xDC}},
/* state = 0x1BA (8 bits, 0xBA buffer) */
{{0, 0x0, 0xDD},{0, 0x1, 0x6E}},
/* state = 0x1BB (8 bits, 0xBB buffer) */
{{0, 0x2, 0x37},{0, 0x0, 0xDD}},
/* state = 0x1BC (8 bits, 0xBC buffer) */
{{0, 0x0, 0xDE},{0, 0x2, 0x37}},
/* state = 0x1BD (8 bits, 0xBD buffer) */
{{0, 0x1, 0x6F},{0, 0x0, 0xDE}},
/* state = 0x1BE (8 bits, 0xBE buffer) */
{{0, 0x0, 0xDF},{0, 0x1, 0x6F}},
/* state = 0x1BF (8 bits, 0xBF buffer) */
{{0, 0x6, 0x3},{0, 0x0, 0xDF}},
/* state = 0x1C0 (8 bits, 0xC0 buffer) */
{{0, 0x0, 0xE0},{0, 0x6, 0x3}},
/* state = 0x1C1 (8 bits, 0xC1 buffer) */
{{0, 0x1, 0x70},{0, 0x0, 0xE0}},
/* state = 0x1C2 (8 bits, 0xC2 buffer) */
{{0, 0x0, 0xE1},{0, 0x1, 0x70}},
/* state = 0x1C3 (8 bits, 0xC3 buffer) */
{{0, 0x2, 0x38},{0, 0x0, 0xE1}},
/* state = 0x1C4 (8 bits, 0xC4 buffer) */
{{0, 0x0, 0xE2},{0, 0x2, 0x38}},
/* state = 0x1C5 (8 bits, 0xC5 buffer) */
{{0, 0x1, 0x71},{0, 0x0, 0xE2}},
/* state = 0x1C6 (8 bits, 0xC6 buffer) */
{{0, 0x0, 0xE3},{0, 0x1, 0x71}},
/* state = 0x1C7 (8 bits, 0xC7 buffer) */
{{0, 0x3, 0x1C},{0, 0x0, 0xE3}},
/* state = 0x1C8 (8 bits, 0xC8 buffer) */
{{0, 0x0, 0xE4},{0, 0x3, 0x1C}},
/* state = 0x1C9 (8 bits, 0xC9 buffer) */
{{0, 0x1, 0x72},{0, 0x0, 0xE4}},
/* state = 0x1CA (8 bits, 0xCA buffer) */
{{0, 0x0, 0xE5},{0, 0x1, 0x72}},
/* state = 0x1CB (8 bits, 0xCB buffer) */
{{0, 0x2, 0x39},{0, 0x0, 0xE5}},
/* state = 0x1CC (8 bits, 0xCC buffer) */
{{0, 0x0, 0xE6},{0, 0x2, 0x39}},
/* state = 0x1CD (8 bits, 0xCD buffer) */
{{0, 0x1, 0x73},{0, 0x0, 0xE6}},
/* state = 0x1CE (8 bits, 0xCE buffer) */
{{0, 0x0, 0xE7},{0, 0x1, 0x73}},
/* state = 0x1CF (8 bits, 0xCF buffer) */
{{0, 0x4, 0xE},{0, 0x0, 0xE7}},
/* state = 0x1D0 (8 bits, 0xD0 buffer) */
{{0, 0x0, 0xE8},{0, 0x4, 0xE}},
/* state = 0x1D1 (8 bits, 0xD1 buffer) */
{{0, 0x1, 0x74},{0, 0x0, 0xE8}},
/* state = 0x1D2 (8 bits, 0xD2 buffer) */
{{0, 0x0, 0xE9},{0, 0x1, 0x74}},
/* state = 0x1D3 (8 bits, 0xD3 buffer) */
{{0, 0x2, 0x3A},{0, 0x0, 0xE9}},
/* state = 0x1D4 (8 bits, 0xD4 buffer) */
{{0, 0x0, 0xEA},{0, 0x2, 0x3A}},
/* state = 0x1D5 (8 bits, 0xD5 buffer) */
{{0, 0x1, 0x75},{0, 0x0, 0xEA}},
/* state = 0x1D6 (8 bits, 0xD6 buffer) */
{{0, 0x0, 0xEB},{0, 0x1, 0x75}},
/* state = 0x1D7 (8 bits, 0xD7 buffer) */
{{0, 0x3, 0x1D},{0, 0x0, 0xEB}},
/* state = 0x1D8 (8 bits, 0xD8 buffer) */
{{0, 0x0, 0xEC},{0, 0x3, 0x1D}},
/* state = 0x1D9 (8 bits, 0xD9 buffer) */
{{0, 0x1, 0x76},{0, 0x0, 0xEC}},
/* state = 0x1DA (8 bits, 0xDA buffer) */
{{0, 0x0, 0xED},{0, 0x1, 0x76}},
/* state = 0x1DB (8 bits, 0xDB buffer) */
{{0, 0x2, 0x3B},{0, 0x0, 0xED}},
/* state = 0x1DC (8 bits, 0xDC buffer) */
{{0, 0x0, 0xEE},{0, 0x2, 0x3B}},
/* state = 0x1DD (8 bits, 0xDD buffer) */
{{0, 0x1, 0x77},{0, 0x0, 0xEE}},
/* state = 0x1DE (8 bits, 0xDE buffer) */
{{0, 0x0, 0xEF},{0, 0x1, 0x77}},
/* state = 0x1DF (8 bits, 0xDF buffer) */
{{0, 0x5, 0x7},{0, 0x0, 0xEF}},
/* state = 0x1E0 (8 bits, 0xE0 buffer) */
{{0, 0x0, 0xF0},{0, 0x5, 0x7}},
/* state = 0x1E1 (8 bits, 0xE1 buffer) */
{{0, 0x1, 0x78},{0, 0x0, 0xF0}},
/* state = 0x1E2 (8 bits, 0xE2 buffer) */
{{0, 0x0, 0xF1},{0, 0x1, 0x78}},
/* state = 0x1E3 (8 bits, 0xE3 buffer) */
{{0, 0x2, 0x3C},{0, 0x0, 0xF1}},
/* state = 0x1E4 (8 bits, 0xE4 buffer) */
{{0, 0x0, 0xF2},{0, 0x2, 0x3C}},
/* state = 0x1E5 (8 bits, 0xE5 buffer) */
{{0, 0x1, 0x79},{0, 0x0, 0xF2}},
/* state = 0x1E6 (8 bits, 0xE6 buffer) */
{{0, 0x0, 0xF3},{0, 0x1, 0x79}},
/* state = 0x1E7 (8 bits, 0xE7 buffer) */
{{0, 0x3, 0x1E},{0, 0x0, 0xF3}},
/* state = 0x1E8 (8 bits, 0xE8 buffer) */
{{0, 0x0, 0xF4},{0, 0x3, 0x1E}},
/* state = 0x1E9 (8 bits, 0xE9 buffer) */
{{0, 0x1, 0x7A},{0, 0x0, 0xF4}},
/* state = 0x1EA (8 bits, 0xEA buffer) */
{{0, 0x0, 0xF5},{0, 0x1, 0x7A}},
/* state = 0x1EB (8 bits, 0xEB buffer) */
{{0, 0x2, 0x3D},{0, 0x0, 0xF5}},
/* state = 0x1EC (8 bits, 0xEC buffer) */
{{0, 0x0, 0xF6},{0, 0x2, 0x3D}},
/* state = 0x1ED (8 bits, 0xED buffer) */
{{0, 0x1, 0x7B},{0, 0x0, 0xF6}},
/* state = 0x1EE (8 bits, 0xEE buffer) */
{{0, 0x0, 0xF7},{0, 0x1, 0x7B}},
/* state = 0x1EF (8 bits, 0xEF buffer) */
{{0, 0x4, 0xF},{0, 0x0, 0xF7}},
/* state = 0x1F0 (8 bits, 0xF0 buffer) */
{{0, 0x0, 0xF8},{0, 0x4, 0xF}},
/* state = 0x1F1 (8 bits, 0xF1 buffer) */
{{0, 0x1, 0x7C},{0, 0x0, 0xF8}},
/* state = 0x1F2 (8 bits, 0xF2 buffer) */
{{0, 0x0, 0xF9},{0, 0x1, 0x7C}},
/* state = 0x1F3 (8 bits, 0xF3 buffer) */
{{0, 0x2, 0x3E},{0, 0x0, 0xF9}},
/* state = 0x1F4 (8 bits, 0xF4 buffer) */
{{0, 0x0, 0xFA},{0, 0x2, 0x3E}},
/* state = 0x1F5 (8 bits, 0xF5 buffer) */
{{0, 0x1, 0x7D},{0, 0x0, 0xFA}},
/* state = 0x1F6 (8 bits, 0xF6 buffer) */
{{0, 0x0, 0xFB},{0, 0x1, 0x7D}},
/* state = 0x1F7 (8 bits, 0xF7 buffer) */
{{0, 0x3, 0x1F},{0, 0x0, 0xFB}},
/* state = 0x1F8 (8 bits, 0xF8 buffer) */
{{0, 0x0, 0xFC},{0, 0x3, 0x1F}},
/* state = 0x1F9 (8 bits, 0xF9 buffer) */
{{0, 0x1, 0x7E},{0, 0x0, 0xFC}},
/* state = 0x1FA (8 bits, 0xFA buffer) */
{{0, 0x0, 0xFD},{0, 0x1, 0x7E}},
/* state = 0x1FB (8 bits, 0xFB buffer) */
{{0, 0x2, 0x3F},{0, 0x0, 0xFD}},
/* state = 0x1FC (8 bits, 0xFC buffer) */
{{0, 0x0, 0xFE},{0, 0x2, 0x3F}},
/* state = 0x1FD (8 bits, 0xFD buffer) */
{{0, 0x1, 0x7F},{0, 0x0, 0xFE}},
/* state = 0x1FE (8 bits, 0xFE buffer) */
{{0, 0x0, 0xFF},{0, 0x1, 0x7F}},
/* state = 0x1FF (8 bits, 0xFF buffer) */
{{1, 0x8, 0x0},{0, 0x0, 0xFF}}
}
